from typing import List, Optional, Dict, Iterable
import aspose.pycore
import aspose.pydrawing
import aspose.svg
import aspose.svg.builder
import aspose.svg.collections
import aspose.svg.converters
import aspose.svg.datatypes
import aspose.svg.diagnostics
import aspose.svg.dom
import aspose.svg.dom.attributes
import aspose.svg.dom.canvas
import aspose.svg.dom.css
import aspose.svg.dom.events
import aspose.svg.dom.mutations
import aspose.svg.dom.traversal
import aspose.svg.dom.traversal.filters
import aspose.svg.dom.views
import aspose.svg.dom.xpath
import aspose.svg.drawing
import aspose.svg.drawing.skiasharp
import aspose.svg.events
import aspose.svg.filters
import aspose.svg.imagevectorization
import aspose.svg.io
import aspose.svg.net
import aspose.svg.net.headers
import aspose.svg.net.messagefilters
import aspose.svg.net.messagehandlers
import aspose.svg.paths
import aspose.svg.rendering
import aspose.svg.rendering.devices
import aspose.svg.rendering.fonts
import aspose.svg.rendering.image
import aspose.svg.rendering.pdf
import aspose.svg.rendering.pdf.encryption
import aspose.svg.rendering.styles
import aspose.svg.rendering.styles.paintservers
import aspose.svg.rendering.xps
import aspose.svg.saving
import aspose.svg.saving.resourcehandlers
import aspose.svg.services
import aspose.svg.toolkit
import aspose.svg.toolkit.optimizers
import aspose.svg.window

class AnimationSplineBuilder:
    '''A builder class for constructing animation timing functions using cubic Bézier curves.
    This class allows for the definition of one or more cubic Bézier curves, each specified by two control points.
    The resulting string can be used in CSS animations or transitions to control the pace of the animation.'''
    
    def add_spline(self, x1 : float, y1 : float, x2 : float, y2 : float) -> aspose.svg.builder.AnimationSplineBuilder:
        '''Adds a cubic Bézier curve to the animation spline.
        
        :param x1: The x-coordinate of the first control point.
        :param y1: The y-coordinate of the first control point.
        :param x2: The x-coordinate of the second control point.
        :param y2: The y-coordinate of the second control point.
        :returns: The current instance of AnimationSplineBuilder for method chaining.'''
        ...
    
    def build(self) -> str:
        '''Builds the animation spline value as a string.
        
        :returns: A string representation of the animation spline, suitable for use in CSS.'''
        ...
    
    ...

class ClipPathBuilder:
    '''A builder class for constructing CSS clip-path values.
    This class provides methods to define clip paths using basic shapes, external references, or geometry boxes.
    It allows for the creation of complex clipping paths in a structured and readable manner.'''
    
    def clip_source_id(self, clip_source_id : str) -> aspose.svg.builder.ClipPathBuilder:
        '''Sets the clip path to reference an external source.
        
        :param clip_source_id: The ID of the external source to reference.
        :returns: The current instance of ClipPathBuilder for method chaining.'''
        ...
    
    def none(self) -> aspose.svg.builder.ClipPathBuilder:
        '''Sets the clip path to 'none', effectively disabling clipping.
        
        :returns: The current instance of ClipPathBuilder for method chaining.'''
        ...
    
    def circle(self, radius : float, center_x : float, center_y : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.ClipPathBuilder:
        '''Defines a circular clip path.
        
        :param radius: Radius of the circle.
        :param center_x: X-coordinate of the circle's center.
        :param center_y: Y-coordinate of the circle's center.
        :param type: The unit type for the dimensions.
        :returns: The current instance of ClipPathBuilder for method chaining.'''
        ...
    
    def ellipse(self, radius_x : float, radius_y : float, center_x : float, center_y : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.ClipPathBuilder:
        '''Defines an elliptical clip path.
        
        :param radius_x: Horizontal radius of the ellipse.
        :param radius_y: Vertical radius of the ellipse.
        :param center_x: X-coordinate of the ellipse's center.
        :param center_y: Y-coordinate of the ellipse's center.
        :param type: The unit type for the dimensions.
        :returns: The current instance of ClipPathBuilder for method chaining.'''
        ...
    
    def rectangle(self, x : float, y : float, width : float, height : float, rx : float, ry : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.ClipPathBuilder:
        '''Defines a rectangular clip path with optional rounded corners.
        
        :param x: X-coordinate of the top-left corner of the rectangle.
        :param y: Y-coordinate of the top-left corner of the rectangle.
        :param width: Width of the rectangle.
        :param height: Height of the rectangle.
        :param rx: Horizontal radius of the corners.
        :param ry: Vertical radius of the corners.
        :param type: The unit type for the dimensions.
        :returns: The current instance of ClipPathBuilder for method chaining.'''
        ...
    
    def polygon(self, points : List[float]) -> aspose.svg.builder.ClipPathBuilder:
        '''Defines a polygonal clip path.
        
        :param points: An array of points defining the vertices of the polygon.
        :returns: The current instance of ClipPathBuilder for method chaining.'''
        ...
    
    def geometry_box(self, box : aspose.svg.builder.GeometryBox) -> aspose.svg.builder.ClipPathBuilder:
        '''Sets the geometry box for the clip path.
        
        :param box: The geometry box to use.
        :returns: The current instance of ClipPathBuilder for method chaining.'''
        ...
    
    def build(self) -> str:
        '''Builds the clip path value as a string.
        
        :returns: A string representation of the clip path.'''
        ...
    
    ...

class ColorBuilder:
    '''A builder class for constructing color values in various formats.
    This class provides methods to set color values and build them into string representations
    that can be used in styling contexts, such as CSS or SVG attributes.'''
    
    def current(self) -> aspose.svg.builder.ColorBuilder:
        '''Sets the color value to 'currentColor', a CSS keyword that represents the current color context.
        
        :returns: The current instance of ColorBuilder for method chaining.'''
        ...
    
    def color(self, color_value : aspose.pydrawing.Color) -> aspose.svg.builder.ColorBuilder:
        '''Sets the color value based on a Color object.
        
        :param color_value: The Color object to set the color to.
        :returns: The current instance of ColorBuilder for method chaining.'''
        ...
    
    def build(self) -> str:
        '''Builds the current color value into a string representation.
        
        :returns: A string representing the color.'''
        ...
    
    ...

class FilterValueListBuilder:
    '''A builder class for creating a list of filter functions for SVG elements.'''
    
    def filter_id(self, filter_id : str) -> aspose.svg.builder.FilterValueListBuilder:
        '''Adds a filter by its ID.
        
        :param filter_id: The ID of the filter.
        :returns: The builder instance for chaining.'''
        ...
    
    def blur(self, std_deviation : float) -> aspose.svg.builder.FilterValueListBuilder:
        '''Adds a blur filter.
        
        :param std_deviation: The standard deviation for the blur.
        :returns: The builder instance for chaining.'''
        ...
    
    def brightness(self, percentage : float) -> aspose.svg.builder.FilterValueListBuilder:
        '''Adds a brightness filter.
        
        :param percentage: The percentage of brightness.
        :returns: The builder instance for chaining.'''
        ...
    
    def contrast(self, percentage : float) -> aspose.svg.builder.FilterValueListBuilder:
        '''Adds a contrast filter.
        
        :param percentage: The percentage of contrast.
        :returns: The builder instance for chaining.'''
        ...
    
    def drop_shadow(self, offset_x : float, offset_y : float, std_deviation : float) -> aspose.svg.builder.FilterValueListBuilder:
        '''Adds a drop shadow filter.
        
        :param offset_x: The X offset of the shadow.
        :param offset_y: The Y offset of the shadow.
        :param std_deviation: The standard deviation of the shadow.
        :returns: The builder instance for chaining.'''
        ...
    
    def grayscale(self, percentage : float) -> aspose.svg.builder.FilterValueListBuilder:
        '''Adds a grayscale filter.
        
        :param percentage: The percentage of grayscale.
        :returns: The builder instance for chaining.'''
        ...
    
    def hue_rotate(self, degrees : float) -> aspose.svg.builder.FilterValueListBuilder:
        '''Adds a hue-rotate filter.
        
        :param degrees: The degrees of hue rotation.
        :returns: The builder instance for chaining.'''
        ...
    
    def invert(self, percentage : float) -> aspose.svg.builder.FilterValueListBuilder:
        '''Adds an invert filter.
        
        :param percentage: The percentage of inversion.
        :returns: The builder instance for chaining.'''
        ...
    
    def opacity(self, percentage : float) -> aspose.svg.builder.FilterValueListBuilder:
        '''Adds an opacity filter.
        
        :param percentage: The percentage of opacity.
        :returns: The builder instance for chaining.'''
        ...
    
    def sepia(self, percentage : float) -> aspose.svg.builder.FilterValueListBuilder:
        '''Adds a sepia filter.
        
        :param percentage: The percentage of sepia tone.
        :returns: The builder instance for chaining.'''
        ...
    
    def saturate(self, percentage : float) -> aspose.svg.builder.FilterValueListBuilder:
        '''Adds a saturate filter.
        
        :param percentage: The percentage of saturation.
        :returns: The builder instance for chaining.'''
        ...
    
    def build(self) -> str:
        '''Builds the final string representing the combined filter functions.
        
        :returns: A string representing the filter functions.'''
        ...
    
    ...

class IAnimationAdditionAttributeSetter:
    '''Interface for setting additional animation attributes.'''
    
    ...

class IAnimationElementBuilder(IBaseAnimationElementBuilder):
    '''Interface for building animation elements.'''
    
    ...

class IAnimationEventAttributeSetter:
    '''Interface for setting animation event attributes.'''
    
    ...

class IAnimationTargetAttributeSetter:
    '''Interface for setting target attributes for animations.'''
    
    ...

class IAnimationTargetElementAttributeSetter:
    '''Interface for setting target element attributes for animations.'''
    
    ...

class IAnimationTimingAttributeSetter:
    '''Interface for setting timing attributes for animations.'''
    
    ...

class IAnimationValueAttributeSetter:
    '''Interface for setting value attributes for animations.'''
    
    ...

class IAttributeSetter:
    '''Basic interface for setting attributes on SVG elements.
    This interface is a fundamental part of the SVG element builder system,
    allowing for the dynamic assignment of attributes to SVG elements.'''
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class IBaseAnimationElementBuilder:
    '''Base interface for building animation elements.'''
    
    ...

class ICommonEventAttributeSetter:
    '''Interface for setting common event attributes.'''
    
    ...

class ICompositeAttributeSetter(IConditionalProcessingAttributeSetter):
    '''Interface for setting a combination of various attribute types.'''
    
    ...

class ICompositeElementBuilder(IAnimationElementBuilder):
    '''Interface for building composite elements, combining various element types.'''
    
    ...

class IConditionalProcessingAttributeSetter:
    '''Interface for setting conditional processing attributes.'''
    
    ...

class ICoreAttributeSetter:
    '''Interface for setting core attributes.'''
    
    ...

class IDescriptiveElementBuilder:
    '''Interface for building descriptive elements like 'desc', 'title', 'metadata'.'''
    
    ...

class IDocumentElementEventAttributeSetter:
    '''Interface for setting document element event attributes.'''
    
    ...

class IDocumentEventAttributeSetter(ICommonEventAttributeSetter):
    '''Interface for setting document event attributes.'''
    
    ...

class IFilterPrimitiveAttributeSetter(IRectAttributeSetter):
    '''Interface for setting attributes specific to filter primitives.'''
    
    ...

class IFilterPrimitiveContentBuilder(IBaseAnimationElementBuilder):
    '''Interface for building content within filter primitives.'''
    
    ...

class IFilterPrimitiveElementBuilder:
    '''Interface for building filter primitive elements.'''
    
    ...

class IFilterPrimitiveInAttributeSetter(IFilterPrimitiveAttributeSetter):
    '''Interface for setting 'in' attributes for filter primitives.'''
    
    ...

class IGlobalEventAttributeSetter(ICommonEventAttributeSetter):
    '''Interface for setting global event attributes.'''
    
    ...

class IGradientStopElementBuilder:
    '''Interface for building gradient stop elements.'''
    
    ...

class IGraphicalEventAttributeSetter:
    '''Interface for setting graphical event attributes.'''
    
    ...

class IHeightAttributeSetter:
    '''Interface for setting height attributes.'''
    
    ...

class IPaintServerElementBuilder:
    '''Interface for building paint server elements.'''
    
    ...

class IPointsAttributeSetter:
    '''Interface for setting points attributes.'''
    
    ...

class IPresentationAttributeSetter(ITransformAttributeSetter):
    '''Interface for setting presentation attributes.'''
    
    ...

class IPreserveAspectRatioAttributeSetter:
    '''Interface for setting 'preserveAspectRatio' attributes.'''
    
    ...

class IRectAttributeSetter(IXYAttributeSetter):
    '''Interface for setting rectangle attributes.'''
    
    ...

class IRefCoordinatesAttributeSetter:
    '''Interface for setting reference coordinates attributes.'''
    
    ...

class ISVGElementBuilder(IAttributeSetter):
    '''Interface for building SVG (Scalable Vector Graphics) elements.
    This interface defines the essential methods and properties required to construct SVG elements programmatically.
    It extends the IAttributeSetter interface to include attribute setting capabilities.'''
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class IShapeAttributeSetter(ICompositeAttributeSetter):
    '''Interface for setting shape attributes.'''
    
    ...

class IShapeContentElementBuilder:
    '''Interface for building content within shape elements.'''
    
    ...

class IShapeElementBuilder:
    '''Interface for building shape elements.'''
    
    ...

class IStructuralElementBuilder:
    '''Interface for building structural elements.'''
    
    ...

class ITextContentPositioningAttributeSetter(ITextContentSetter):
    '''Interface for setting text content positioning attributes.'''
    
    ...

class ITextContentSetter:
    '''Interface for setting text content.'''
    
    ...

class ITransferFunctionAttributeSetter:
    '''Interface for setting transfer function attributes.'''
    
    ...

class ITransformAttributeSetter:
    '''Interface for setting transformation attributes.'''
    
    ...

class IViewBoxAttributeSetter:
    '''Interface for setting 'viewBox' attributes.'''
    
    ...

class IWidthAttributeSetter:
    '''Interface for setting width attributes.'''
    
    ...

class IXAttributeSetter:
    '''Interface for setting 'x' attributes.'''
    
    ...

class IXLinkAttributeSetter:
    '''Interface for setting XLink attributes.'''
    
    ...

class IXYAttributeSetter(IXAttributeSetter):
    '''Interface for setting 'x' and 'y' attributes.'''
    
    ...

class IYAttributeSetter:
    '''Interface for setting 'y' attributes.'''
    
    ...

class MaskBuilder:
    '''A builder class for creating CSS mask properties.
    This class allows for the construction of complex mask styles using various properties such as mask source, position, size, repeat style, and more.
    The resulting string can be used in CSS to define the masking behavior of an element.'''
    
    @overload
    def position(self, position : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.MaskBuilder:
        '''Sets the position of the mask.
        
        :param position: The position value.
        :param type: The type of length measurement.
        :returns: The current instance of MaskBuilder.'''
        ...
    
    @overload
    def position(self, horizontal : float, vertical : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.MaskBuilder:
        '''Sets the position of the mask using horizontal and vertical values.
        
        :param horizontal: The horizontal position value.
        :param vertical: The vertical position value.
        :param type: The type of length measurement.
        :returns: The current instance of MaskBuilder.'''
        ...
    
    @overload
    def position(self, horizontal : aspose.svg.builder.HorizontalPosition, vertical : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.MaskBuilder:
        '''Sets the position of the mask using a predefined horizontal position and a vertical value.
        
        :param horizontal: The predefined horizontal position.
        :param vertical: The vertical position value.
        :param type: The type of length measurement.
        :returns: The current instance of MaskBuilder.'''
        ...
    
    @overload
    def position(self, vertical : aspose.svg.builder.VerticalPosition, horizontal : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.MaskBuilder:
        '''Sets the position of the mask using a predefined vertical position and a horizontal value.
        
        :param vertical: The predefined vertical position.
        :param horizontal: The horizontal position value.
        :param type: The type of length measurement.
        :returns: The current instance of MaskBuilder.'''
        ...
    
    @overload
    def position(self, horizontal : aspose.svg.builder.HorizontalPosition, vertical : aspose.svg.builder.VerticalPosition) -> aspose.svg.builder.MaskBuilder:
        '''Sets the position of the mask using predefined horizontal and vertical positions.
        
        :param horizontal: The predefined horizontal position.
        :param vertical: The predefined vertical position.
        :returns: The current instance of MaskBuilder.'''
        ...
    
    @overload
    def position(self, horizontal_edge : aspose.svg.builder.HorizontalEdge, horizontal_value : float, vertical_edge : aspose.svg.builder.VerticalEdge, vertical_value : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.MaskBuilder:
        '''Sets the position of the mask using edges and values.
        
        :param horizontal_edge: The horizontal edge position.
        :param horizontal_value: The horizontal position value.
        :param vertical_edge: The vertical edge position.
        :param vertical_value: The vertical position value.
        :param type: The type of length measurement.
        :returns: The current instance of MaskBuilder.'''
        ...
    
    def mask_source_id(self, mask_source_id : str) -> aspose.svg.builder.MaskBuilder:
        '''Sets the mask source ID for the mask.
        
        :param mask_source_id: The ID of the mask source element.
        :returns: The current instance of MaskBuilder.'''
        ...
    
    def background_size(self, width : float, height : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.MaskBuilder:
        '''Sets the background size for the mask.
        
        :param width: Width of the background.
        :param height: Height of the background.
        :param type: The type of length measurement.
        :returns: The current instance of MaskBuilder.'''
        ...
    
    def repeat_style(self, style : aspose.svg.builder.RepeatStyle) -> aspose.svg.builder.MaskBuilder:
        '''Sets the repeat style of the mask.
        
        :param style: The repeat style.
        :returns: The current instance of MaskBuilder.'''
        ...
    
    def geometry_box(self, box : aspose.svg.builder.GeometryBox) -> aspose.svg.builder.MaskBuilder:
        '''Sets the geometry box of the mask.
        
        :param box: The geometry box.
        :returns: The current instance of MaskBuilder.'''
        ...
    
    def geometry_box_noclip(self, box : aspose.svg.builder.GeometryBox) -> aspose.svg.builder.MaskBuilder:
        '''Sets the geometry box of the mask with no clipping.
        
        :param box: The geometry box.
        :returns: The current instance of MaskBuilder.'''
        ...
    
    def compositing_operator(self, op : aspose.svg.builder.CompositingOperator) -> aspose.svg.builder.MaskBuilder:
        '''Sets the compositing operator for the mask.
        
        :param op: The compositing operator.
        :returns: The current instance of MaskBuilder.'''
        ...
    
    def build(self) -> str:
        '''Builds the mask property value as a string.
        
        :returns: A string representation of the mask property, suitable for use in CSS.'''
        ...
    
    ...

class PaintBuilder:
    '''A builder class for creating paint values for SVG elements.'''
    
    def none(self) -> aspose.svg.builder.PaintBuilder:
        '''Sets the paint to 'none'.
        
        :returns: The builder instance for chaining.'''
        ...
    
    def color(self, color_value : aspose.pydrawing.Color) -> aspose.svg.builder.PaintBuilder:
        '''Sets the paint to a specific color.
        
        :param color_value: The color to set.
        :returns: The builder instance for chaining.'''
        ...
    
    def paint_server_id(self, paint_server_id : str, fallback_color : Optional[aspose.pydrawing.Color]) -> aspose.svg.builder.PaintBuilder:
        ...
    
    def context_fill(self) -> aspose.svg.builder.PaintBuilder:
        '''Sets the paint to 'context-fill', which uses the current fill color of the context.
        
        :returns: The builder instance for chaining.'''
        ...
    
    def context_stroke(self) -> aspose.svg.builder.PaintBuilder:
        '''Sets the paint to 'context-stroke', which uses the current stroke color of the context.
        
        :returns: The builder instance for chaining.'''
        ...
    
    def build(self) -> str:
        '''Builds the final paint value.
        
        :returns: A string representing the paint value.'''
        ...
    
    ...

class PathBuilder:
    '''Builder class for creating SVG path data strings.'''
    
    def m(self, x : float, y : float) -> aspose.svg.builder.PathBuilder:
        '''Adds a 'Move To' command to the path data.
        
        :param x: The x-coordinate to move to.
        :param y: The y-coordinate to move to.
        :returns: The current PathBuilder instance.'''
        ...
    
    def mr(self, x : float, y : float) -> aspose.svg.builder.PathBuilder:
        '''Adds a relative 'Move To' command to the path data.
        
        :param x: The x-coordinate to move to, relative to the current position.
        :param y: The y-coordinate to move to, relative to the current position.
        :returns: The current PathBuilder instance.'''
        ...
    
    def l(self, x : float, y : float) -> aspose.svg.builder.PathBuilder:
        '''Adds a 'Line To' command to the path data.
        
        :param x: The x-coordinate of the end point of the line.
        :param y: The y-coordinate of the end point of the line.
        :returns: The current PathBuilder instance.'''
        ...
    
    def lr(self, x : float, y : float) -> aspose.svg.builder.PathBuilder:
        '''Adds a relative 'Line To' command to the path data.
        
        :param x: The x-coordinate of the end point of the line, relative to the current position.
        :param y: The y-coordinate of the end point of the line, relative to the current position.
        :returns: The current PathBuilder instance.'''
        ...
    
    def c(self, x1 : float, y1 : float, x2 : float, y2 : float, x : float, y : float) -> aspose.svg.builder.PathBuilder:
        '''Adds a 'Cubic Bezier Curve' command to the path data.
        
        :param x1: The x-coordinate of the first control point.
        :param y1: The y-coordinate of the first control point.
        :param x2: The x-coordinate of the second control point.
        :param y2: The y-coordinate of the second control point.
        :param x: The x-coordinate of the end point of the curve.
        :param y: The y-coordinate of the end point of the curve.
        :returns: The current PathBuilder instance.'''
        ...
    
    def cr(self, x1 : float, y1 : float, x2 : float, y2 : float, x : float, y : float) -> aspose.svg.builder.PathBuilder:
        '''Adds a relative 'Cubic Bezier Curve' command to the path data.
        
        :param x1: The x-coordinate of the first control point, relative to the current position.
        :param y1: The y-coordinate of the first control point, relative to the current position.
        :param x2: The x-coordinate of the second control point, relative to the current position.
        :param y2: The y-coordinate of the second control point, relative to the current position.
        :param x: The x-coordinate of the end point of the curve, relative to the current position.
        :param y: The y-coordinate of the end point of the curve, relative to the current position.
        :returns: The current PathBuilder instance.'''
        ...
    
    def q(self, x1 : float, y1 : float, x : float, y : float) -> aspose.svg.builder.PathBuilder:
        '''Adds a 'Quadratic Bezier Curve' command to the path data.
        
        :param x1: The x-coordinate of the control point.
        :param y1: The y-coordinate of the control point.
        :param x: The x-coordinate of the end point of the curve.
        :param y: The y-coordinate of the end point of the curve.
        :returns: The current PathBuilder instance.'''
        ...
    
    def qr(self, x1 : float, y1 : float, x : float, y : float) -> aspose.svg.builder.PathBuilder:
        '''Adds a relative 'Quadratic Bezier Curve' command to the path data.
        
        :param x1: The x-coordinate of the control point, relative to the current position.
        :param y1: The y-coordinate of the control point, relative to the current position.
        :param x: The x-coordinate of the end point of the curve, relative to the current position.
        :param y: The y-coordinate of the end point of the curve, relative to the current position.
        :returns: The current PathBuilder instance.'''
        ...
    
    def a(self, r1 : float, r2 : float, angle : float, large_arc_flag : bool, sweep_flag : bool, x : float, y : float) -> aspose.svg.builder.PathBuilder:
        '''Adds an 'Elliptical Arc Curve' command to the path data.
        
        :param r1: The x-radius of the ellipse.
        :param r2: The y-radius of the ellipse.
        :param angle: The rotation angle of the ellipse in degrees.
        :param large_arc_flag: Flag indicating if the arc should be greater than or equal to 180 degrees.
        :param sweep_flag: Flag indicating if the arc should be drawn in a positive angle direction.
        :param x: The x-coordinate of the end point of the arc.
        :param y: The y-coordinate of the end point of the arc.
        :returns: The current PathBuilder instance.'''
        ...
    
    def ar(self, r1 : float, r2 : float, angle : float, large_arc_flag : bool, sweep_flag : bool, x : float, y : float) -> aspose.svg.builder.PathBuilder:
        '''Adds a relative 'Elliptical Arc Curve' command to the path data.
        
        :param r1: The x-radius of the ellipse, relative to the current position.
        :param r2: The y-radius of the ellipse, relative to the current position.
        :param angle: The rotation angle of the ellipse in degrees, relative to the current position.
        :param large_arc_flag: Flag indicating if the arc should be greater than or equal to 180 degrees.
        :param sweep_flag: Flag indicating if the arc should be drawn in a positive angle direction.
        :param x: The x-coordinate of the end point of the arc, relative to the current position.
        :param y: The y-coordinate of the end point of the arc, relative to the current position.
        :returns: The current PathBuilder instance.'''
        ...
    
    def h(self, x : float) -> aspose.svg.builder.PathBuilder:
        '''Adds a 'Horizontal Line To' command to the path data.
        
        :param x: The x-coordinate to draw a horizontal line to.
        :returns: The current PathBuilder instance.'''
        ...
    
    def hr(self, x : float) -> aspose.svg.builder.PathBuilder:
        '''Adds a relative 'Horizontal Line To' command to the path data.
        
        :param x: The x-coordinate to draw a horizontal line to, relative to the current position.
        :returns: The current PathBuilder instance.'''
        ...
    
    def v(self, y : float) -> aspose.svg.builder.PathBuilder:
        '''Adds a 'Vertical Line To' command to the path data.
        
        :param y: The y-coordinate to draw a vertical line to.
        :returns: The current PathBuilder instance.'''
        ...
    
    def vr(self, y : float) -> aspose.svg.builder.PathBuilder:
        '''Adds a relative 'Vertical Line To' command to the path data.
        
        :param y: The y-coordinate to draw a vertical line to, relative to the current position.
        :returns: The current PathBuilder instance.'''
        ...
    
    def s(self, x2 : float, y2 : float, x : float, y : float) -> aspose.svg.builder.PathBuilder:
        '''Adds a 'Smooth Cubic Bezier Curve To' command to the path data.
        
        :param x2: The x-coordinate of the second control point.
        :param y2: The y-coordinate of the second control point.
        :param x: The x-coordinate of the end point of the curve.
        :param y: The y-coordinate of the end point of the curve.
        :returns: The current PathBuilder instance.'''
        ...
    
    def sr(self, x2 : float, y2 : float, x : float, y : float) -> aspose.svg.builder.PathBuilder:
        '''Adds a relative 'Smooth Cubic Bezier Curve To' command to the path data.
        
        :param x2: The x-coordinate of the second control point, relative to the current position.
        :param y2: The y-coordinate of the second control point, relative to the current position.
        :param x: The x-coordinate of the end point of the curve, relative to the current position.
        :param y: The y-coordinate of the end point of the curve, relative to the current position.
        :returns: The current PathBuilder instance.'''
        ...
    
    def t(self, x : float, y : float) -> aspose.svg.builder.PathBuilder:
        '''Adds a 'Smooth Quadratic Bezier Curve To' command to the path data.
        
        :param x: The x-coordinate of the end point of the curve.
        :param y: The y-coordinate of the end point of the curve.
        :returns: The current PathBuilder instance.'''
        ...
    
    def tr(self, x : float, y : float) -> aspose.svg.builder.PathBuilder:
        '''Adds a relative 'Smooth Quadratic Bezier Curve To' command to the path data.
        
        :param x: The x-coordinate of the end point of the curve, relative to the current position.
        :param y: The y-coordinate of the end point of the curve, relative to the current position.
        :returns: The current PathBuilder instance.'''
        ...
    
    def z(self) -> aspose.svg.builder.PathBuilder:
        '''Adds a 'Close Path' command to the path data.
        
        :returns: The current PathBuilder instance.'''
        ...
    
    def add_path_segment(self, segment : str) -> aspose.svg.builder.PathBuilder:
        '''Adds a custom path segment to the path data.
        
        :param segment: The custom path segment string.
        :returns: The current PathBuilder instance.'''
        ...
    
    def build(self) -> str:
        '''Builds the path data string.
        
        :returns: The constructed path data string.'''
        ...
    
    ...

class RuleBuilder(IAttributeSetter):
    '''A builder class for constructing CSS style rules.
    This class is used to dynamically build a string of CSS styles by setting various attributes and their values.'''
    
    def build(self) -> str:
        '''Builds the final CSS style string from the accumulated style attributes.
        
        :returns: A string representing the CSS style rule.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates a style attribute with a specified value.
        
        :param name: The name of the CSS style attribute.
        :param value: The value to be set for the specified CSS style attribute.'''
        ...
    
    ...

class SVGAElementBuilder(ISVGElementBuilder):
    '''Builder class for constructing an SVG 'a' element, which is used to define hyperlinks.
    It enables the building of content within 'a' element and provides methods to set various attributes specific to the 'a' element in SVG.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGAElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGAElement) -> aspose.svg.SVGAElement:
        ...
    
    def set_target(self, xml_name : str) -> aspose.svg.builder.SVGAElementBuilder:
        '''Sets the 'target' attribute of the SVG 'a' element to a custom XML name.
        
        :param xml_name: The custom XML name to be used as the target.
        :returns: The current instance of SVGAElementBuilder for method chaining.'''
        ...
    
    def href(self, value : str) -> aspose.svg.builder.SVGAElementBuilder:
        '''Sets the 'href' attribute of the SVG 'a' element, specifying the URL of the linked resource.
        
        :param value: The URL to link to.
        :returns: The current instance of SVGAElementBuilder for method chaining.'''
        ...
    
    def download(self, value : str) -> aspose.svg.builder.SVGAElementBuilder:
        '''Sets the 'download' attribute of the SVG 'a' element, indicating that the link is to be downloaded when activated.
        
        :param value: The filename for the downloaded file.
        :returns: The current instance of SVGAElementBuilder for method chaining.'''
        ...
    
    def ping(self, value : str) -> aspose.svg.builder.SVGAElementBuilder:
        '''Sets the 'ping' attribute of the SVG 'a' element, containing a list of URLs to be notified if the link is followed.
        
        :param value: The list of URLs for pingback.
        :returns: The current instance of SVGAElementBuilder for method chaining.'''
        ...
    
    def rel(self, value : str) -> aspose.svg.builder.SVGAElementBuilder:
        '''Sets the 'rel' attribute of the SVG 'a' element, specifying the relationship of the target object to the link object.
        
        :param value: The relationship type.
        :returns: The current instance of SVGAElementBuilder for method chaining.'''
        ...
    
    def href_lang(self, value : str) -> aspose.svg.builder.SVGAElementBuilder:
        '''Sets the 'hreflang' attribute of the SVG 'a' element, indicating the language of the linked resource.
        
        :param value: The language code of the linked resource.
        :returns: The current instance of SVGAElementBuilder for method chaining.'''
        ...
    
    def type(self, value : str) -> aspose.svg.builder.SVGAElementBuilder:
        '''Sets the 'type' attribute of the SVG 'a' element, specifying the media type of the linked resource.
        
        :param value: The media type of the linked resource.
        :returns: The current instance of SVGAElementBuilder for method chaining.'''
        ...
    
    def referrer_policy(self, value : aspose.svg.builder.ReferrerPolicy) -> aspose.svg.builder.SVGAElementBuilder:
        '''Sets the 'referrerPolicy' attribute of the SVG 'a' element, specifying how much of the referrer to send along with requests.
        
        :param value: The referrer policy as defined in the ReferrerPolicy enum.
        :returns: The current instance of SVGAElementBuilder for method chaining.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGAnimateElementBuilder(ISVGElementBuilder):
    '''Builder class for constructing an SVG 'animate' element, which is used for creating animations within SVG graphics.
    It enables the building of content within the 'animate' element and provides methods to set various attributes specific to the 'animate' element in SVG.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGAnimateElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGAnimateElement) -> aspose.svg.SVGAnimateElement:
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGAnimateMotionElementBuilder(ISVGElementBuilder):
    '''Builder class for constructing an SVG 'animateMotion' element, which is used for creating motion animations within SVG graphics.
    It enables the building of content within the 'animateMotion' element and provides methods to set various attributes specific to the 'animateMotion' element in SVG.'''
    
    @overload
    def rotate(self, degrees : float) -> aspose.svg.builder.SVGAnimateMotionElementBuilder:
        '''Sets the 'rotate' attribute, defining the rotation of the animated element.
        
        :param degrees: The degrees of rotation.
        :returns: The current instance of SVGAnimateMotionElementBuilder for method chaining.'''
        ...
    
    @overload
    def rotate(self, value : aspose.svg.builder.Rotate) -> aspose.svg.builder.SVGAnimateMotionElementBuilder:
        '''Sets the 'rotate' attribute using a predefined rotation value.
        
        :param value: The predefined rotation value.
        :returns: The current instance of SVGAnimateMotionElementBuilder for method chaining.'''
        ...
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGAnimateMotionElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGAnimateMotionElement) -> aspose.svg.SVGAnimateMotionElement:
        ...
    
    def key_points(self, key_points : List[float]) -> aspose.svg.builder.SVGAnimateMotionElementBuilder:
        '''Sets the 'keyPoints' attribute, defining the points at which the animation occurs.
        
        :param key_points: An array of key points for the animation, each between 0 and 1.
        :returns: The current instance of SVGAnimateMotionElementBuilder for method chaining.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGAnimateTransformElementBuilder(ISVGElementBuilder):
    '''Builder class for constructing an SVG 'animateTransform' element, which is used for creating transformation animations within SVG graphics.
    It enables the building of content within the 'animateTransform' element and provides methods to set various attributes specific to the 'animateTransform' element in SVG.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGAnimateTransformElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGAnimateTransformElement) -> aspose.svg.SVGAnimateTransformElement:
        ...
    
    def type(self, type : aspose.svg.builder.TransformationType) -> aspose.svg.builder.SVGAnimateTransformElementBuilder:
        '''Sets the 'type' attribute of the SVG 'animateTransform' element, specifying the type of transformation.
        
        :param type: The type of transformation (e.g., translate, rotate, scale).
        :returns: The current instance of SVGAnimateTransformElementBuilder for method chaining.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGBuilderExtensions:
    '''Provides extension methods for building and configuring SVG (Scalable Vector Graphics) elements.
    This class contains a collection of static methods that extend various builder interfaces,
    allowing for fluent and convenient construction of SVG elements and their attributes.'''
    
    @staticmethod
    def format_svg_lengths(values : List[float]type : aspose.svg.builder.LengthType) -> str:
        '''Formats an array of double values into a string representation of SVG lengths.
        
        :param values: The array of double values representing lengths.
        :param type: The type of length unit to use (e.g., pixels).
        :returns: A formatted string of SVG lengths.'''
        ...
    
    ...

class SVGCircleElementBuilder(ISVGElementBuilder):
    '''Builder class for constructing an SVG 'circle' element, which is used to draw circles within SVG graphics.
    It enables the building of content within the 'circle' element and provides methods to set various attributes specific to the 'circle' element in SVG.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGCircleElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGCircleElement) -> aspose.svg.SVGCircleElement:
        ...
    
    def cx(self, value : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.SVGCircleElementBuilder:
        '''Sets the 'cx' attribute of the SVG 'circle' element, specifying the x-coordinate of the center of the circle.
        
        :param value: The x-coordinate of the circle's center.
        :param type: The unit of measurement for the x-coordinate (default is pixels).
        :returns: The current instance of SVGCircleElementBuilder for method chaining.'''
        ...
    
    def cy(self, value : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.SVGCircleElementBuilder:
        '''Sets the 'cy' attribute of the SVG 'circle' element, specifying the y-coordinate of the center of the circle.
        
        :param value: The y-coordinate of the circle's center.
        :param type: The unit of measurement for the y-coordinate (default is pixels).
        :returns: The current instance of SVGCircleElementBuilder for method chaining.'''
        ...
    
    def r(self, value : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.SVGCircleElementBuilder:
        '''Sets the 'r' attribute of the SVG 'circle' element, specifying the radius of the circle.
        
        :param value: The radius of the circle.
        :param type: The unit of measurement for the radius (default is pixels).
        :returns: The current instance of SVGCircleElementBuilder for method chaining.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGClipPathElementBuilder(ISVGElementBuilder):
    '''Builder class for constructing an SVG 'clipPath' element, which is used to define a clipping path.
    It enables the building of content within the 'clipPath' element and provides methods to set various attributes specific to the 'clipPath' element in SVG.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGClipPathElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGClipPathElement) -> aspose.svg.SVGClipPathElement:
        ...
    
    def clip_path_units(self, units : aspose.svg.builder.CoordinateUnits) -> aspose.svg.builder.SVGClipPathElementBuilder:
        '''Sets the 'clipPathUnits' attribute of the SVG 'clipPath' element, specifying the coordinate system for the clipping path.
        
        :param units: The coordinate system units.
        :returns: The current instance of SVGClipPathElementBuilder for method chaining.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGDefsElementBuilder(ISVGElementBuilder):
    '''Builder class for constructing an SVG 'defs' element, which is used to define reusable elements.
    It enables the building of content within the 'defs' element and provides methods to set various attributes specific to the 'defs' element in SVG.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGDefsElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGDefsElement) -> aspose.svg.SVGDefsElement:
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGDescElementBuilder(ISVGElementBuilder):
    '''Builder class for constructing an SVG 'desc' element, which is used to provide a description for SVG container elements.
    It enables the building of content within the 'desc' element and provides methods to set various attributes specific to the 'desc' element in SVG.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGDescElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGDescElement) -> aspose.svg.SVGDescElement:
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGEllipseElementBuilder(ISVGElementBuilder):
    '''Builder class for constructing an SVG 'ellipse' element, which is used to draw ellipses within SVG graphics.
    It enables the building of content within the 'ellipse' element and provides methods to set various attributes specific to the 'ellipse' element in SVG.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGEllipseElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGEllipseElement) -> aspose.svg.SVGEllipseElement:
        ...
    
    def cx(self, value : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.SVGEllipseElementBuilder:
        '''Sets the 'cx' attribute of the SVG 'ellipse' element, specifying the x-coordinate of the center of the ellipse.
        
        :param value: The x-coordinate of the ellipse's center.
        :param type: The unit of measurement for the x-coordinate (default is pixels).
        :returns: The current instance of SVGEllipseElementBuilder for method chaining.'''
        ...
    
    def cy(self, value : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.SVGEllipseElementBuilder:
        '''Sets the 'cy' attribute of the SVG 'ellipse' element, specifying the y-coordinate of the center of the ellipse.
        
        :param value: The y-coordinate of the ellipse's center.
        :param type: The unit of measurement for the y-coordinate (default is pixels).
        :returns: The current instance of SVGEllipseElementBuilder for method chaining.'''
        ...
    
    def rx(self, value : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.SVGEllipseElementBuilder:
        '''Sets the 'rx' attribute of the SVG 'ellipse' element, specifying the horizontal radius of the ellipse.
        
        :param value: The horizontal radius of the ellipse.
        :param type: The unit of measurement for the horizontal radius (default is pixels).
        :returns: The current instance of SVGEllipseElementBuilder for method chaining.'''
        ...
    
    def ry(self, value : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.SVGEllipseElementBuilder:
        '''Sets the 'ry' attribute of the SVG 'ellipse' element, specifying the vertical radius of the ellipse.
        
        :param value: The vertical radius of the ellipse.
        :param type: The unit of measurement for the vertical radius (default is pixels).
        :returns: The current instance of SVGEllipseElementBuilder for method chaining.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGFEBlendElementBuilder(ISVGElementBuilder):
    '''Builder class for creating SVG 'feBlend' elements, used in SVG filters.'''
    
    @overload
    def in2(self, value : str) -> aspose.svg.builder.SVGFEBlendElementBuilder:
        '''Sets the 'in2' attribute of the feBlend element, specifying the second input for the blending operation.
        
        :param value: The identifier for the second input.
        :returns: The current builder instance.'''
        ...
    
    @overload
    def in2(self, input : aspose.svg.builder.FilterInput) -> aspose.svg.builder.SVGFEBlendElementBuilder:
        '''Sets the 'in2' attribute of the feBlend element, specifying the second input for the blending operation.
        
        :param input: The FilterInput enum value representing the second input.
        :returns: The current builder instance.'''
        ...
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.filters.SVGFEBlendElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.filters.SVGFEBlendElement) -> aspose.svg.filters.SVGFEBlendElement:
        ...
    
    def mode(self, mode : aspose.svg.builder.BlendMode) -> aspose.svg.builder.SVGFEBlendElementBuilder:
        '''Sets the 'mode' attribute of the feBlend element, specifying the blending mode to be used.
        
        :param mode: The BlendMode enum value representing the blending mode.
        :returns: The current builder instance.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGFEColorMatrixElementBuilder(ISVGElementBuilder):
    '''Builder class for creating SVG 'feColorMatrix' elements, used in SVG filters.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.filters.SVGFEColorMatrixElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.filters.SVGFEColorMatrixElement) -> aspose.svg.filters.SVGFEColorMatrixElement:
        ...
    
    def type_and_values(self, type : aspose.svg.builder.ColorMatrixOperation, values : List[float]) -> aspose.svg.builder.SVGFEColorMatrixElementBuilder:
        '''Sets the 'type' and 'values' attributes of the feColorMatrix element, specifying the color matrix operation and its parameters.
        
        :param type: The ColorMatrixOperation enum value representing the type of color matrix operation.
        :param values: The parameters for the color matrix operation.
        :returns: The current builder instance.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGFEComponentTransferElementBuilder(ISVGElementBuilder):
    '''Builder class for creating SVG 'feComponentTransfer' elements, used in SVG filters.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.filters.SVGFEComponentTransferElement:
        '''Builds the SVGFEComponentTransferElement with the configured component transfer functions.
        
        :param document: The document in which the element will be created.
        :returns: The constructed SVGFEComponentTransferElement.'''
        ...
    
    @overload
    def build(self, element : aspose.svg.filters.SVGFEComponentTransferElement) -> aspose.svg.filters.SVGFEComponentTransferElement:
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGFECompositeElementBuilder(ISVGElementBuilder):
    '''Builder class for creating SVG 'feComposite' elements, used in SVG filters.'''
    
    @overload
    def in2(self, value : str) -> aspose.svg.builder.SVGFECompositeElementBuilder:
        '''Sets the 'in2' attribute of the feComposite element.
        
        :param value: The value for the 'in2' attribute.
        :returns: The current builder instance.'''
        ...
    
    @overload
    def in2(self, input : aspose.svg.builder.FilterInput) -> aspose.svg.builder.SVGFECompositeElementBuilder:
        '''Sets the 'in2' attribute of the feComposite element using a FilterInput.
        
        :param input: The FilterInput object providing the value for 'in2'.
        :returns: The current builder instance.'''
        ...
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.filters.SVGFECompositeElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.filters.SVGFECompositeElement) -> aspose.svg.filters.SVGFECompositeElement:
        ...
    
    def operator(self, composit_operator : aspose.svg.builder.CompositeOperator) -> aspose.svg.builder.SVGFECompositeElementBuilder:
        '''Sets the 'operator' attribute of the feComposite element.
        
        :param composit_operator: The composite operator to be used.
        :returns: The current builder instance.'''
        ...
    
    def k1(self, value : float) -> aspose.svg.builder.SVGFECompositeElementBuilder:
        '''Sets the 'k1' attribute of the feComposite element.
        
        :param value: The value for the 'k1' attribute.
        :returns: The current builder instance.'''
        ...
    
    def k2(self, value : float) -> aspose.svg.builder.SVGFECompositeElementBuilder:
        '''Sets the 'k2' attribute of the feComposite element.
        
        :param value: The value for the 'k2' attribute.
        :returns: The current builder instance.'''
        ...
    
    def k3(self, value : float) -> aspose.svg.builder.SVGFECompositeElementBuilder:
        '''Sets the 'k3' attribute of the feComposite element.
        
        :param value: The value for the 'k3' attribute.
        :returns: The current builder instance.'''
        ...
    
    def k4(self, value : float) -> aspose.svg.builder.SVGFECompositeElementBuilder:
        '''Sets the 'k4' attribute of the feComposite element.
        
        :param value: The value for the 'k4' attribute.
        :returns: The current builder instance.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGFEConvolveMatrixElementBuilder(ISVGElementBuilder):
    '''Builder class for creating SVG 'feConvolveMatrix' elements, used in SVG filters for applying convolution matrix effects.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.filters.SVGFEConvolveMatrixElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.filters.SVGFEConvolveMatrixElement) -> aspose.svg.filters.SVGFEConvolveMatrixElement:
        ...
    
    def order(self, order_x : int, order_y : Optional[int]) -> aspose.svg.builder.SVGFEConvolveMatrixElementBuilder:
        ...
    
    def kernel_matrix(self, kernel_matrix : List[float]) -> aspose.svg.builder.SVGFEConvolveMatrixElementBuilder:
        '''Sets the 'kernelMatrix' attribute of the feConvolveMatrix element.
        
        :param kernel_matrix: The convolution matrix values.
        :returns: The current builder instance.'''
        ...
    
    def divisor(self, divisor : float) -> aspose.svg.builder.SVGFEConvolveMatrixElementBuilder:
        '''Sets the 'divisor' attribute of the feConvolveMatrix element.
        
        :param divisor: The divisor applied to the matrix.
        :returns: The current builder instance.'''
        ...
    
    def bias(self, bias : float) -> aspose.svg.builder.SVGFEConvolveMatrixElementBuilder:
        '''Sets the 'bias' attribute of the feConvolveMatrix element.
        
        :param bias: The bias to be added to the result of the convolution.
        :returns: The current builder instance.'''
        ...
    
    def target_x(self, target_x : int) -> aspose.svg.builder.SVGFEConvolveMatrixElementBuilder:
        '''Sets the 'targetX' attribute of the feConvolveMatrix element.
        
        :param target_x: The X coordinate of the target pixel in the kernel matrix.
        :returns: The current builder instance.'''
        ...
    
    def target_y(self, target_y : int) -> aspose.svg.builder.SVGFEConvolveMatrixElementBuilder:
        '''Sets the 'targetY' attribute of the feConvolveMatrix element.
        
        :param target_y: The Y coordinate of the target pixel in the kernel matrix.
        :returns: The current builder instance.'''
        ...
    
    def edge_mode(self, mode : aspose.svg.builder.EdgeMode) -> aspose.svg.builder.SVGFEConvolveMatrixElementBuilder:
        '''Sets the 'edgeMode' attribute of the feConvolveMatrix element.
        
        :param mode: The edge mode for the convolution (e.g., duplicate, wrap, none).
        :returns: The current builder instance.'''
        ...
    
    def kernel_unit_length(self, dx : float, dy : Optional[float]) -> aspose.svg.builder.SVGFEConvolveMatrixElementBuilder:
        ...
    
    def preserve_alpha(self, value : bool) -> aspose.svg.builder.SVGFEConvolveMatrixElementBuilder:
        '''Sets the 'preserveAlpha' attribute of the feConvolveMatrix element.
        
        :param value: Indicates whether to preserve the alpha channel of the input graphic.
        :returns: The current builder instance.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGFEDiffuseLightingElementBuilder(ISVGElementBuilder):
    '''Builder class for creating SVG 'feDiffuseLighting' elements, used in SVG filters to apply diffuse lighting effects.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.filters.SVGFEDiffuseLightingElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.filters.SVGFEDiffuseLightingElement) -> aspose.svg.filters.SVGFEDiffuseLightingElement:
        ...
    
    def surface_scale(self, value : float) -> aspose.svg.builder.SVGFEDiffuseLightingElementBuilder:
        '''Sets the 'surfaceScale' attribute of the feDiffuseLighting element.
        
        :param value: The height of the surface for the lighting calculation.
        :returns: The current builder instance.'''
        ...
    
    def diffuse_constant(self, value : float) -> aspose.svg.builder.SVGFEDiffuseLightingElementBuilder:
        '''Sets the 'diffuseConstant' attribute of the feDiffuseLighting element.
        
        :param value: The constant used to determine the lighting contribution.
        :returns: The current builder instance.'''
        ...
    
    def kernel_unit_length(self, dx : float, dy : Optional[float]) -> aspose.svg.builder.SVGFEDiffuseLightingElementBuilder:
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGFEDisplacementMapElementBuilder(ISVGElementBuilder):
    '''Builder class for creating SVG 'feDisplacementMap' elements, used in SVG filters to apply displacement mapping effects.'''
    
    @overload
    def in2(self, value : str) -> aspose.svg.builder.SVGFEDisplacementMapElementBuilder:
        '''Sets the 'in2' attribute of the feDisplacementMap element.
        
        :param value: The identifier of the second input filter primitive.
        :returns: The current builder instance.'''
        ...
    
    @overload
    def in2(self, input : aspose.svg.builder.FilterInput) -> aspose.svg.builder.SVGFEDisplacementMapElementBuilder:
        '''Sets the 'in2' attribute of the feDisplacementMap element using a FilterInput.
        
        :param input: The second input filter primitive.
        :returns: The current builder instance.'''
        ...
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.filters.SVGFEDisplacementMapElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.filters.SVGFEDisplacementMapElement) -> aspose.svg.filters.SVGFEDisplacementMapElement:
        ...
    
    def scale(self, value : float) -> aspose.svg.builder.SVGFEDisplacementMapElementBuilder:
        '''Sets the 'scale' attribute of the feDisplacementMap element.
        
        :param value: The scale factor for the displacement.
        :returns: The current builder instance.'''
        ...
    
    def x_channel_selector(self, value : aspose.svg.builder.ChannelSelector) -> aspose.svg.builder.SVGFEDisplacementMapElementBuilder:
        '''Sets the 'xChannelSelector' attribute of the feDisplacementMap element.
        
        :param value: The channel to use for displacement along the x-axis.
        :returns: The current builder instance.'''
        ...
    
    def y_channel_selector(self, value : aspose.svg.builder.ChannelSelector) -> aspose.svg.builder.SVGFEDisplacementMapElementBuilder:
        '''Sets the 'yChannelSelector' attribute of the feDisplacementMap element.
        
        :param value: The channel to use for displacement along the y-axis.
        :returns: The current builder instance.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGFEDistantLightElementBuilder(ISVGElementBuilder):
    '''Builder class for creating SVG 'feDistantLight' elements, used within SVG filters to define a distant light source.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.filters.SVGFEDistantLightElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.filters.SVGFEDistantLightElement) -> aspose.svg.filters.SVGFEDistantLightElement:
        ...
    
    def azimuth(self, value : float) -> aspose.svg.builder.SVGFEDistantLightElementBuilder:
        '''Sets the 'azimuth' attribute of the feDistantLight element.
        
        :param value: The azimuth angle for the light source in degrees.
        :returns: The current builder instance.'''
        ...
    
    def elevation(self, value : float) -> aspose.svg.builder.SVGFEDistantLightElementBuilder:
        '''Sets the 'elevation' attribute of the feDistantLight element.
        
        :param value: The elevation angle for the light source in degrees.
        :returns: The current builder instance.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGFEDropShadowElementBuilder(ISVGElementBuilder):
    '''Builder class for creating SVG 'feDropShadow' elements, used within SVG filters to apply a drop shadow effect.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.filters.SVGFEDropShadowElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.filters.SVGFEDropShadowElement) -> aspose.svg.filters.SVGFEDropShadowElement:
        ...
    
    def std_deviation(self, dx : float, dy : Optional[float]) -> aspose.svg.builder.SVGFEDropShadowElementBuilder:
        ...
    
    def dx(self, value : float) -> aspose.svg.builder.SVGFEDropShadowElementBuilder:
        '''Sets the horizontal offset ('dx') for the drop shadow.
        
        :param value: The horizontal offset value.
        :returns: The current builder instance.'''
        ...
    
    def dy(self, value : float) -> aspose.svg.builder.SVGFEDropShadowElementBuilder:
        '''Sets the vertical offset ('dy') for the drop shadow.
        
        :param value: The vertical offset value.
        :returns: The current builder instance.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGFEFloodElementBuilder(ISVGElementBuilder):
    '''Builder class for creating SVG 'feFlood' elements, used within SVG filters to create a flood of color.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.filters.SVGFEFloodElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.filters.SVGFEFloodElement) -> aspose.svg.filters.SVGFEFloodElement:
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGFEFuncAElementBuilder(ISVGElementBuilder):
    '''Builder class for creating SVG 'feFuncA' elements, which define the alpha component transfer function.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.filters.SVGFEFuncAElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.filters.SVGFEFuncAElement) -> aspose.svg.filters.SVGFEFuncAElement:
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGFEFuncBElementBuilder(ISVGElementBuilder):
    '''Builder class for creating SVG 'feFuncB' elements, which define the alpha component transfer function.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.filters.SVGFEFuncBElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.filters.SVGFEFuncBElement) -> aspose.svg.filters.SVGFEFuncBElement:
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGFEFuncGElementBuilder(ISVGElementBuilder):
    '''Builder class for creating SVG 'feFuncG' elements, which define the alpha component transfer function.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.filters.SVGFEFuncGElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.filters.SVGFEFuncGElement) -> aspose.svg.filters.SVGFEFuncGElement:
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGFEFuncRElementBuilder(ISVGElementBuilder):
    '''Builder class for creating SVG 'feFuncR' elements, which define the alpha component transfer function.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.filters.SVGFEFuncRElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.filters.SVGFEFuncRElement) -> aspose.svg.filters.SVGFEFuncRElement:
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGFEGaussianBlurElementBuilder(ISVGElementBuilder):
    '''Builder class for creating SVG 'feGaussianBlur' elements, which apply a Gaussian blur filter effect.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.filters.SVGFEGaussianBlurElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.filters.SVGFEGaussianBlurElement) -> aspose.svg.filters.SVGFEGaussianBlurElement:
        ...
    
    def std_deviation(self, dx : float, dy : Optional[float]) -> aspose.svg.builder.SVGFEGaussianBlurElementBuilder:
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGFEImageElementBuilder(ISVGElementBuilder):
    '''Builder class for creating SVG 'feImage' elements, which define an image to be used by other filter primitives.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.filters.SVGFEImageElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.filters.SVGFEImageElement) -> aspose.svg.filters.SVGFEImageElement:
        ...
    
    def href(self, value : str) -> aspose.svg.builder.SVGFEImageElementBuilder:
        '''Sets the 'href' attribute of the feImage element, defining the URL of the image to be used.
        
        :param value: The URL of the image.
        :returns: The current builder instance.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGFEMergeElementBuilder(ISVGElementBuilder):
    '''Builder class for creating SVG 'feMerge' elements, which are used to composite together images or parts of images.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.filters.SVGFEMergeElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.filters.SVGFEMergeElement) -> aspose.svg.filters.SVGFEMergeElement:
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGFEMergeNodeElementBuilder(ISVGElementBuilder):
    '''Builder class for creating SVG 'feMergeNode' elements, which define the input layers to be used within an 'feMerge' filter.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.filters.SVGFEMergeNodeElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.filters.SVGFEMergeNodeElement) -> aspose.svg.filters.SVGFEMergeNodeElement:
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGFEMorphologyElementBuilder(ISVGElementBuilder):
    '''Builder class for creating SVG 'feMorphology' elements, which are used to apply morphological operations like dilation or erosion on an input image.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.filters.SVGFEMorphologyElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.filters.SVGFEMorphologyElement) -> aspose.svg.filters.SVGFEMorphologyElement:
        ...
    
    def operator(self, op : aspose.svg.builder.MorphologyOperator) -> aspose.svg.builder.SVGFEMorphologyElementBuilder:
        '''Sets the 'operator' attribute of the feMorphology element, specifying the type of morphological operation.
        
        :param op: The MorphologyOperator specifying the operation type (e.g., 'dilate' or 'erode').
        :returns: The current builder instance.'''
        ...
    
    def radius(self, rx : float, ry : Optional[float]) -> aspose.svg.builder.SVGFEMorphologyElementBuilder:
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGFEOffsetElementBuilder(ISVGElementBuilder):
    '''Builder class for creating SVG 'feOffset' elements, which are used to apply an offset effect to an input image.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.filters.SVGFEOffsetElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.filters.SVGFEOffsetElement) -> aspose.svg.filters.SVGFEOffsetElement:
        ...
    
    def dx(self, value : float) -> aspose.svg.builder.SVGFEOffsetElementBuilder:
        '''Sets the 'dx' attribute of the feOffset element, specifying the horizontal offset.
        
        :param value: The horizontal offset value.
        :returns: The current builder instance.'''
        ...
    
    def dy(self, value : float) -> aspose.svg.builder.SVGFEOffsetElementBuilder:
        '''Sets the 'dy' attribute of the feOffset element, specifying the vertical offset.
        
        :param value: The vertical offset value.
        :returns: The current builder instance.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGFEPointLightElementBuilder(ISVGElementBuilder):
    '''Builder class for creating SVG 'fePointLight' elements, which define a point light source for use with lighting filter primitives.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.filters.SVGFEPointLightElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.filters.SVGFEPointLightElement) -> aspose.svg.filters.SVGFEPointLightElement:
        ...
    
    def x(self, value : float) -> aspose.svg.builder.SVGFEPointLightElementBuilder:
        '''Sets the 'x' attribute of the fePointLight element, specifying the x-coordinate of the light source.
        
        :param value: The x-coordinate value.
        :returns: The current builder instance.'''
        ...
    
    def y(self, value : float) -> aspose.svg.builder.SVGFEPointLightElementBuilder:
        '''Sets the 'y' attribute of the fePointLight element, specifying the y-coordinate of the light source.
        
        :param value: The y-coordinate value.
        :returns: The current builder instance.'''
        ...
    
    def z(self, value : float) -> aspose.svg.builder.SVGFEPointLightElementBuilder:
        '''Sets the 'z' attribute of the fePointLight element, specifying the z-coordinate of the light source.
        
        :param value: The z-coordinate value.
        :returns: The current builder instance.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGFESpecularLightingElementBuilder(ISVGElementBuilder):
    '''Builder class for creating SVG 'feSpecularLighting' elements, which apply specular lighting effects to an image.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.filters.SVGFESpecularLightingElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.filters.SVGFESpecularLightingElement) -> aspose.svg.filters.SVGFESpecularLightingElement:
        ...
    
    def surface_scale(self, value : float) -> aspose.svg.builder.SVGFESpecularLightingElementBuilder:
        '''Sets the 'surfaceScale' attribute of the feSpecularLighting element, defining the height of the surface for the lighting calculation.
        
        :param value: The surface scale value.
        :returns: The current builder instance.'''
        ...
    
    def specular_constant(self, specular_constant : float) -> aspose.svg.builder.SVGFESpecularLightingElementBuilder:
        '''Sets the 'specularConstant' attribute, representing the specular reflection constant.
        
        :param specular_constant: The specular constant value, must be non-negative.
        :returns: The current builder instance.'''
        ...
    
    def specular_exponent(self, specular_exponent : float) -> aspose.svg.builder.SVGFESpecularLightingElementBuilder:
        '''Sets the 'specularExponent' attribute, controlling the focus of the specular highlight.
        
        :param specular_exponent: The specular exponent value, must be in the range 1.0 to 128.0.
        :returns: The current builder instance.'''
        ...
    
    def kernel_unit_length(self, dx : float, dy : Optional[float]) -> aspose.svg.builder.SVGFESpecularLightingElementBuilder:
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGFESpotLightElementBuilder(ISVGElementBuilder):
    '''Builder class for creating SVG 'feSpotLight' elements, which define a light source that emits light in a specific direction, like a spotlight.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.filters.SVGFESpotLightElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.filters.SVGFESpotLightElement) -> aspose.svg.filters.SVGFESpotLightElement:
        ...
    
    def x(self, value : float) -> aspose.svg.builder.SVGFESpotLightElementBuilder:
        '''Sets the 'x' attribute of the feSpotLight element, representing the x-coordinate of the light source.
        
        :param value: The x-coordinate value.
        :returns: The current builder instance.'''
        ...
    
    def y(self, value : float) -> aspose.svg.builder.SVGFESpotLightElementBuilder:
        '''Sets the 'y' attribute, representing the y-coordinate of the light source.
        
        :param value: The y-coordinate value.
        :returns: The current builder instance.'''
        ...
    
    def z(self, value : float) -> aspose.svg.builder.SVGFESpotLightElementBuilder:
        '''Sets the 'z' attribute, representing the z-coordinate of the light source.
        
        :param value: The z-coordinate value.
        :returns: The current builder instance.'''
        ...
    
    def points_at_x(self, value : float) -> aspose.svg.builder.SVGFESpotLightElementBuilder:
        '''Sets the 'pointsAtX' attribute, indicating the x-coordinate towards which the light is pointing.
        
        :param value: The pointsAtX value.
        :returns: The current builder instance.'''
        ...
    
    def points_at_y(self, value : float) -> aspose.svg.builder.SVGFESpotLightElementBuilder:
        '''Sets the 'pointsAtY' attribute, indicating the y-coordinate towards which the light is pointing.
        
        :param value: The pointsAtY value.
        :returns: The current builder instance.'''
        ...
    
    def points_at_z(self, value : float) -> aspose.svg.builder.SVGFESpotLightElementBuilder:
        '''Sets the 'pointsAtZ' attribute, indicating the z-coordinate towards which the light is pointing.
        
        :param value: The pointsAtZ value.
        :returns: The current builder instance.'''
        ...
    
    def specular_exponent(self, value : float) -> aspose.svg.builder.SVGFESpotLightElementBuilder:
        '''Sets the 'specularExponent' attribute, controlling the focus of the specular highlight.
        
        :param value: The specular exponent value.
        :returns: The current builder instance.'''
        ...
    
    def limiting_cone_angle(self, value : float) -> aspose.svg.builder.SVGFESpotLightElementBuilder:
        '''Sets the 'limitingConeAngle' attribute, defining the limiting cone of the spotlight.
        
        :param value: The limiting cone angle value.
        :returns: The current builder instance.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGFETileElementBuilder(ISVGElementBuilder):
    '''Builder class for creating SVG 'feTile' elements, which replicate and tile the input image to fill the filter primitive subregion.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.filters.SVGFETileElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.filters.SVGFETileElement) -> aspose.svg.filters.SVGFETileElement:
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGFETurbulenceElementBuilder(ISVGElementBuilder):
    '''Builder class for creating SVG 'feTurbulence' elements, which create an image using the Perlin turbulence function.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.filters.SVGFETurbulenceElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.filters.SVGFETurbulenceElement) -> aspose.svg.filters.SVGFETurbulenceElement:
        ...
    
    def base_frequency(self, base_frequency_x : float, base_frequency_y : Optional[float]) -> aspose.svg.builder.SVGFETurbulenceElementBuilder:
        ...
    
    def num_octaves(self, num_octaves : int) -> aspose.svg.builder.SVGFETurbulenceElementBuilder:
        '''Sets the number of octaves for the turbulence function.
        
        :param num_octaves: The number of octaves.
        :returns: The current builder instance.'''
        ...
    
    def seed(self, seed : float) -> aspose.svg.builder.SVGFETurbulenceElementBuilder:
        '''Sets the seed for the random number generator used by the turbulence function.
        
        :param seed: The seed value.
        :returns: The current builder instance.'''
        ...
    
    def stitch_tiles(self, stitch_tiles : aspose.svg.builder.StitchTiles) -> aspose.svg.builder.SVGFETurbulenceElementBuilder:
        '''Sets the stitch tiles option for the turbulence function.
        
        :param stitch_tiles: The stitch tiles setting.
        :returns: The current builder instance.'''
        ...
    
    def type(self, type : aspose.svg.builder.TurbulenceType) -> aspose.svg.builder.SVGFETurbulenceElementBuilder:
        '''Sets the type of turbulence (fractal noise or turbulence).
        
        :param type: The type of turbulence.
        :returns: The current builder instance.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGFilterElementBuilder(ISVGElementBuilder):
    '''Builder class for creating SVG 'filter' elements, which define filter effects that can be applied to SVG graphics.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGFilterElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGFilterElement) -> aspose.svg.SVGFilterElement:
        ...
    
    def filter_units(self, units : aspose.svg.builder.CoordinateUnits) -> aspose.svg.builder.SVGFilterElementBuilder:
        '''Sets the coordinate system for the filter's x, y, width, and height attributes.
        
        :param units: The coordinate units (userSpaceOnUse or objectBoundingBox).
        :returns: The current builder instance.'''
        ...
    
    def primitive_units(self, units : aspose.svg.builder.CoordinateUnits) -> aspose.svg.builder.SVGFilterElementBuilder:
        '''Sets the coordinate system for the filter's primitive sub-elements.
        
        :param units: The coordinate units for the filter primitives (userSpaceOnUse or objectBoundingBox).
        :returns: The current builder instance.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGForeignObjectElementBuilder(ISVGElementBuilder):
    '''Builder class for constructing an SVG 'foreignObject' element, which allows for inclusion of external content in an SVG document.
    This element can contain various types of content, such as HTML and XHTML, enabling more complex graphical representations within SVG.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGForeignObjectElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGForeignObjectElement) -> aspose.svg.SVGForeignObjectElement:
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGGElementBuilder(ISVGElementBuilder):
    '''Builder class for constructing an SVG 'g' (group) element. The 'g' element is used to group SVG shapes together.
    Grouping elements allows for easier manipulation and styling of multiple elements as a single unit within SVG graphics.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGGElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGGElement) -> aspose.svg.SVGGElement:
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGImageElementBuilder(ISVGElementBuilder):
    '''Builder class for constructing an SVG 'image' element. This element is used to embed images within SVG graphics.
    It provides methods to set various attributes specific to the 'image' element and to add additional configurations like clip paths, masks, styles, and scripts.'''
    
    @overload
    def href_base_64_from_file(self, image_path : str) -> aspose.svg.builder.SVGImageElementBuilder:
        '''Sets the 'href' attribute of the SVG 'image' element using a base64 encoded image file.
        
        :param image_path: The file path of the image.
        :returns: The current instance of SVGImageElementBuilder for method chaining.'''
        ...
    
    @overload
    def href_base_64_from_file(self, file_path : str, mime_type : str) -> aspose.svg.builder.SVGImageElementBuilder:
        '''Sets the 'href' attribute of the SVG 'image' element using a base64 encoded image file with a specified MIME type.
        
        :param file_path: The file path of the image.
        :param mime_type: The MIME type of the image.
        :returns: The current instance of SVGImageElementBuilder for method chaining.'''
        ...
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGImageElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGImageElement) -> aspose.svg.SVGImageElement:
        ...
    
    def href(self, value : str) -> aspose.svg.builder.SVGImageElementBuilder:
        '''Sets the 'href' attribute of the SVG 'image' element, specifying the URL of the image to be embedded.
        
        :param value: The URL of the image.
        :returns: The current instance of SVGImageElementBuilder for method chaining.'''
        ...
    
    def href_base_64_from_bytes(self, data : bytes, mime_type : str) -> aspose.svg.builder.SVGImageElementBuilder:
        '''Sets the 'href' attribute of the SVG 'image' element using base64 encoded bytes of an image.
        
        :param data: The byte array of the image data.
        :param mime_type: The MIME type of the image.
        :returns: The current instance of SVGImageElementBuilder for method chaining.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGLineElementBuilder(ISVGElementBuilder):
    '''Builder class for constructing an SVG 'line' element, which is used to draw straight lines within SVG graphics.
    This class enables the building of content within the 'line' element and provides methods to set various attributes specific to the 'line' element in SVG.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGLineElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGLineElement) -> aspose.svg.SVGLineElement:
        ...
    
    def x1(self, value : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.SVGLineElementBuilder:
        '''Sets the 'x1' attribute of the SVG 'line' element, specifying the x-coordinate of the start point of the line.
        
        :param value: The x-coordinate of the line's start point.
        :param type: The unit of measurement for the x-coordinate (default is pixels).
        :returns: The current instance of SVGLineElementBuilder for method chaining.'''
        ...
    
    def y1(self, value : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.SVGLineElementBuilder:
        '''Sets the 'y1' attribute of the SVG 'line' element, specifying the y-coordinate of the start point of the line.
        
        :param value: The y-coordinate of the line's start point.
        :param type: The unit of measurement for the y-coordinate (default is pixels).
        :returns: The current instance of SVGLineElementBuilder for method chaining.'''
        ...
    
    def x2(self, value : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.SVGLineElementBuilder:
        '''Sets the 'x2' attribute of the SVG 'line' element, specifying the x-coordinate of the end point of the line.
        
        :param value: The x-coordinate of the line's end point.
        :param type: The unit of measurement for the x-coordinate (default is pixels).
        :returns: The current instance of SVGLineElementBuilder for method chaining.'''
        ...
    
    def y2(self, value : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.SVGLineElementBuilder:
        '''Sets the 'y2' attribute of the SVG 'line' element, specifying the y-coordinate of the end point of the line.
        
        :param value: The y-coordinate of the line's end point.
        :param type: The unit of measurement for the y-coordinate (default is pixels).
        :returns: The current instance of SVGLineElementBuilder for method chaining.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGLinearGradientElementBuilder(ISVGElementBuilder):
    '''Builder class for constructing an SVG 'linearGradient' element, which is used to define a linear gradient within SVG graphics.
    It enables the building of content within the 'linearGradient' element and provides methods to set various attributes specific to the 'linearGradient' element in SVG.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGLinearGradientElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGLinearGradientElement) -> aspose.svg.SVGLinearGradientElement:
        ...
    
    def href(self, value : str) -> aspose.svg.builder.SVGLinearGradientElementBuilder:
        '''Sets the 'href' attribute of the SVG 'linearGradient' element, specifying a reference to another gradient.
        
        :param value: The reference URL of the gradient.
        :returns: The current instance of SVGLinearGradientElementBuilder for method chaining.'''
        ...
    
    def x1(self, value : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.SVGLinearGradientElementBuilder:
        '''Sets the 'x1' attribute of the SVG 'linearGradient' element, specifying the x-coordinate of the start point of the gradient.
        
        :param value: The x-coordinate of the gradient's start point.
        :param type: The unit of measurement for the x-coordinate (default is pixels).
        :returns: The current instance of SVGLinearGradientElementBuilder for method chaining.'''
        ...
    
    def y1(self, value : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.SVGLinearGradientElementBuilder:
        '''Sets the 'y1' attribute of the SVG 'linearGradient' element, specifying the y-coordinate of the start point of the gradient.
        
        :param value: The y-coordinate of the gradient's start point.
        :param type: The unit of measurement for the y-coordinate (default is pixels).
        :returns: The current instance of SVGLinearGradientElementBuilder for method chaining.'''
        ...
    
    def x2(self, value : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.SVGLinearGradientElementBuilder:
        '''Sets the 'x2' attribute of the SVG 'linearGradient' element, specifying the x-coordinate of the end point of the gradient.
        
        :param value: The x-coordinate of the gradient's end point.
        :param type: The unit of measurement for the x-coordinate (default is pixels).
        :returns: The current instance of SVGLinearGradientElementBuilder for method chaining.'''
        ...
    
    def y2(self, value : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.SVGLinearGradientElementBuilder:
        '''Sets the 'y2' attribute of the SVG 'linearGradient' element, specifying the y-coordinate of the end point of the gradient.
        
        :param value: The y-coordinate of the gradient's end point.
        :param type: The unit of measurement for the y-coordinate (default is pixels).
        :returns: The current instance of SVGLinearGradientElementBuilder for method chaining.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGMarkerElementBuilder(ISVGElementBuilder):
    '''Builder class for constructing an SVG 'marker' element, which is used to define graphical markers, such as arrowheads or bullets, that can be attached to the 'path', 'line', 'polyline', and 'polygon' elements.
    This class enables the building of content within the 'marker' element and provides methods to set various attributes specific to the 'marker' element in SVG.'''
    
    @overload
    def orient(self, auto : aspose.svg.builder.Orient) -> aspose.svg.builder.SVGMarkerElementBuilder:
        '''Sets the 'orient' attribute of the SVG 'marker' element, specifying the orientation of the marker.
        
        :param auto: The orientation setting, either 'auto' or a specific angle.
        :returns: The current instance of SVGMarkerElementBuilder for method chaining.'''
        ...
    
    @overload
    def orient(self, angle : float, unit : aspose.svg.builder.AngleUnits) -> aspose.svg.builder.SVGMarkerElementBuilder:
        '''Sets the 'orient' attribute of the SVG 'marker' element, specifying the orientation angle of the marker.
        
        :param angle: The angle of orientation.
        :param unit: The unit of measurement for the angle (default is degrees).
        :returns: The current instance of SVGMarkerElementBuilder for method chaining.'''
        ...
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGMarkerElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGMarkerElement) -> aspose.svg.SVGMarkerElement:
        ...
    
    def marker_width(self, value : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.SVGMarkerElementBuilder:
        '''Sets the 'markerWidth' attribute of the SVG 'marker' element, specifying the width of the marker's viewport.
        
        :param value: The width of the marker's viewport.
        :param type: The unit of measurement for the width (default is pixels).
        :returns: The current instance of SVGMarkerElementBuilder for method chaining.'''
        ...
    
    def marker_height(self, value : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.SVGMarkerElementBuilder:
        '''Sets the 'markerHeight' attribute of the SVG 'marker' element, specifying the height of the marker's viewport.
        
        :param value: The height of the marker's viewport.
        :param type: The unit of measurement for the height (default is pixels).
        :returns: The current instance of SVGMarkerElementBuilder for method chaining.'''
        ...
    
    def marker_units(self, units : aspose.svg.builder.MarkerUnits) -> aspose.svg.builder.SVGMarkerElementBuilder:
        '''Sets the 'markerUnits' attribute of the SVG 'marker' element, specifying the coordinate system for the marker's attributes.
        
        :param units: The marker units, either 'userSpaceOnUse' or 'strokeWidth'.
        :returns: The current instance of SVGMarkerElementBuilder for method chaining.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGMaskElementBuilder(ISVGElementBuilder):
    '''Builder class for constructing an SVG 'mask' element, which is used to define an alpha mask for compositing the current object into the background.
    This class enables the building of content within the 'mask' element and provides methods to set various attributes specific to the 'mask' element in SVG.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGMaskElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGMaskElement) -> aspose.svg.SVGMaskElement:
        ...
    
    def mask_units(self, units : aspose.svg.builder.CoordinateUnits) -> aspose.svg.builder.SVGMaskElementBuilder:
        '''Sets the 'maskUnits' attribute of the SVG 'mask' element, specifying the coordinate system for the mask's attributes.
        
        :param units: The coordinate units for the mask, either 'userSpaceOnUse' or 'objectBoundingBox'.
        :returns: The current instance of SVGMaskElementBuilder for method chaining.'''
        ...
    
    def mask_content_units(self, units : aspose.svg.builder.CoordinateUnits) -> aspose.svg.builder.SVGMaskElementBuilder:
        '''Sets the 'maskContentUnits' attribute of the SVG 'mask' element, specifying the coordinate system for the contents of the mask.
        
        :param units: The coordinate units for the mask's content, either 'userSpaceOnUse' or 'objectBoundingBox'.
        :returns: The current instance of SVGMaskElementBuilder for method chaining.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGMetadataElementBuilder(ISVGElementBuilder):
    '''Builder class for constructing an SVG 'metadata' element, which is used to add metadata to an SVG document.
    This class enables the addition of metadata content and provides methods to set various attributes specific to the 'metadata' element in SVG.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGMetadataElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGMetadataElement) -> aspose.svg.SVGMetadataElement:
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGPathElementBuilder(ISVGElementBuilder):
    '''Builder class for constructing an SVG 'path' element, which is used to define a path in an SVG document.
    This class provides methods to set various attributes specific to the 'path' element and to build its content.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGPathElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGPathElement) -> aspose.svg.SVGPathElement:
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGPatternElementBuilder(ISVGElementBuilder):
    '''Builder class for constructing an SVG 'pattern' element, which is used to define a pattern to be used for filling graphics elements within SVG.
    This class provides methods to set various attributes specific to the 'pattern' element and to build its content.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGPatternElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGPatternElement) -> aspose.svg.SVGPatternElement:
        ...
    
    def pattern_units(self, units : aspose.svg.builder.CoordinateUnits) -> aspose.svg.builder.SVGPatternElementBuilder:
        '''Sets the 'patternUnits' attribute of the SVG 'pattern' element, specifying the coordinate system for the pattern's x, y, width, and height.
        
        :param units: The coordinate units to be used (userSpaceOnUse or objectBoundingBox).
        :returns: The current instance of SVGPatternElementBuilder for method chaining.'''
        ...
    
    def pattern_content_units(self, units : aspose.svg.builder.CoordinateUnits) -> aspose.svg.builder.SVGPatternElementBuilder:
        '''Sets the 'patternContentUnits' attribute of the SVG 'pattern' element, specifying the coordinate system for the contents of the pattern.
        
        :param units: The coordinate units for the pattern's content (userSpaceOnUse or objectBoundingBox).
        :returns: The current instance of SVGPatternElementBuilder for method chaining.'''
        ...
    
    def href(self, value : str) -> aspose.svg.builder.SVGPatternElementBuilder:
        '''Sets the 'href' attribute of the SVG 'pattern' element, specifying a reference to another pattern which this pattern inherits attributes from.
        
        :param value: The reference to another pattern.
        :returns: The current instance of SVGPatternElementBuilder for method chaining.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGPolygonElementBuilder(ISVGElementBuilder):
    '''Builder class for constructing an SVG 'polygon' element.
    The 'polygon' element is used to create a graphic that contains at least three sides.
    This class provides methods to set various attributes and animate the polygon element.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGPolygonElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGPolygonElement) -> aspose.svg.SVGPolygonElement:
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGPolylineElementBuilder(ISVGElementBuilder):
    '''Builder class for constructing an SVG 'polyline' element.
    The 'polyline' element is used to create a series of straight lines connecting multiple points in SVG graphics.
    This class provides methods to set various attributes and animate the polyline element.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGPolylineElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGPolylineElement) -> aspose.svg.SVGPolylineElement:
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGRadialGradientElementBuilder(ISVGElementBuilder):
    '''Builder class for constructing an SVG 'radialGradient' element, which is used to define a radial gradient within SVG graphics.
    This class enables the building of content within the 'radialGradient' element and provides methods to set various attributes specific to the 'radialGradient' element in SVG.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGRadialGradientElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGRadialGradientElement) -> aspose.svg.SVGRadialGradientElement:
        ...
    
    def href(self, value : str) -> aspose.svg.builder.SVGRadialGradientElementBuilder:
        '''Sets the 'href' attribute of the SVG 'radialGradient' element, specifying a reference to another gradient.
        
        :param value: The reference URL of the gradient.
        :returns: The current instance of SVGRadialGradientElementBuilder for method chaining.'''
        ...
    
    def cx(self, value : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.SVGRadialGradientElementBuilder:
        '''Sets the 'cx' attribute of the SVG 'radialGradient' element, specifying the x-coordinate of the center of the gradient.
        
        :param value: The x-coordinate of the gradient's center.
        :param type: The unit of measurement for the x-coordinate (default is pixels).
        :returns: The current instance of SVGRadialGradientElementBuilder for method chaining.'''
        ...
    
    def cy(self, value : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.SVGRadialGradientElementBuilder:
        '''Sets the 'cy' attribute of the SVG 'radialGradient' element, specifying the y-coordinate of the center of the gradient.
        
        :param value: The y-coordinate of the gradient's center.
        :param type: The unit of measurement for the y-coordinate (default is pixels).
        :returns: The current instance of SVGRadialGradientElementBuilder for method chaining.'''
        ...
    
    def r(self, value : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.SVGRadialGradientElementBuilder:
        '''Sets the 'r' attribute of the SVG 'radialGradient' element, specifying the radius of the gradient.
        
        :param value: The radius of the gradient.
        :param type: The unit of measurement for the radius (default is pixels).
        :returns: The current instance of SVGRadialGradientElementBuilder for method chaining.'''
        ...
    
    def fx(self, value : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.SVGRadialGradientElementBuilder:
        '''Sets the 'fx' attribute of the SVG 'radialGradient' element, specifying the x-coordinate of the focal point of the gradient.
        
        :param value: The x-coordinate of the gradient's focal point.
        :param type: The unit of measurement for the x-coordinate (default is pixels).
        :returns: The current instance of SVGRadialGradientElementBuilder for method chaining.'''
        ...
    
    def fy(self, value : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.SVGRadialGradientElementBuilder:
        '''Sets the 'fy' attribute of the SVG 'radialGradient' element, specifying the y-coordinate of the focal point of the gradient.
        
        :param value: The y-coordinate of the gradient's focal point.
        :param type: The unit of measurement for the y-coordinate (default is pixels).
        :returns: The current instance of SVGRadialGradientElementBuilder for method chaining.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGRectElementBuilder(ISVGElementBuilder):
    '''Builder class for constructing an SVG 'rect' element.
    The 'rect' element is used to create rectangles within SVG graphics.
    This class provides methods to set various attributes specific to the 'rect' element, including corner radii and dimensions.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGRectElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGRectElement) -> aspose.svg.SVGRectElement:
        ...
    
    def rx(self, value : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.SVGRectElementBuilder:
        '''Sets the 'rx' attribute of the SVG 'rect' element, specifying the horizontal radius of the rectangle's rounded corners.
        
        :param value: The horizontal radius for the rectangle's rounded corners.
        :param type: The unit of measurement for the radius (default is pixels).
        :returns: The current instance of SVGRectElementBuilder for method chaining.'''
        ...
    
    def ry(self, value : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.SVGRectElementBuilder:
        '''Sets the 'ry' attribute of the SVG 'rect' element, specifying the vertical radius of the rectangle's rounded corners.
        
        :param value: The vertical radius for the rectangle's rounded corners.
        :param type: The unit of measurement for the radius (default is pixels).
        :returns: The current instance of SVGRectElementBuilder for method chaining.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGSVGElementBuilder(ISVGElementBuilder):
    '''Builder class for creating an SVGSVGElement, the root element of an SVG document.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGSVGElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGSVGElement) -> aspose.svg.SVGSVGElement:
        ...
    
    def version(self, value : float) -> aspose.svg.builder.SVGSVGElementBuilder:
        '''Sets the 'version' attribute of the SVG element.
        This attribute specifies the SVG specification version that the document conforms to.
        
        :param value: The SVG version number.
        :returns: The SVGSVGElementBuilder instance for chaining.'''
        ...
    
    def base_profile(self, value : float) -> aspose.svg.builder.SVGSVGElementBuilder:
        '''Sets the 'baseProfile' attribute of the SVG element.
        This attribute indicates which subset of the full SVG specification applies to the document.
        
        :param value: The base profile value.
        :returns: The SVGSVGElementBuilder instance for chaining.'''
        ...
    
    def content_script_type(self, value : str) -> aspose.svg.builder.SVGSVGElementBuilder:
        '''Sets the 'contentScriptType' attribute of the SVG element.
        This attribute specifies the default scripting language for the contents of the SVG document.
        
        :param value: The scripting language (e.g., "text/ecmascript").
        :returns: The SVGSVGElementBuilder instance for chaining.'''
        ...
    
    def content_style_type(self, value : str) -> aspose.svg.builder.SVGSVGElementBuilder:
        '''Sets the 'contentStyleType' attribute of the SVG element.
        This attribute specifies the default styling language for the contents of the SVG document.
        
        :param value: The styling language (e.g., "text/css").
        :returns: The SVGSVGElementBuilder instance for chaining.'''
        ...
    
    def zoom_and_pan(self, value : str) -> aspose.svg.builder.SVGSVGElementBuilder:
        '''Sets the 'zoomAndPan' attribute of the SVG element.
        This attribute controls whether the SVG content can be zoomed and panned.
        
        :param value: The zoom and pan behavior (e.g., "magnify").
        :returns: The SVGSVGElementBuilder instance for chaining.'''
        ...
    
    def with_xlink(self) -> aspose.svg.builder.SVGSVGElementBuilder:
        '''Adds the XLink namespace declaration to the SVG element.
        This is necessary for using XLink attributes such as 'xlink:href'.
        
        :returns: The SVGSVGElementBuilder instance for chaining.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGScriptElementBuilder(ISVGElementBuilder):
    '''Builder class for constructing an SVG 'script' element.
    The 'script' element is used to embed or reference executable scripts within SVG documents.
    This class provides methods to set various attributes specific to the 'script' element, such as type, source, and cross-origin settings.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGScriptElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGScriptElement) -> aspose.svg.SVGScriptElement:
        ...
    
    def type(self, value : str) -> aspose.svg.builder.SVGScriptElementBuilder:
        '''Sets the 'type' attribute of the SVG 'script' element, specifying the scripting language type (e.g., "text/javascript").
        
        :param value: The MIME type of the script.
        :returns: The current instance of SVGScriptElementBuilder for method chaining.'''
        ...
    
    def href(self, value : str) -> aspose.svg.builder.SVGScriptElementBuilder:
        '''Sets the 'href' attribute of the SVG 'script' element, specifying the URL of an external script file.
        
        :param value: The URL of the external script file.
        :returns: The current instance of SVGScriptElementBuilder for method chaining.'''
        ...
    
    def crossorigin(self, value : str) -> aspose.svg.builder.SVGScriptElementBuilder:
        '''Sets the 'crossorigin' attribute of the SVG 'script' element, specifying the CORS settings for the external script.
        
        :param value: The CORS setting (e.g., "anonymous", "use-credentials").
        :returns: The current instance of SVGScriptElementBuilder for method chaining.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGSetElementBuilder(ISVGElementBuilder):
    '''Builder class for constructing an SVG 'set' element.
    The 'set' element is used to define a simple animation where a single attribute value changes over a period of time.
    This class provides methods to set various attributes specific to the 'set' element, such as the target attribute and the value to set.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGSetElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGSetElement) -> aspose.svg.SVGSetElement:
        ...
    
    def to(self, value : str) -> aspose.svg.builder.SVGSetElementBuilder:
        '''Sets the 'to' attribute of the SVG 'set' element, specifying the final value of the attribute that will be changed during the animation.
        
        :param value: The final value of the attribute at the end of the animation.
        :returns: The current instance of SVGSetElementBuilder for method chaining.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGStopElementBuilder(ISVGElementBuilder):
    '''Builder class for constructing an SVG 'stop' element.
    The 'stop' element is used within a gradient definition (either linear or radial) to define the color stops.
    This class provides methods to set various attributes specific to the 'stop' element, such as the offset and color.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGStopElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGStopElement) -> aspose.svg.SVGStopElement:
        ...
    
    def offset(self, value : float, unit_type : aspose.svg.builder.StopUnitType) -> aspose.svg.builder.SVGStopElementBuilder:
        '''Sets the 'offset' attribute of the SVG 'stop' element, specifying the position of the color stop within the gradient.
        
        :param value: The offset value of the color stop (0 to 1 for numbers, 0% to 100% for percentages).
        :param unit_type: The unit type of the offset value (number or percentage).
        :returns: The current instance of SVGStopElementBuilder for method chaining.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGStyleElementBuilder(ISVGElementBuilder):
    '''A builder class for constructing an SVG 'style' element.
    This class facilitates the creation and configuration of an SVG style element with CSS rules.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGStyleElement:
        '''Builds the SVG style element with the accumulated CSS rules and adds it to the specified document.
        
        :param document: The document to which the style element will be added.
        :returns: The constructed SVGStyleElement.'''
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGStyleElement) -> aspose.svg.SVGStyleElement:
        ...
    
    def add_rule(self, selector : str, rules : str) -> aspose.svg.builder.SVGStyleElementBuilder:
        '''Adds a CSS rule to the style element.
        
        :param selector: The CSS selector for the rule.
        :param rules: The CSS rules as a string.
        :returns: The SVGStyleElementBuilder instance for chaining.'''
        ...
    
    def add_comment(self, comment : str) -> aspose.svg.builder.SVGStyleElementBuilder:
        '''Adds a comment to the style content.
        
        :param comment: The comment text to add.
        :returns: The SVGStyleElementBuilder instance for chaining.'''
        ...
    
    def type(self, content_type : str) -> aspose.svg.builder.SVGStyleElementBuilder:
        '''Sets the 'type' attribute of the SVG 'style' element.
        This attribute specifies the style sheet language of the element's contents.
        
        :param content_type: The MIME type of the style language (e.g., "text/css").
        :returns: The SVGStyleElementBuilder instance for chaining.'''
        ...
    
    def media(self, media_descriptors : str) -> aspose.svg.builder.SVGStyleElementBuilder:
        '''Sets the 'media' attribute of the SVG 'style' element.
        This attribute specifies the media for which the styles are intended, allowing the styles to be conditional on the media type.
        
        :param media_descriptors: The media descriptor string (e.g., "screen", "print").
        :returns: The SVGStyleElementBuilder instance for chaining.'''
        ...
    
    def title(self, advisory_title : str) -> aspose.svg.builder.SVGStyleElementBuilder:
        '''Sets the 'title' attribute of the SVG 'style' element.
        This attribute provides an advisory title for the style element, which can be useful for accessibility and tool-tip text.
        
        :param advisory_title: The advisory title text.
        :returns: The SVGStyleElementBuilder instance for chaining.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGSwitchElementBuilder(ISVGElementBuilder):
    '''Builder class for creating an SVGSwitchElement, which is used to conditionally display SVG content.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGSwitchElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGSwitchElement) -> aspose.svg.SVGSwitchElement:
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGSymbolElementBuilder(ISVGElementBuilder):
    '''Builder class for creating an SVGSymbolElement, which is used to define graphical template objects within SVG.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGSymbolElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGSymbolElement) -> aspose.svg.SVGSymbolElement:
        ...
    
    def ref_x(self, value : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.SVGSymbolElementBuilder:
        '''Sets the 'refX' attribute of the symbol element, defining the x-coordinate of the reference point of the symbol.
        
        :param value: The value for the 'refX' attribute.
        :param type: The type of length measurement (e.g., pixels).
        :returns: The SVGSymbolElementBuilder instance for chaining.'''
        ...
    
    def ref_y(self, value : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.SVGSymbolElementBuilder:
        '''Sets the 'refY' attribute of the symbol element, defining the y-coordinate of the reference point of the symbol.
        
        :param value: The value for the 'refY' attribute.
        :param type: The type of length measurement (e.g., pixels).
        :returns: The SVGSymbolElementBuilder instance for chaining.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGTSpanElementBuilder(ISVGElementBuilder):
    '''Builder class for creating an SVGTSpanElement, which is used to position and style text within an SVG document.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGTSpanElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGTSpanElement) -> aspose.svg.SVGTSpanElement:
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGTextElementBuilder(ISVGElementBuilder):
    '''Builder class for creating an SVGTextElement, which is used to define text in an SVG document.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGTextElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGTextElement) -> aspose.svg.SVGTextElement:
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGTextPathElementBuilder(ISVGElementBuilder):
    '''Builder class for creating SVG 'textPath' elements, which are used to align text to a path.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGTextPathElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGTextPathElement) -> aspose.svg.SVGTextPathElement:
        ...
    
    def text_length(self, value : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.SVGTextPathElementBuilder:
        '''Sets the 'textLength' attribute, specifying the length of the text.
        
        :param value: The length of the text.
        :param type: The type of length measurement (e.g., pixels).
        :returns: The current builder instance.'''
        ...
    
    def length_adjust(self, value : aspose.svg.builder.LengthAdjust) -> aspose.svg.builder.SVGTextPathElementBuilder:
        '''Sets the 'lengthAdjust' attribute, specifying how text length adjustments are made.
        
        :param value: The length adjust value.
        :returns: The current builder instance.'''
        ...
    
    def href(self, value : str) -> aspose.svg.builder.SVGTextPathElementBuilder:
        '''Sets the 'href' attribute, specifying a reference to a path element.
        
        :param value: The reference value.
        :returns: The current builder instance.'''
        ...
    
    def start_offset(self, value : float, type : aspose.svg.builder.LengthType) -> aspose.svg.builder.SVGTextPathElementBuilder:
        '''Sets the 'startOffset' attribute, specifying the starting position of the text on the path.
        
        :param value: The offset value.
        :param type: The type of length measurement (e.g., pixels).
        :returns: The current builder instance.'''
        ...
    
    def method(self, value : aspose.svg.builder.TextPathMethod) -> aspose.svg.builder.SVGTextPathElementBuilder:
        '''Sets the 'method' attribute, specifying the text layout method along the path.
        
        :param value: The text path method.
        :returns: The current builder instance.'''
        ...
    
    def spacing(self, value : aspose.svg.builder.TextPathSpacing) -> aspose.svg.builder.SVGTextPathElementBuilder:
        '''Sets the 'spacing' attribute, specifying the spacing strategy for text along the path.
        
        :param value: The text path spacing.
        :returns: The current builder instance.'''
        ...
    
    def side(self, value : aspose.svg.builder.HorizontalEdge) -> aspose.svg.builder.SVGTextPathElementBuilder:
        '''Sets the 'side' attribute, specifying which side of the path the text is placed on.
        
        :param value: The horizontal edge value.
        :returns: The current builder instance.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGTitleElementBuilder(ISVGElementBuilder):
    '''Builder class for creating an SVGTitleElement, which is used to define the title of an SVG document or a part thereof.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGTitleElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGTitleElement) -> aspose.svg.SVGTitleElement:
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGUseElementBuilder(ISVGElementBuilder):
    '''Builder class for creating an SVGUseElement, which is used to reuse an existing SVG element by referencing it.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGUseElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGUseElement) -> aspose.svg.SVGUseElement:
        ...
    
    def href(self, value : str) -> aspose.svg.builder.SVGUseElementBuilder:
        '''Sets the href attribute of the use element, specifying the URL of the element to be reused.
        
        :param value: The URL of the element to reference and reuse.
        :returns: The current SVGUseElementBuilder instance.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class SVGViewElementBuilder(ISVGElementBuilder):
    '''Builder class for creating an SVGViewElement, which defines a view within an SVG document.'''
    
    @overload
    def build(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGViewElement:
        ...
    
    @overload
    def build(self, element : aspose.svg.SVGViewElement) -> aspose.svg.SVGViewElement:
        ...
    
    def zoom_and_pan(self, zoom_and_pan : aspose.svg.builder.ZoomAndPan) -> aspose.svg.builder.SVGViewElementBuilder:
        '''Sets the zoomAndPan attribute of the view element, specifying the zoom and pan behavior.
        
        :param zoom_and_pan: The zoom and pan behavior.
        :returns: The current SVGViewElementBuilder instance.'''
        ...
    
    def view_target(self, view_targets : List[str]) -> aspose.svg.builder.SVGViewElementBuilder:
        '''Sets the viewTarget attribute of the view element, specifying the target elements for the view.
        
        :param view_targets: An array of identifiers for the target elements.
        :returns: The current SVGViewElementBuilder instance.'''
        ...
    
    def build_element(self, document : aspose.svg.dom.Document) -> aspose.svg.SVGElement:
        '''Builds and returns an SVGElement instance based on the current configuration of the builder.
        
        :param document: The SVG document to which the element will be added. This document provides the context necessary for creating the element.
        :returns: An SVGElement instance representing the constructed SVG element.'''
        ...
    
    def attribute(self, name : str, value : str):
        '''Sets or updates an attribute on an SVG element.
        
        :param name: The name of the attribute to set. This should be a valid SVG attribute name.
        :param value: The value to assign to the attribute. The value should be a string representation suitable for the specific SVG attribute.'''
        ...
    
    ...

class TimingValueBuilder:
    '''Builds a timing value used for specifying animation or transition timings.'''
    
    @staticmethod
    def format_time_span(time_span : TimeSpan) -> str:
        ...
    
    def add_offset(self, offset : TimeSpan) -> aspose.svg.builder.TimingValueBuilder:
        ...
    
    def add_syncbase(self, id : str, timing : str, offset : Optional[TimeSpan]) -> aspose.svg.builder.TimingValueBuilder:
        ...
    
    def add_event(self, id : str, event_name : str, offset : Optional[TimeSpan]) -> aspose.svg.builder.TimingValueBuilder:
        ...
    
    def add_repeat(self, id : str, repeat_count : int, offset : Optional[TimeSpan]) -> aspose.svg.builder.TimingValueBuilder:
        ...
    
    def add_access_key(self, key : char, offset : Optional[TimeSpan]) -> aspose.svg.builder.TimingValueBuilder:
        ...
    
    def add_wallclock(self, wallclock_time : DateTime) -> aspose.svg.builder.TimingValueBuilder:
        '''Adds a wallclock timing value.
        
        :param wallclock_time: The specific date and time for the timing.
        :returns: The current TimingValueBuilder instance for chaining.'''
        ...
    
    def add_indefinite(self) -> aspose.svg.builder.TimingValueBuilder:
        '''Adds an indefinite timing value.
        
        :returns: The current TimingValueBuilder instance for chaining.'''
        ...
    
    def build(self) -> str:
        '''Builds the final timing value string from the added components.
        
        :returns: The constructed timing value string.'''
        ...
    
    ...

class TransformBuilder:
    '''Builder class for creating SVG transform attribute strings.'''
    
    def matrix(self, a : float, b : float, c : float, d : float, e : float, f : float) -> aspose.svg.builder.TransformBuilder:
        '''Adds a matrix transform to the builder.
        
        :param a: The a component of the matrix.
        :param b: The b component of the matrix.
        :param c: The c component of the matrix.
        :param d: The d component of the matrix.
        :param e: The e component of the matrix.
        :param f: The f component of the matrix.
        :returns: The current TransformBuilder instance.'''
        ...
    
    def translate(self, tx : float, ty : float) -> aspose.svg.builder.TransformBuilder:
        '''Adds a translate transform to the builder.
        
        :param tx: The translation along the x-axis.
        :param ty: The translation along the y-axis. Defaults to 0.
        :returns: The current TransformBuilder instance.'''
        ...
    
    def scale(self, sx : float, sy : float) -> aspose.svg.builder.TransformBuilder:
        '''Adds a scale transform to the builder.
        
        :param sx: The scaling factor along the x-axis.
        :param sy: The scaling factor along the y-axis. Defaults to 0.
        :returns: The current TransformBuilder instance.'''
        ...
    
    def rotate(self, angle : float, cx : float, cy : float) -> aspose.svg.builder.TransformBuilder:
        '''Adds a rotate transform to the builder.
        
        :param angle: The rotation angle in degrees.
        :param cx: The x-coordinate of the rotation center. Defaults to 0.
        :param cy: The y-coordinate of the rotation center. Defaults to 0.
        :returns: The current TransformBuilder instance.'''
        ...
    
    def skew_x(self, angle : float) -> aspose.svg.builder.TransformBuilder:
        '''Adds a skewX transform to the builder.
        
        :param angle: The skew angle along the x-axis in degrees.
        :returns: The current TransformBuilder instance.'''
        ...
    
    def skew_y(self, angle : float) -> aspose.svg.builder.TransformBuilder:
        '''Adds a skewY transform to the builder.
        
        :param angle: The skew angle along the y-axis in degrees.
        :returns: The current TransformBuilder instance.'''
        ...
    
    def build(self) -> str:
        '''Builds the transform attribute string.
        
        :returns: The transform attribute string.'''
        ...
    
    ...

class AlignmentBaseline:
    '''Specifies the alignment baseline for text and other inline content in SVG.'''
    
    @classmethod
    @property
    def BASELINE(cls) -> AlignmentBaseline:
        '''Aligns the baseline of the box with the baseline of the parent box.'''
        ...
    
    @classmethod
    @property
    def TEXT_BOTTOM(cls) -> AlignmentBaseline:
        '''Aligns the bottom of the box with the bottom of the parent's content area.'''
        ...
    
    @classmethod
    @property
    def MIDDLE(cls) -> AlignmentBaseline:
        '''Aligns the middle of the box with the middle of the parent's content area.'''
        ...
    
    @classmethod
    @property
    def CENTRAL(cls) -> AlignmentBaseline:
        '''Aligns the central baseline of the box with the central baseline of the parent box.'''
        ...
    
    @classmethod
    @property
    def TEXT_TOP(cls) -> AlignmentBaseline:
        '''Aligns the top of the box with the top of the parent's content area.'''
        ...
    
    @classmethod
    @property
    def IDEOGRAPHIC(cls) -> AlignmentBaseline:
        '''Aligns the box's ideographic baseline with the parent's ideographic baseline.'''
        ...
    
    @classmethod
    @property
    def ALPHABETIC(cls) -> AlignmentBaseline:
        '''Aligns the box's alphabetic baseline with the parent's alphabetic baseline.'''
        ...
    
    @classmethod
    @property
    def MATHEMATICAL(cls) -> AlignmentBaseline:
        '''Aligns the box's mathematical baseline with the parent's mathematical baseline.'''
        ...
    
    ...

class AngleUnits:
    '''Specifies the units for angles used in defining the orientation of markers in SVG.'''
    
    @classmethod
    @property
    def DEGREES(cls) -> AngleUnits:
        '''Specifies the angle in degrees. One full circle is 360 degrees.'''
        ...
    
    @classmethod
    @property
    def GRADIANS(cls) -> AngleUnits:
        '''Specifies the angle in gradians. One full circle is 400 gradians.'''
        ...
    
    @classmethod
    @property
    def RADIANS(cls) -> AngleUnits:
        '''Specifies the angle in radians. One full circle is approximately 6.283 radians (2π radians).'''
        ...
    
    @classmethod
    @property
    def NONE(cls) -> AngleUnits:
        '''Indicates no specific angle unit. Used for default or context-based settings.'''
        ...
    
    ...

class AnimationFill:
    '''Specifies the behavior of the animation before and after its execution.'''
    
    @classmethod
    @property
    def FREEZE(cls) -> AnimationFill:
        '''The animation will apply the property values for the time the animation ended.'''
        ...
    
    @classmethod
    @property
    def REMOVE(cls) -> AnimationFill:
        '''The animation will not apply any values after it finishes executing.'''
        ...
    
    ...

class AspectRatioAlign:
    '''Specifies alignment types for the 'preserveAspectRatio' attribute in SVG.'''
    
    @classmethod
    @property
    def NONE(cls) -> AspectRatioAlign:
        '''Indicates that no uniform scaling is applied; the aspect ratio is not preserved.'''
        ...
    
    @classmethod
    @property
    def X_MIN_Y_MIN(cls) -> AspectRatioAlign:
        '''Aligns the minimum X and minimum Y of the viewBox with the smallest X and Y values of the viewport.'''
        ...
    
    @classmethod
    @property
    def X_MID_Y_MIN(cls) -> AspectRatioAlign:
        '''Aligns the midpoint X and minimum Y of the viewBox with the midpoint X and smallest Y value of the viewport.'''
        ...
    
    @classmethod
    @property
    def X_MAX_Y_MIN(cls) -> AspectRatioAlign:
        '''Aligns the maximum X and minimum Y of the viewBox with the largest X and smallest Y value of the viewport.'''
        ...
    
    @classmethod
    @property
    def X_MIN_Y_MID(cls) -> AspectRatioAlign:
        '''Aligns the minimum X and midpoint Y of the viewBox with the smallest X and midpoint Y value of the viewport.'''
        ...
    
    @classmethod
    @property
    def X_MID_Y_MID(cls) -> AspectRatioAlign:
        '''Aligns the midpoint X and Y of the viewBox with the midpoint X and Y of the viewport.'''
        ...
    
    @classmethod
    @property
    def X_MAX_Y_MID(cls) -> AspectRatioAlign:
        '''Aligns the maximum X and midpoint Y of the viewBox with the largest X and midpoint Y value of the viewport.'''
        ...
    
    @classmethod
    @property
    def X_MIN_Y_MAX(cls) -> AspectRatioAlign:
        '''Aligns the minimum X and maximum Y of the viewBox with the smallest X and largest Y value of the viewport.'''
        ...
    
    @classmethod
    @property
    def X_MID_Y_MAX(cls) -> AspectRatioAlign:
        '''Aligns the midpoint X and maximum Y of the viewBox with the midpoint X and largest Y value of the viewport.'''
        ...
    
    @classmethod
    @property
    def X_MAX_Y_MAX(cls) -> AspectRatioAlign:
        '''Aligns the maximum X and maximum Y of the viewBox with the largest X and Y values of the viewport.'''
        ...
    
    ...

class AspectRatioScaling:
    '''Specifies the scaling behavior for SVG elements when preserving their aspect ratio.'''
    
    @classmethod
    @property
    def MEET(cls) -> AspectRatioScaling:
        '''Scales the SVG element to fit within the viewport while preserving its aspect ratio.
        If the aspect ratio of the viewport does not match the element, extra space will be distributed evenly along the axis that has more space.'''
        ...
    
    @classmethod
    @property
    def SLICE(cls) -> AspectRatioScaling:
        '''Scales the SVG element to fill the viewport while preserving its aspect ratio.
        If the aspect ratio of the viewport does not match the element, the element will be clipped to fit.'''
        ...
    
    ...

class BaseLineShift:
    '''Specifies the vertical position of an element relative to its baseline in SVG.'''
    
    @classmethod
    @property
    def SUB(cls) -> BaseLineShift:
        '''Aligns the baseline of the element with the subscript baseline of the parent's text.'''
        ...
    
    @classmethod
    @property
    def SUPER(cls) -> BaseLineShift:
        '''Aligns the baseline of the element with the superscript baseline of the parent's text.'''
        ...
    
    @classmethod
    @property
    def TOP(cls) -> BaseLineShift:
        '''Aligns the top of the element with the top of the line box.'''
        ...
    
    @classmethod
    @property
    def CENTER(cls) -> BaseLineShift:
        '''Centers the element in the line box.'''
        ...
    
    @classmethod
    @property
    def BOTTOM(cls) -> BaseLineShift:
        '''Aligns the bottom of the element with the bottom of the line box.'''
        ...
    
    ...

class BlendMode:
    '''Specifies the blending modes available for combining images or elements in SVG.'''
    
    @classmethod
    @property
    def NORMAL(cls) -> BlendMode:
        '''Displays the source image as is, without any blending.'''
        ...
    
    @classmethod
    @property
    def MULTIPLY(cls) -> BlendMode:
        '''Multiplies the colors of the source image and the background. The result is a darker image.'''
        ...
    
    @classmethod
    @property
    def SCREEN(cls) -> BlendMode:
        '''Makes the dark parts of the source image lighter and the light parts unchanged.'''
        ...
    
    @classmethod
    @property
    def OVERLAY(cls) -> BlendMode:
        '''Combines Multiply and Screen blend modes to enhance contrast.'''
        ...
    
    @classmethod
    @property
    def DARKEN(cls) -> BlendMode:
        '''Darkens the background based on the source image's colors.'''
        ...
    
    @classmethod
    @property
    def LIGHTEN(cls) -> BlendMode:
        '''Lightens the background based on the source image's colors.'''
        ...
    
    @classmethod
    @property
    def COLOR_DODGE(cls) -> BlendMode:
        '''Brightens the background to reflect the source image.'''
        ...
    
    @classmethod
    @property
    def COLOR_BURN(cls) -> BlendMode:
        '''Darkens the background to reflect the source image.'''
        ...
    
    @classmethod
    @property
    def HARD_LIGHT(cls) -> BlendMode:
        '''Creates a hard light effect based on the source image's brightness.'''
        ...
    
    @classmethod
    @property
    def SOFT_LIGHT(cls) -> BlendMode:
        '''Creates a soft light effect based on the source image's brightness.'''
        ...
    
    @classmethod
    @property
    def DIFFERENCE(cls) -> BlendMode:
        '''Highlights the differences between the source image and the background.'''
        ...
    
    @classmethod
    @property
    def EXCLUSION(cls) -> BlendMode:
        '''Creates an effect similar to Difference, but with lower contrast.'''
        ...
    
    @classmethod
    @property
    def HUE(cls) -> BlendMode:
        '''Uses the hue of the source image combined with the luminance and saturation of the background.'''
        ...
    
    @classmethod
    @property
    def SATURATION(cls) -> BlendMode:
        '''Uses the saturation of the source image combined with the hue and luminance of the background.'''
        ...
    
    @classmethod
    @property
    def COLOR(cls) -> BlendMode:
        '''Uses the hue and saturation of the source image combined with the luminance of the background.'''
        ...
    
    @classmethod
    @property
    def LUMINOSITY(cls) -> BlendMode:
        '''Uses the luminance of the source image combined with the hue and saturation of the background.'''
        ...
    
    ...

class CalcMode:
    '''Specifies the calculation modes for interpolating values in SVG animations.'''
    
    @classmethod
    @property
    def DISCRETE(cls) -> CalcMode:
        '''The animation jumps from one value to the next without any interpolation.'''
        ...
    
    @classmethod
    @property
    def LINEAR(cls) -> CalcMode:
        '''The animation values are interpolated linearly across the animation duration.'''
        ...
    
    @classmethod
    @property
    def PACED(cls) -> CalcMode:
        '''The animation is paced so that the progress is even across the entire animation.'''
        ...
    
    @classmethod
    @property
    def SPLINE(cls) -> CalcMode:
        '''The animation uses cubic Bézier splines to interpolate values.'''
        ...
    
    ...

class ChannelSelector:
    '''Specifies the channel selectors for use in SVG filter operations.'''
    
    @classmethod
    @property
    def R(cls) -> ChannelSelector:
        '''Selects the Red channel of the image.'''
        ...
    
    @classmethod
    @property
    def G(cls) -> ChannelSelector:
        '''Selects the Green channel of the image.'''
        ...
    
    @classmethod
    @property
    def B(cls) -> ChannelSelector:
        '''Selects the Blue channel of the image.'''
        ...
    
    @classmethod
    @property
    def A(cls) -> ChannelSelector:
        '''Selects the Alpha (transparency) channel of the image.'''
        ...
    
    ...

class ClipRule:
    '''Defines the rule to determine how to clip paths in SVG graphics.'''
    
    @classmethod
    @property
    def NONZERO(cls) -> ClipRule:
        '''The nonzero winding rule for clipping paths.'''
        ...
    
    @classmethod
    @property
    def EVENODD(cls) -> ClipRule:
        '''The even-odd winding rule for clipping paths.'''
        ...
    
    ...

class ColorInterpolation:
    '''Specifies the color interpolation mode for SVG elements and filters.'''
    
    @classmethod
    @property
    def AUTO(cls) -> ColorInterpolation:
        '''Automatically determines the color interpolation mode.'''
        ...
    
    @classmethod
    @property
    def SRGB(cls) -> ColorInterpolation:
        '''Uses the standard RGB color space (sRGB) for color interpolation.'''
        ...
    
    @classmethod
    @property
    def LINEAR_RGB(cls) -> ColorInterpolation:
        '''Uses a linear RGB color space for color interpolation.'''
        ...
    
    ...

class ColorMatrixOperation:
    '''Specifies the type of operation to be applied in a color matrix filter.'''
    
    @classmethod
    @property
    def MATRIX(cls) -> ColorMatrixOperation:
        '''Applies a matrix transformation to the color data.'''
        ...
    
    @classmethod
    @property
    def SATURATE(cls) -> ColorMatrixOperation:
        '''Adjusts the saturation level of the image.'''
        ...
    
    @classmethod
    @property
    def HUE_ROTATE(cls) -> ColorMatrixOperation:
        '''Applies a hue rotation on the image.'''
        ...
    
    @classmethod
    @property
    def LUMINANCE_TO_ALPHA(cls) -> ColorMatrixOperation:
        '''Converts the colors of the image to grayscale based on their luminance.'''
        ...
    
    ...

class ColorRendering:
    '''Specifies the color rendering mode for an SVG element.'''
    
    @classmethod
    @property
    def AUTO(cls) -> ColorRendering:
        '''Allows the browser or viewer to choose the color rendering mode, balancing between speed and quality.'''
        ...
    
    @classmethod
    @property
    def OPTIMIZE_SPEED(cls) -> ColorRendering:
        '''Prioritizes rendering speed over color precision and visual quality.'''
        ...
    
    @classmethod
    @property
    def OPTIMIZE_QUALITY(cls) -> ColorRendering:
        '''Prioritizes color accuracy and visual quality over rendering speed.'''
        ...
    
    ...

class ComponentTransferType:
    '''Specifies the type of component transfer function to be applied in the FeComponentTransfer filter primitive of an SVG.'''
    
    @classmethod
    @property
    def IDENTITY(cls) -> ComponentTransferType:
        '''Represents no change in the input graphic. This is the default type.'''
        ...
    
    @classmethod
    @property
    def TABLE(cls) -> ComponentTransferType:
        '''Uses a lookup table to define the function within the filter.'''
        ...
    
    @classmethod
    @property
    def DISCRETE(cls) -> ComponentTransferType:
        '''Uses a set of discrete values to define the function in the filter.'''
        ...
    
    @classmethod
    @property
    def LINEAR(cls) -> ComponentTransferType:
        '''Defines a linear transformation of the component within the filter.'''
        ...
    
    @classmethod
    @property
    def GAMMA(cls) -> ComponentTransferType:
        '''Defines a gamma correction transformation in the filter.'''
        ...
    
    ...

class CompositeOperator:
    '''Specifies the type of compositing operation to be applied in SVG compositing operations.'''
    
    @classmethod
    @property
    def OVER(cls) -> CompositeOperator:
        '''Places the source graphic over the destination graphic.'''
        ...
    
    @classmethod
    @property
    def IN(cls) -> CompositeOperator:
        '''Displays the source graphic where it overlaps the destination graphic.'''
        ...
    
    @classmethod
    @property
    def OUT(cls) -> CompositeOperator:
        '''Displays the source graphic where it does not overlap the destination.'''
        ...
    
    @classmethod
    @property
    def ATOP(cls) -> CompositeOperator:
        '''Displays the source graphic atop the destination graphic.'''
        ...
    
    @classmethod
    @property
    def XOR(cls) -> CompositeOperator:
        '''Displays the source graphic where it does not overlap the destination and vice versa.'''
        ...
    
    @classmethod
    @property
    def ARITHMETIC(cls) -> CompositeOperator:
        '''Allows for a custom arithmetic compositing operation.'''
        ...
    
    ...

class CompositingOperator:
    '''Specifies the type of compositing operation to be applied in SVG masking operations.'''
    
    @classmethod
    @property
    def ADD(cls) -> CompositingOperator:
        '''Adds the color values of the source graphic to the destination graphic.'''
        ...
    
    @classmethod
    @property
    def SUBTRACT(cls) -> CompositingOperator:
        '''Subtracts the color values of the source graphic from the destination graphic.'''
        ...
    
    @classmethod
    @property
    def INTERSECT(cls) -> CompositingOperator:
        '''Displays only the areas where both the source and destination graphics overlap.'''
        ...
    
    @classmethod
    @property
    def EXCLUDE(cls) -> CompositingOperator:
        '''Excludes the overlapping areas of the source and destination graphics.'''
        ...
    
    ...

class CoordinateUnits:
    '''Specifies the coordinate system units for various SVG elements such as masks, paint servers, and filters.'''
    
    @classmethod
    @property
    def USER_SPACE_ON_USE(cls) -> CoordinateUnits:
        '''Uses the user coordinate system for the SVG element.'''
        ...
    
    @classmethod
    @property
    def OBJECT_BOUNDING_BOX(cls) -> CoordinateUnits:
        '''Uses the bounding box of the object for the SVG element.'''
        ...
    
    ...

class Cursor:
    '''Defines cursor types for SVG elements, allowing customization of the cursor appearance when hovering over these elements.'''
    
    @classmethod
    @property
    def AUTO(cls) -> Cursor:
        '''The browser determines the cursor to display based on the current context.'''
        ...
    
    @classmethod
    @property
    def DEFAULT(cls) -> Cursor:
        '''Default cursor, typically an arrow.'''
        ...
    
    @classmethod
    @property
    def NONE(cls) -> Cursor:
        '''No cursor is displayed.'''
        ...
    
    @classmethod
    @property
    def CONTEXT_MENU(cls) -> Cursor:
        '''Cursor indicating a context menu is available.'''
        ...
    
    @classmethod
    @property
    def HELP(cls) -> Cursor:
        '''Cursor indicating help information is available.'''
        ...
    
    @classmethod
    @property
    def POINTER(cls) -> Cursor:
        '''Cursor indicating a clickable element, typically a hand pointer.'''
        ...
    
    @classmethod
    @property
    def PROGRESS(cls) -> Cursor:
        '''Cursor indicating an ongoing operation or task.'''
        ...
    
    @classmethod
    @property
    def WAIT(cls) -> Cursor:
        '''Cursor indicating that the system is busy and the user should wait.'''
        ...
    
    @classmethod
    @property
    def CELL(cls) -> Cursor:
        '''Cursor indicating a cell or table element.'''
        ...
    
    @classmethod
    @property
    def CROSSHAIR(cls) -> Cursor:
        '''Cursor indicating precision selection, typically a crosshair.'''
        ...
    
    @classmethod
    @property
    def TEXT(cls) -> Cursor:
        '''Cursor indicating text selection.'''
        ...
    
    @classmethod
    @property
    def VERTICAL_TEXT(cls) -> Cursor:
        '''Cursor indicating vertical text selection.'''
        ...
    
    @classmethod
    @property
    def ALIAS(cls) -> Cursor:
        '''Cursor indicating an alias or shortcut is being created.'''
        ...
    
    @classmethod
    @property
    def COPY(cls) -> Cursor:
        '''Cursor indicating copy operation.'''
        ...
    
    @classmethod
    @property
    def MOVE(cls) -> Cursor:
        '''Cursor indicating a movable item or area.'''
        ...
    
    @classmethod
    @property
    def NO_DROP(cls) -> Cursor:
        '''Cursor indicating that dropping is not allowed.'''
        ...
    
    @classmethod
    @property
    def NOT_ALLOWED(cls) -> Cursor:
        '''Cursor indicating an action is not allowed.'''
        ...
    
    @classmethod
    @property
    def GRAB(cls) -> Cursor:
        '''Cursor indicating an item can be grabbed.'''
        ...
    
    @classmethod
    @property
    def GRABBING(cls) -> Cursor:
        '''Cursor indicating an item is currently being grabbed.'''
        ...
    
    @classmethod
    @property
    def E_RESIZE(cls) -> Cursor:
        '''Cursor indicating eastward resize.'''
        ...
    
    @classmethod
    @property
    def N_RESIZE(cls) -> Cursor:
        '''Cursor indicating northward resize.'''
        ...
    
    @classmethod
    @property
    def NE_RESIZE(cls) -> Cursor:
        '''Cursor indicating northeastward resize.'''
        ...
    
    @classmethod
    @property
    def NW_RESIZE(cls) -> Cursor:
        '''Cursor indicating northwestward resize.'''
        ...
    
    @classmethod
    @property
    def S_RESIZE(cls) -> Cursor:
        '''Cursor indicating southward resize.'''
        ...
    
    @classmethod
    @property
    def SE_RESIZE(cls) -> Cursor:
        '''Cursor indicating southeastward resize.'''
        ...
    
    @classmethod
    @property
    def SW_RESIZE(cls) -> Cursor:
        '''Cursor indicating southwestward resize.'''
        ...
    
    @classmethod
    @property
    def W_RESIZE(cls) -> Cursor:
        '''Cursor indicating westward resize.'''
        ...
    
    @classmethod
    @property
    def EW_RESIZE(cls) -> Cursor:
        '''Cursor indicating east-west resize.'''
        ...
    
    @classmethod
    @property
    def NS_RESIZE(cls) -> Cursor:
        '''Cursor indicating north-south resize.'''
        ...
    
    @classmethod
    @property
    def NESW_RESIZE(cls) -> Cursor:
        '''Cursor indicating northeast-southwest resize.'''
        ...
    
    @classmethod
    @property
    def NW_SE_RESIZE(cls) -> Cursor:
        '''Cursor indicating northwest-southeast resize.'''
        ...
    
    @classmethod
    @property
    def COL_RESIZE(cls) -> Cursor:
        '''Cursor indicating column resize.'''
        ...
    
    @classmethod
    @property
    def ROW_RESIZE(cls) -> Cursor:
        '''Cursor indicating row resize.'''
        ...
    
    @classmethod
    @property
    def ALL_SCROLL(cls) -> Cursor:
        '''Cursor indicating scrolling in all directions.'''
        ...
    
    @classmethod
    @property
    def ZOOM_IN(cls) -> Cursor:
        '''Cursor indicating zoom-in capability.'''
        ...
    
    @classmethod
    @property
    def ZOOM_OUT(cls) -> Cursor:
        '''Cursor indicating zoom-out capability.'''
        ...
    
    ...

class Dash:
    '''Defines the pattern of dashes and gaps used to paint the outline of shapes (stroke) in SVG elements.'''
    
    @classmethod
    @property
    def NONE(cls) -> Dash:
        '''Indicates a solid stroke with no dashes. This is the default behavior when 'stroke-dasharray' is not specified.'''
        ...
    
    ...

class DisplayType:
    '''Specifies the display behavior of elements in SVG documents.'''
    
    @classmethod
    @property
    def INLINE(cls) -> DisplayType:
        '''The element generates one or more inline boxes.'''
        ...
    
    @classmethod
    @property
    def BLOCK(cls) -> DisplayType:
        '''The element generates a block box.'''
        ...
    
    @classmethod
    @property
    def LIST_ITEM(cls) -> DisplayType:
        '''The element generates a block box for the content and a separate list-item inline box.'''
        ...
    
    @classmethod
    @property
    def INLINE_BLOCK(cls) -> DisplayType:
        '''The element generates a block box for the content and an inline box for the container.'''
        ...
    
    @classmethod
    @property
    def TABLE(cls) -> DisplayType:
        '''The element behaves like a table element.'''
        ...
    
    @classmethod
    @property
    def INLINE_TABLE(cls) -> DisplayType:
        '''The element behaves like an inline table.'''
        ...
    
    @classmethod
    @property
    def TABLE_ROW_GROUP(cls) -> DisplayType:
        '''The element behaves like a table row group.'''
        ...
    
    @classmethod
    @property
    def TABLE_HEADER_GROUP(cls) -> DisplayType:
        '''The element behaves like a table header group.'''
        ...
    
    @classmethod
    @property
    def TABLE_FOOTER_GROUP(cls) -> DisplayType:
        '''The element behaves like a table footer group.'''
        ...
    
    @classmethod
    @property
    def TABLE_ROW(cls) -> DisplayType:
        '''The element behaves like a table row.'''
        ...
    
    @classmethod
    @property
    def TABLE_COLUMN_GROUP(cls) -> DisplayType:
        '''The element behaves like a table column group.'''
        ...
    
    @classmethod
    @property
    def TABLE_COLUMN(cls) -> DisplayType:
        '''The element behaves like a table column.'''
        ...
    
    @classmethod
    @property
    def TABLE_CELL(cls) -> DisplayType:
        '''The element behaves like a table cell.'''
        ...
    
    @classmethod
    @property
    def TABLE_CAPTION(cls) -> DisplayType:
        '''The element behaves like a table caption.'''
        ...
    
    @classmethod
    @property
    def NONE(cls) -> DisplayType:
        '''The element does not generate any box and is not rendered. It does not affect layout.'''
        ...
    
    @classmethod
    @property
    def FLEX(cls) -> DisplayType:
        '''The element behaves like a flex container.'''
        ...
    
    @classmethod
    @property
    def INLINE_FLEX(cls) -> DisplayType:
        '''The element behaves like an inline flex container.'''
        ...
    
    @classmethod
    @property
    def GRID(cls) -> DisplayType:
        '''The element behaves like a grid container.'''
        ...
    
    @classmethod
    @property
    def INLINE_GRID(cls) -> DisplayType:
        '''The element behaves like an inline grid container.'''
        ...
    
    ...

class DominantBaseline:
    '''Specifies the dominant baseline used for aligning text.'''
    
    @classmethod
    @property
    def AUTO(cls) -> DominantBaseline:
        '''Automatically determines the dominant baseline based on the font and/or the language.'''
        ...
    
    @classmethod
    @property
    def TEXT_BOTTOM(cls) -> DominantBaseline:
        '''Aligns the text to the bottom of the em square.'''
        ...
    
    @classmethod
    @property
    def ALPHABETIC(cls) -> DominantBaseline:
        '''Aligns the text on the baseline used by alphabetic characters.'''
        ...
    
    @classmethod
    @property
    def IDEOGRAPHIC(cls) -> DominantBaseline:
        '''Aligns the text on the baseline used by ideographic characters.'''
        ...
    
    @classmethod
    @property
    def MIDDLE(cls) -> DominantBaseline:
        '''Aligns the text in the middle of the em square.'''
        ...
    
    @classmethod
    @property
    def CENTRAL(cls) -> DominantBaseline:
        '''Aligns the text in the central baseline of the em square.'''
        ...
    
    @classmethod
    @property
    def MATHEMATICAL(cls) -> DominantBaseline:
        '''Aligns the text on the baseline used by mathematical characters.'''
        ...
    
    @classmethod
    @property
    def HANGING(cls) -> DominantBaseline:
        '''Aligns the text on the hanging baseline, typically used for Tibetan or other Asian scripts.'''
        ...
    
    @classmethod
    @property
    def TEXT_TOP(cls) -> DominantBaseline:
        '''Aligns the text to the top of the em square.'''
        ...
    
    ...

class Dur:
    '''Specifies the duration of an animation in SVG.'''
    
    @classmethod
    @property
    def MEDIA(cls) -> Dur:
        '''The duration of the animation is determined by the length of the media being used.'''
        ...
    
    @classmethod
    @property
    def INDEFINITE(cls) -> Dur:
        '''The animation will continue indefinitely until it is explicitly stopped.'''
        ...
    
    ...

class EdgeMode:
    '''Specifies the edge mode for the feConvolveMatrix filter primitive in SVG.'''
    
    @classmethod
    @property
    def DUPLICATE(cls) -> EdgeMode:
        '''The input image is extended along each of its borders as necessary by duplicating the color values at the given edge of the input image.'''
        ...
    
    @classmethod
    @property
    def WRAP(cls) -> EdgeMode:
        '''The input image is conceptually wrapped (or tiled) and the convolution uses these wrapped values. This creates a toroidal topology for the image.'''
        ...
    
    @classmethod
    @property
    def NONE(cls) -> EdgeMode:
        '''The edge mode is not defined, and the effect of the filter is defined by the implementation.'''
        ...
    
    ...

class FillRule:
    '''Specifies the rule to determine what parts of a shape are inside or outside in SVG graphics.'''
    
    @classmethod
    @property
    def NONZERO(cls) -> FillRule:
        '''The nonzero winding rule: Determines the "insideness" of a point in the shape by drawing a ray from that point to infinity in any direction and counting the number of path segments from the given shape that the ray crosses. If this number is odd, the point is inside; if even, the point is outside.'''
        ...
    
    @classmethod
    @property
    def EVENODD(cls) -> FillRule:
        '''The even-odd winding rule: Determines the "insideness" of a point in the shape by drawing a ray from that point to infinity in any direction and counting the number of path segments from the given shape that the ray crosses. If this number is even, the point is outside; if odd, the point is inside.'''
        ...
    
    ...

class FilterInput:
    '''Specifies predefined input images for an SVG filter.'''
    
    @classmethod
    @property
    def SOURCE_GRAPHIC(cls) -> FilterInput:
        '''Refers to the graphic element to which the filter is applied.'''
        ...
    
    @classmethod
    @property
    def SOURCE_ALPHA(cls) -> FilterInput:
        '''Refers to the alpha channel of the graphic element to which the filter is applied.'''
        ...
    
    @classmethod
    @property
    def BACKGROUND_IMAGE(cls) -> FilterInput:
        '''Refers to the background image that lies directly beneath the graphic element to which the filter is applied.'''
        ...
    
    @classmethod
    @property
    def BACKGROUND_ALPHA(cls) -> FilterInput:
        '''Refers to the alpha channel of the background image that lies directly beneath the graphic element to which the filter is applied.'''
        ...
    
    @classmethod
    @property
    def FILL_PAINT(cls) -> FilterInput:
        '''Refers to the fill paint of the graphic element to which the filter is applied.'''
        ...
    
    @classmethod
    @property
    def STROKE_PAINT(cls) -> FilterInput:
        '''Refers to the stroke paint of the graphic element to which the filter is applied.'''
        ...
    
    ...

class FontSize:
    '''Specifies predefined font sizes for SVG text elements.'''
    
    @classmethod
    @property
    def XX_SMALL(cls) -> FontSize:
        '''Represents an extra-extra-small font size.'''
        ...
    
    @classmethod
    @property
    def X_SMALL(cls) -> FontSize:
        '''Represents an extra-small font size.'''
        ...
    
    @classmethod
    @property
    def SMALL(cls) -> FontSize:
        '''Represents a small font size.'''
        ...
    
    @classmethod
    @property
    def MEDIUM(cls) -> FontSize:
        '''Represents a medium font size.'''
        ...
    
    @classmethod
    @property
    def LARGE(cls) -> FontSize:
        '''Represents a large font size.'''
        ...
    
    @classmethod
    @property
    def X_LARGE(cls) -> FontSize:
        '''Represents an extra-large font size.'''
        ...
    
    @classmethod
    @property
    def XX_LARGE(cls) -> FontSize:
        '''Represents an extra-extra-large font size.'''
        ...
    
    @classmethod
    @property
    def LARGER(cls) -> FontSize:
        '''Represents a font size larger than the parent element's font size.'''
        ...
    
    @classmethod
    @property
    def SMALLER(cls) -> FontSize:
        '''Represents a font size smaller than the parent element's font size.'''
        ...
    
    @classmethod
    @property
    def INHERIT(cls) -> FontSize:
        '''Inherits the font size from the parent element.'''
        ...
    
    ...

class FontStretch:
    '''Specifies the different levels of font stretching for SVG text elements.'''
    
    @classmethod
    @property
    def NORMAL(cls) -> FontStretch:
        '''Represents the normal (default) font stretch.'''
        ...
    
    @classmethod
    @property
    def ULTRA_CONDENSED(cls) -> FontStretch:
        '''Represents the most condensed font stretch.'''
        ...
    
    @classmethod
    @property
    def EXTRA_CONDENSED(cls) -> FontStretch:
        '''Represents a more condensed font stretch than 'condensed' but less than 'ultra-condensed'.'''
        ...
    
    @classmethod
    @property
    def CONDENSED(cls) -> FontStretch:
        '''Represents a condensed font stretch.'''
        ...
    
    @classmethod
    @property
    def SEMI_CONDENSED(cls) -> FontStretch:
        '''Represents a slightly condensed font stretch.'''
        ...
    
    @classmethod
    @property
    def SEMI_EXPANDED(cls) -> FontStretch:
        '''Represents a slightly expanded font stretch.'''
        ...
    
    @classmethod
    @property
    def EXPANDED(cls) -> FontStretch:
        '''Represents an expanded font stretch.'''
        ...
    
    @classmethod
    @property
    def EXTRA_EXPANDED(cls) -> FontStretch:
        '''Represents a more expanded font stretch than 'expanded' but less than 'ultra-expanded'.'''
        ...
    
    @classmethod
    @property
    def ULTRA_EXPANDED(cls) -> FontStretch:
        '''Represents the most expanded font stretch.'''
        ...
    
    ...

class FontStyle:
    '''Specifies the different styles of fonts for SVG text elements.'''
    
    @classmethod
    @property
    def NORMAL(cls) -> FontStyle:
        '''Represents the normal font style, with no emphasis or slant.'''
        ...
    
    @classmethod
    @property
    def ITALIC(cls) -> FontStyle:
        '''Represents a font style with an italicized appearance, typically used for emphasis.'''
        ...
    
    @classmethod
    @property
    def OBLIQUE(cls) -> FontStyle:
        '''Represents a font style with an oblique appearance, similar to italic but with a less pronounced slant.'''
        ...
    
    ...

class FontWeight:
    '''Specifies the different weights of fonts for SVG text elements.'''
    
    @classmethod
    @property
    def NORMAL(cls) -> FontWeight:
        '''Represents the normal font weight, which is the default weight.'''
        ...
    
    @classmethod
    @property
    def BOLD(cls) -> FontWeight:
        '''Represents a bold font weight, typically used for emphasis.'''
        ...
    
    @classmethod
    @property
    def BOLDER(cls) -> FontWeight:
        '''Represents a font weight that is bolder than the parent element's weight.'''
        ...
    
    @classmethod
    @property
    def LIGHTER(cls) -> FontWeight:
        '''Represents a font weight that is lighter than the parent element's weight.'''
        ...
    
    @classmethod
    @property
    def W100(cls) -> FontWeight:
        '''Represents the font weight of 100, the thinnest available.'''
        ...
    
    @classmethod
    @property
    def W200(cls) -> FontWeight:
        '''Represents the font weight of 200.'''
        ...
    
    @classmethod
    @property
    def W300(cls) -> FontWeight:
        '''Represents the font weight of 300.'''
        ...
    
    @classmethod
    @property
    def W400(cls) -> FontWeight:
        '''Represents the font weight of 400, equivalent to 'normal'.'''
        ...
    
    @classmethod
    @property
    def W500(cls) -> FontWeight:
        '''Represents the font weight of 500.'''
        ...
    
    @classmethod
    @property
    def W600(cls) -> FontWeight:
        '''Represents the font weight of 600.'''
        ...
    
    @classmethod
    @property
    def W700(cls) -> FontWeight:
        '''Represents the font weight of 700, equivalent to 'bold'.'''
        ...
    
    @classmethod
    @property
    def W800(cls) -> FontWeight:
        '''Represents the font weight of 800.'''
        ...
    
    @classmethod
    @property
    def W900(cls) -> FontWeight:
        '''Represents the font weight of 900, the boldest available.'''
        ...
    
    ...

class GeometryBox:
    '''Specifies the reference box for mask and clip-path elements in SVG.'''
    
    @classmethod
    @property
    def MARGIN_BOX(cls) -> GeometryBox:
        '''Uses the margin box as the reference box.'''
        ...
    
    @classmethod
    @property
    def BORDER_BOX(cls) -> GeometryBox:
        '''Uses the border box as the reference box.'''
        ...
    
    @classmethod
    @property
    def PADDING_BOX(cls) -> GeometryBox:
        '''Uses the padding box as the reference box.'''
        ...
    
    @classmethod
    @property
    def CONTENT_BOX(cls) -> GeometryBox:
        '''Uses the content box as the reference box.'''
        ...
    
    @classmethod
    @property
    def FILL_BOX(cls) -> GeometryBox:
        '''Uses the area of the element's fill as the reference box.'''
        ...
    
    @classmethod
    @property
    def STROKE_BOX(cls) -> GeometryBox:
        '''Uses the area of the element's stroke as the reference box.'''
        ...
    
    @classmethod
    @property
    def VIEW_BOX(cls) -> GeometryBox:
        '''Uses the nearest SVG viewport as the reference box.'''
        ...
    
    ...

class HorizontalEdge:
    '''Specifies the horizontal edge reference for positioning in SVG.'''
    
    @classmethod
    @property
    def LEFT(cls) -> HorizontalEdge:
        '''Refers to the left edge for horizontal positioning.'''
        ...
    
    @classmethod
    @property
    def RIGHT(cls) -> HorizontalEdge:
        '''Refers to the right edge for horizontal positioning.'''
        ...
    
    ...

class HorizontalPosition:
    '''Specifies the horizontal position of an element or a component in SVG.'''
    
    @classmethod
    @property
    def LEFT(cls) -> HorizontalPosition:
        '''Aligns the element or component to the left.'''
        ...
    
    @classmethod
    @property
    def CENTER(cls) -> HorizontalPosition:
        '''Centers the element or component horizontally.'''
        ...
    
    @classmethod
    @property
    def RIGHT(cls) -> HorizontalPosition:
        '''Aligns the element or component to the right.'''
        ...
    
    ...

class ImageRendering:
    '''Specifies how an image should be rendered in SVG.'''
    
    @classmethod
    @property
    def AUTO(cls) -> ImageRendering:
        '''The browser makes a trade-off between speed and quality when rendering the image.'''
        ...
    
    @classmethod
    @property
    def OPTIMIZE_SPEED(cls) -> ImageRendering:
        '''The browser emphasizes rendering speed over image quality. This often means scaling images in a way that might make them look pixelated or blocky.'''
        ...
    
    @classmethod
    @property
    def OPTIMIZE_QUALITY(cls) -> ImageRendering:
        '''The browser emphasizes image quality over rendering speed. This can mean smoother, higher quality scaling of images but might result in slower rendering.'''
        ...
    
    ...

class IndefiniteRepeat:
    '''Specifies the indefinite repetition of an SVG animation.'''
    
    @classmethod
    @property
    def INDEFINITE(cls) -> IndefiniteRepeat:
        '''Indicates that the animation should repeat indefinitely.'''
        ...
    
    ...

class Kerning:
    '''Specifies the kerning behavior for text in SVG.'''
    
    @classmethod
    @property
    def AUTO(cls) -> Kerning:
        '''Enables the browser to determine whether kerning should be applied.'''
        ...
    
    @classmethod
    @property
    def NORMAL(cls) -> Kerning:
        '''Applies the standard kerning, as defined in the font file.'''
        ...
    
    @classmethod
    @property
    def NONE(cls) -> Kerning:
        '''Disables kerning, ignoring any kerning information in the font.'''
        ...
    
    ...

class LengthAdjust:
    '''Specifies how text length adjustments are made in SVG.'''
    
    @classmethod
    @property
    def SPACING(cls) -> LengthAdjust:
        '''Adjusts the spacing between characters to achieve the desired length.'''
        ...
    
    @classmethod
    @property
    def SPACING_AND_GLYPHS(cls) -> LengthAdjust:
        '''Adjusts both the spacing and the size of the glyphs to achieve the desired length.'''
        ...
    
    ...

class LengthType:
    '''Specifies the units of measurement for lengths in SVG.'''
    
    @classmethod
    @property
    def NUMBER(cls) -> LengthType:
        '''Represents a numeric value without any unit. It is often interpreted in the context of other values or default units.'''
        ...
    
    @classmethod
    @property
    def PERCENTAGE(cls) -> LengthType:
        '''Represents a percentage value, relative to another value or a bounding dimension.'''
        ...
    
    @classmethod
    @property
    def EMS(cls) -> LengthType:
        '''Represents a length in 'ems', a scalable unit that is relative to the current font size.'''
        ...
    
    @classmethod
    @property
    def EXS(cls) -> LengthType:
        '''Represents a length in 'exs', related to the x-height of the current font.'''
        ...
    
    @classmethod
    @property
    def PX(cls) -> LengthType:
        '''Represents a length in pixels, a unit of measurement based on the digital representation of an image.'''
        ...
    
    @classmethod
    @property
    def CM(cls) -> LengthType:
        '''Represents a length in centimeters.'''
        ...
    
    @classmethod
    @property
    def MM(cls) -> LengthType:
        '''Represents a length in millimeters.'''
        ...
    
    @classmethod
    @property
    def IN(cls) -> LengthType:
        '''Represents a length in inches.'''
        ...
    
    @classmethod
    @property
    def PT(cls) -> LengthType:
        '''Represents a length in points, a traditional unit in typography. 1 point is approximately 1/72 of an inch.'''
        ...
    
    @classmethod
    @property
    def PC(cls) -> LengthType:
        '''Represents a length in picas, a typographic unit of measurement. 1 pica is equivalent to 12 points.'''
        ...
    
    ...

class MarkerPos:
    '''Specifies the position of markers in SVG.'''
    
    @classmethod
    @property
    def NONE(cls) -> MarkerPos:
        '''Indicates that no markers will be rendered on the element.'''
        ...
    
    ...

class MarkerUnits:
    '''Specifies the coordinate system for the marker size in SVG.'''
    
    @classmethod
    @property
    def STROKE_WIDTH(cls) -> MarkerUnits:
        '''The size of the marker is relative to the stroke width of the path.'''
        ...
    
    @classmethod
    @property
    def USER_SPACE_ON_USE(cls) -> MarkerUnits:
        '''The size of the marker is based on the user coordinate system, making it independent of the stroke width.'''
        ...
    
    ...

class Media:
    '''Specifies the media-related timing conditions for SVG animations.'''
    
    @classmethod
    @property
    def MEDIA(cls) -> Media:
        '''Indicates that the timing of the animation is dependent on the timing of the media.'''
        ...
    
    ...

class MorphologyOperator:
    '''Specifies the type of morphological operation to be applied in SVG filters.'''
    
    @classmethod
    @property
    def ERODE(cls) -> MorphologyOperator:
        '''Erodes the graphics, making the shapes smaller and the edges smoother.'''
        ...
    
    @classmethod
    @property
    def DILATE(cls) -> MorphologyOperator:
        '''Dilates the graphics, making the shapes larger and the edges more pronounced.'''
        ...
    
    ...

class Orient:
    '''Specifies the orientation of the marker relative to the shape it is attached to.'''
    
    @classmethod
    @property
    def AUTO(cls) -> Orient:
        '''The marker is oriented in such a way that it points in the direction of the path.'''
        ...
    
    @classmethod
    @property
    def AUTO_START_REVERSE(cls) -> Orient:
        '''The marker is oriented in the reverse direction of the path's start.'''
        ...
    
    ...

class Overflow:
    '''Specifies the overflow behavior for SVG elements.'''
    
    @classmethod
    @property
    def VISIBLE(cls) -> Overflow:
        '''Content that exceeds the bounds of the element is visible.'''
        ...
    
    @classmethod
    @property
    def HIDDEN(cls) -> Overflow:
        '''Content that exceeds the bounds of the element is clipped and not visible.'''
        ...
    
    @classmethod
    @property
    def SCROLL(cls) -> Overflow:
        '''Provides scrollbars for the content that exceeds the bounds of the element.'''
        ...
    
    ...

class Paint:
    '''Specifies the paint options for the fill and stroke attributes in SVG elements.'''
    
    @classmethod
    @property
    def NONE(cls) -> Paint:
        '''Indicates no paint should be applied.'''
        ...
    
    @classmethod
    @property
    def CONTEXT_FILL(cls) -> Paint:
        '''Uses the current context fill color for painting.'''
        ...
    
    @classmethod
    @property
    def CONTEXT_STROKE(cls) -> Paint:
        '''Uses the current context stroke color for painting.'''
        ...
    
    ...

class PaintOrder:
    '''Specifies the order in which fill, stroke, and markers are applied to SVG elements.'''
    
    @classmethod
    @property
    def NORMAL(cls) -> PaintOrder:
        '''The default paint order: first fill, then stroke, and finally markers.'''
        ...
    
    @classmethod
    @property
    def FILL(cls) -> PaintOrder:
        '''Paint only the fill.'''
        ...
    
    @classmethod
    @property
    def STROKE(cls) -> PaintOrder:
        '''Paint only the stroke.'''
        ...
    
    @classmethod
    @property
    def MARKERS(cls) -> PaintOrder:
        '''Paint only the markers.'''
        ...
    
    @classmethod
    @property
    def FILL_STROKE(cls) -> PaintOrder:
        '''Paint in the order of fill, then stroke.'''
        ...
    
    @classmethod
    @property
    def FILL_MARKERS(cls) -> PaintOrder:
        '''Paint in the order of fill, then markers.'''
        ...
    
    @classmethod
    @property
    def STROKE_FILL(cls) -> PaintOrder:
        '''Paint in the order of stroke, then fill.'''
        ...
    
    @classmethod
    @property
    def STROKE_MARKERS(cls) -> PaintOrder:
        '''Paint in the order of stroke, then markers.'''
        ...
    
    @classmethod
    @property
    def MARKERS_FILL(cls) -> PaintOrder:
        '''Paint in the order of markers, then fill.'''
        ...
    
    @classmethod
    @property
    def MARKERS_STROKE(cls) -> PaintOrder:
        '''Paint in the order of markers, then stroke.'''
        ...
    
    @classmethod
    @property
    def FILL_STROKE_MARKERS(cls) -> PaintOrder:
        '''Paint in the order of fill, then stroke, and finally markers.'''
        ...
    
    @classmethod
    @property
    def FILL_MARKERS_STROKE(cls) -> PaintOrder:
        '''Paint in the order of fill, then markers, and finally stroke.'''
        ...
    
    @classmethod
    @property
    def STROKE_FILL_MARKERS(cls) -> PaintOrder:
        '''Paint in the order of stroke, then fill, and finally markers.'''
        ...
    
    @classmethod
    @property
    def STROKE_MARKERS_FILL(cls) -> PaintOrder:
        '''Paint in the order of stroke, then markers, and finally fill.'''
        ...
    
    @classmethod
    @property
    def MARKERS_FILL_STROKE(cls) -> PaintOrder:
        '''Paint in the order of markers, then fill, and finally stroke.'''
        ...
    
    @classmethod
    @property
    def MARKERS_STROKE_FILL(cls) -> PaintOrder:
        '''Paint in the order of markers, then stroke, and finally fill.'''
        ...
    
    ...

class PointerEvents:
    '''Specifies how pointer events are handled by graphical elements in SVG.'''
    
    @classmethod
    @property
    def BOUNDING_BOX(cls) -> PointerEvents:
        '''Pointer events are targeted at the bounding box of the element.'''
        ...
    
    @classmethod
    @property
    def VISIBLE_PAINTED(cls) -> PointerEvents:
        '''Pointer events are targeted only at the visible (painted) parts of the element.'''
        ...
    
    @classmethod
    @property
    def VISIBLE_FILL(cls) -> PointerEvents:
        '''Pointer events are targeted only at the visible (filled) parts of the element.'''
        ...
    
    @classmethod
    @property
    def VISIBLE_STROKE(cls) -> PointerEvents:
        '''Pointer events are targeted only at the visible (stroked) parts of the element.'''
        ...
    
    @classmethod
    @property
    def VISIBLE(cls) -> PointerEvents:
        '''Pointer events are targeted at all visible parts of the element.'''
        ...
    
    @classmethod
    @property
    def PAINTED(cls) -> PointerEvents:
        '''Pointer events are targeted at all painted parts of the element, including fill and stroke.'''
        ...
    
    @classmethod
    @property
    def FILL(cls) -> PointerEvents:
        '''Pointer events are targeted only at the filled parts of the element.'''
        ...
    
    @classmethod
    @property
    def STROKE(cls) -> PointerEvents:
        '''Pointer events are targeted only at the stroked parts of the element.'''
        ...
    
    @classmethod
    @property
    def ALL(cls) -> PointerEvents:
        '''Pointer events are targeted at all parts of the element, regardless of visibility.'''
        ...
    
    @classmethod
    @property
    def NONE(cls) -> PointerEvents:
        '''The element does not become the target of pointer events.'''
        ...
    
    ...

class ReferrerPolicy:
    '''Specifies the referrer policy to be used when fetching resources.'''
    
    @classmethod
    @property
    def NONE(cls) -> ReferrerPolicy:
        '''No referrer policy is set.'''
        ...
    
    @classmethod
    @property
    def NO_REFERRER(cls) -> ReferrerPolicy:
        '''The Referer header will not be sent.'''
        ...
    
    @classmethod
    @property
    def NO_REFERRER_WHEN_DOWNGRADE(cls) -> ReferrerPolicy:
        '''The Referer header will not be sent to origins with less security (HTTPS -> HTTP).'''
        ...
    
    @classmethod
    @property
    def SAME_ORIGIN(cls) -> ReferrerPolicy:
        '''The Referer header will be sent for same-origin requests only.'''
        ...
    
    @classmethod
    @property
    def ORIGIN(cls) -> ReferrerPolicy:
        '''Only the origin of the document will be sent as the Referer header.'''
        ...
    
    @classmethod
    @property
    def STRICT_ORIGIN(cls) -> ReferrerPolicy:
        '''Only the origin of the document will be sent as the Referer header for secure contexts.'''
        ...
    
    @classmethod
    @property
    def ORIGIN_WHEN_CROSS_ORIGIN(cls) -> ReferrerPolicy:
        '''The full URL will be sent as the Referer header for same-origin requests, but only the origin for cross-origin requests.'''
        ...
    
    @classmethod
    @property
    def STRICT_ORIGIN_WHEN_CROSS_ORIGIN(cls) -> ReferrerPolicy:
        '''Only the origin of the document will be sent as the Referer header for same-origin requests, but no header for cross-origin requests in insecure contexts.'''
        ...
    
    @classmethod
    @property
    def UNSAFE_URL(cls) -> ReferrerPolicy:
        '''The full URL, including the path and query string, will always be sent as the Referer header.'''
        ...
    
    ...

class RepeatStyle:
    '''Specifies the repeat style for background images or patterns in SVG.'''
    
    @classmethod
    @property
    def REPEAT_X(cls) -> RepeatStyle:
        '''The image or pattern is repeated horizontally only.'''
        ...
    
    @classmethod
    @property
    def REPEAT_Y(cls) -> RepeatStyle:
        '''The image or pattern is repeated vertically only.'''
        ...
    
    @classmethod
    @property
    def REPEAT(cls) -> RepeatStyle:
        '''The image or pattern is repeated both horizontally and vertically.'''
        ...
    
    @classmethod
    @property
    def SPACE(cls) -> RepeatStyle:
        '''The image or pattern is repeated as much as possible without clipping, and the remaining space is distributed evenly between the images.'''
        ...
    
    @classmethod
    @property
    def ROUND(cls) -> RepeatStyle:
        '''The image or pattern is scaled so that it fits and is repeated without clipping, maintaining its aspect ratio.'''
        ...
    
    @classmethod
    @property
    def NO_REPEAT(cls) -> RepeatStyle:
        '''The image or pattern is not repeated, and only one copy of the image will be drawn.'''
        ...
    
    ...

class Restart:
    '''Specifies the restart behavior for SVG animations.'''
    
    @classmethod
    @property
    def ALWAYS(cls) -> Restart:
        '''The animation can be restarted at any time, even if it is currently active.'''
        ...
    
    @classmethod
    @property
    def WHEN_NOT_ACTIVE(cls) -> Restart:
        '''The animation can only be restarted when it is not currently active.'''
        ...
    
    @classmethod
    @property
    def NEVER(cls) -> Restart:
        '''The animation cannot be restarted once it has started; it will run to completion.'''
        ...
    
    ...

class Rotate:
    '''Specifies the rotation behavior for elements during motion animation in SVG.'''
    
    @classmethod
    @property
    def AUTO(cls) -> Rotate:
        '''Automatically rotates the element in the direction of the path.'''
        ...
    
    @classmethod
    @property
    def AUTO_REVERSE(cls) -> Rotate:
        '''Automatically rotates the element in the direction of the path and allows it to reverse.'''
        ...
    
    ...

class ShapeRendering:
    '''Specifies the shape rendering mode for SVG elements.'''
    
    @classmethod
    @property
    def AUTO(cls) -> ShapeRendering:
        '''The browser makes trade-offs between speed, smoothness, and geometric precision when rendering shapes.'''
        ...
    
    @classmethod
    @property
    def OPTIMIZE_SPEED(cls) -> ShapeRendering:
        '''The browser emphasizes rendering speed over geometric precision and smoothness. This mode can lead to faster rendering but less accurate shapes.'''
        ...
    
    @classmethod
    @property
    def CRISP_EDGES(cls) -> ShapeRendering:
        '''The browser attempts to preserve sharp edges and corners. This mode is useful for rendering graphics with straight lines and edges.'''
        ...
    
    @classmethod
    @property
    def GEOMETRIC_PRECISION(cls) -> ShapeRendering:
        '''The browser emphasizes geometric precision in rendering at the cost of speed. This mode is suitable for high-quality rendering where precise geometry is important.'''
        ...
    
    ...

class Spacing:
    '''Specifies the spacing behavior for text elements in SVG.'''
    
    @classmethod
    @property
    def NORMAL(cls) -> Spacing:
        '''Indicates the use of the normal spacing behavior. The spacing is determined based on the current font and text size.'''
        ...
    
    ...

class SpreadMethod:
    '''Specifies how the colors in a gradient are spread beyond its bounds.'''
    
    @classmethod
    @property
    def PAD(cls) -> SpreadMethod:
        '''The color of the last gradient stop is used to fill the rest of the gradient area.'''
        ...
    
    @classmethod
    @property
    def REFLECT(cls) -> SpreadMethod:
        '''The gradient is reflected (mirrored) outside its bounds.'''
        ...
    
    @classmethod
    @property
    def REPEAT(cls) -> SpreadMethod:
        '''The gradient is repeated outside its bounds.'''
        ...
    
    ...

class StitchTiles:
    '''Specifies the stitching options for the 'feTurbulence' filter primitive.'''
    
    @classmethod
    @property
    def STITCH(cls) -> StitchTiles:
        '''The tiles are stitched together to form a smooth, continuous pattern.'''
        ...
    
    @classmethod
    @property
    def NO_STITCH(cls) -> StitchTiles:
        '''The tiles are not stitched, which may result in visible seams.'''
        ...
    
    ...

class StopUnitType:
    '''Defines the unit types for the offset in gradient 'stop' elements.'''
    
    @classmethod
    @property
    def NUMBER(cls) -> StopUnitType:
        '''The offset is defined as a number.'''
        ...
    
    @classmethod
    @property
    def PERCENTAGE(cls) -> StopUnitType:
        '''The offset is defined as a percentage of the gradient's size.'''
        ...
    
    ...

class StrokeLineCap:
    '''Specifies the shape to be used at the end of open subpaths when they are stroked.'''
    
    @classmethod
    @property
    def BUTT(cls) -> StrokeLineCap:
        '''The stroke ends with a flat edge perpendicular to the direction of the line.'''
        ...
    
    @classmethod
    @property
    def ROUND(cls) -> StrokeLineCap:
        '''The stroke ends with a half-circle, which has a radius equal to the stroke width and is centered on the end of the line.'''
        ...
    
    @classmethod
    @property
    def SQUARE(cls) -> StrokeLineCap:
        '''The stroke ends with a square edge that extends half the stroke width beyond the end of the line.'''
        ...
    
    ...

class StrokeLineJoin:
    '''Specifies the shape to be used at the corners of paths or basic shapes when they are stroked.'''
    
    @classmethod
    @property
    def MITER(cls) -> StrokeLineJoin:
        '''A sharp corner is used to join path segments.'''
        ...
    
    @classmethod
    @property
    def MITER_CLIP(cls) -> StrokeLineJoin:
        '''Similar to 'miter', but if the join would extend beyond a limit, it is clipped.'''
        ...
    
    @classmethod
    @property
    def ROUND(cls) -> StrokeLineJoin:
        '''A rounded corner is used to join path segments.'''
        ...
    
    @classmethod
    @property
    def BEVEL(cls) -> StrokeLineJoin:
        '''A beveled corner is used to join path segments.'''
        ...
    
    @classmethod
    @property
    def ARCS(cls) -> StrokeLineJoin:
        '''The corner is joined by arcs.'''
        ...
    
    ...

class Target:
    '''Specifies the browsing context for where to display the linked URL.'''
    
    @classmethod
    @property
    def SELF(cls) -> Target:
        '''Opens the linked document in the same frame as it was clicked.'''
        ...
    
    @classmethod
    @property
    def PARENT(cls) -> Target:
        '''Opens the linked document in the parent frame.'''
        ...
    
    @classmethod
    @property
    def TOP(cls) -> Target:
        '''Opens the linked document in the full body of the window.'''
        ...
    
    @classmethod
    @property
    def BLANK(cls) -> Target:
        '''Opens the linked document in a new window or tab.'''
        ...
    
    ...

class TextAnchor:
    '''Specifies how text is horizontally aligned relative to a given point.'''
    
    @classmethod
    @property
    def START(cls) -> TextAnchor:
        '''The text is aligned to the start of the line.'''
        ...
    
    @classmethod
    @property
    def MIDDLE(cls) -> TextAnchor:
        '''The text is aligned to the middle of the line.'''
        ...
    
    @classmethod
    @property
    def END(cls) -> TextAnchor:
        '''The text is aligned to the end of the line.'''
        ...
    
    ...

class TextDirection:
    '''Specifies the directionality of text.'''
    
    @classmethod
    @property
    def LTR(cls) -> TextDirection:
        '''Text direction is left-to-right.'''
        ...
    
    @classmethod
    @property
    def RTL(cls) -> TextDirection:
        '''Text direction is right-to-left.'''
        ...
    
    @classmethod
    @property
    def INHERIT(cls) -> TextDirection:
        '''Inherits text direction from its parent.'''
        ...
    
    ...

class TextOrientation:
    '''Specifies the orientation of text when writing.'''
    
    @classmethod
    @property
    def MIXED(cls) -> TextOrientation:
        '''Text orientation is mixed, allowing both upright and sideways text.'''
        ...
    
    @classmethod
    @property
    def UPRIGHT(cls) -> TextOrientation:
        '''Text orientation is upright.'''
        ...
    
    @classmethod
    @property
    def SIDEWAYS(cls) -> TextOrientation:
        '''Text orientation is sideways.'''
        ...
    
    ...

class TextOverflow:
    '''Specifies how overflowed content inside a text element is handled.'''
    
    @classmethod
    @property
    def CLIP(cls) -> TextOverflow:
        '''Overflowed content is clipped.'''
        ...
    
    @classmethod
    @property
    def ELLIPSIS(cls) -> TextOverflow:
        '''Overflowed content is represented with an ellipsis.'''
        ...
    
    ...

class TextPathMethod:
    '''Specifies the method used to render text along a path.'''
    
    @classmethod
    @property
    def ALIGN(cls) -> TextPathMethod:
        '''The text is aligned with the path.'''
        ...
    
    @classmethod
    @property
    def STRETCH(cls) -> TextPathMethod:
        '''The text is stretched to fit the path.'''
        ...
    
    ...

class TextPathSpacing:
    '''Specifies the spacing strategy for text along a path.'''
    
    @classmethod
    @property
    def AUTO(cls) -> TextPathSpacing:
        '''Default spacing is used, which may vary.'''
        ...
    
    @classmethod
    @property
    def EXACT(cls) -> TextPathSpacing:
        '''Exact spacing as specified is used.'''
        ...
    
    ...

class TextRendering:
    '''Specifies the text rendering strategy in SVG.'''
    
    @classmethod
    @property
    def AUTO(cls) -> TextRendering:
        '''Allows the browser to choose an optimized text rendering mode.'''
        ...
    
    @classmethod
    @property
    def OPTIMIZE_SPEED(cls) -> TextRendering:
        '''Emphasizes rendering speed over text legibility and geometric precision.'''
        ...
    
    @classmethod
    @property
    def OPTIMIZE_LEGIBILITY(cls) -> TextRendering:
        '''Emphasizes legibility over rendering speed and geometric precision.'''
        ...
    
    @classmethod
    @property
    def GEOMETRIC_PRECISION(cls) -> TextRendering:
        '''Emphasizes geometric precision over rendering speed and legibility.'''
        ...
    
    ...

class TransformationType:
    '''Specifies the type of transformation applied to an SVG element.'''
    
    @classmethod
    @property
    def TRANSLATE(cls) -> TransformationType:
        '''Translates (moves) an element by a certain distance.'''
        ...
    
    @classmethod
    @property
    def SCALE(cls) -> TransformationType:
        '''Scales an element up or down in size.'''
        ...
    
    @classmethod
    @property
    def ROTATE(cls) -> TransformationType:
        '''Rotates an element around a given point.'''
        ...
    
    @classmethod
    @property
    def SKEW_X(cls) -> TransformationType:
        '''Skews an element along the X-axis.'''
        ...
    
    @classmethod
    @property
    def SKEW_Y(cls) -> TransformationType:
        '''Skews an element along the Y-axis.'''
        ...
    
    ...

class TurbulenceType:
    '''Specifies the type of turbulence effect for the feTurbulence SVG filter.'''
    
    @classmethod
    @property
    def FRACTAL_NOISE(cls) -> TurbulenceType:
        '''Generates a fractal noise pattern.'''
        ...
    
    @classmethod
    @property
    def TURBULENCE(cls) -> TurbulenceType:
        '''Generates a turbulence pattern.'''
        ...
    
    ...

class UnicodeBidi:
    '''Specifies the handling of bidirectional text in SVG.'''
    
    @classmethod
    @property
    def NORMAL(cls) -> UnicodeBidi:
        '''Normal bidirectional text handling.'''
        ...
    
    @classmethod
    @property
    def EMBED(cls) -> UnicodeBidi:
        '''Embeds a section of text with a different or explicit directionality.'''
        ...
    
    @classmethod
    @property
    def ISOLATE(cls) -> UnicodeBidi:
        '''Isolates a section of text from its surroundings for bidirectional text handling.'''
        ...
    
    @classmethod
    @property
    def BIDI_OVERRIDE(cls) -> UnicodeBidi:
        '''Overrides the inherent directionality of characters in a section of text.'''
        ...
    
    @classmethod
    @property
    def ISOLATE_OVERRIDE(cls) -> UnicodeBidi:
        '''Isolates a section of text and overrides its directionality.'''
        ...
    
    @classmethod
    @property
    def PLAINTEXT(cls) -> UnicodeBidi:
        '''Treats the section of text as plaintext with no special bidirectional handling.'''
        ...
    
    ...

class VerticalEdge:
    '''Specifies the vertical edge reference for positioning in SVG.'''
    
    @classmethod
    @property
    def TOP(cls) -> VerticalEdge:
        '''Refers to the top edge for vertical positioning.'''
        ...
    
    @classmethod
    @property
    def BOTTOM(cls) -> VerticalEdge:
        '''Refers to the bottom edge for vertical positioning.'''
        ...
    
    ...

class VerticalPosition:
    '''Specifies the vertical position of an element or a component in SVG.'''
    
    @classmethod
    @property
    def TOP(cls) -> VerticalPosition:
        '''Aligns the element or component to the top.'''
        ...
    
    @classmethod
    @property
    def CENTER(cls) -> VerticalPosition:
        '''Centers the element or component vertically.'''
        ...
    
    @classmethod
    @property
    def BOTTOM(cls) -> VerticalPosition:
        '''Aligns the element or component to the bottom.'''
        ...
    
    ...

class Visibility:
    '''Specifies the visibility of SVG elements.'''
    
    @classmethod
    @property
    def VISIBLE(cls) -> Visibility:
        '''The element is visible.'''
        ...
    
    @classmethod
    @property
    def HIDDEN(cls) -> Visibility:
        '''The element is not visible, but still affects layout.'''
        ...
    
    @classmethod
    @property
    def COLLAPSE(cls) -> Visibility:
        '''The element is not visible and does not affect layout.'''
        ...
    
    ...

class WhiteSpace:
    '''Specifies how white space inside an SVG element is handled.'''
    
    @classmethod
    @property
    def NORMAL(cls) -> WhiteSpace:
        '''White space is collapsed; newline characters create new lines.'''
        ...
    
    @classmethod
    @property
    def PRE(cls) -> WhiteSpace:
        '''White space is preserved; text is only wrapped where it contains newline characters.'''
        ...
    
    @classmethod
    @property
    def NO_WRAP(cls) -> WhiteSpace:
        '''White space is collapsed; text does not wrap.'''
        ...
    
    @classmethod
    @property
    def PRE_WRAP(cls) -> WhiteSpace:
        '''White space is preserved; text wraps where necessary and on newline characters.'''
        ...
    
    @classmethod
    @property
    def BREAK_SPACES(cls) -> WhiteSpace:
        '''White space is preserved; line breaks are added to fill line boxes.'''
        ...
    
    @classmethod
    @property
    def PRE_LINE(cls) -> WhiteSpace:
        '''White space is preserved; text wraps where necessary, but no newline characters.'''
        ...
    
    ...

class WritingMode:
    '''Specifies the writing mode (direction of text flow) in SVG.'''
    
    @classmethod
    @property
    def HORIZONTAL_TB(cls) -> WritingMode:
        '''Horizontal text flow from top to bottom.'''
        ...
    
    @classmethod
    @property
    def VERTICAL_RL(cls) -> WritingMode:
        '''Vertical text flow from right to left.'''
        ...
    
    @classmethod
    @property
    def VERTICAL_LR(cls) -> WritingMode:
        '''Vertical text flow from left to right.'''
        ...
    
    ...

class XLinkShow:
    '''Specifies the behavior when an SVG link is triggered.'''
    
    @classmethod
    @property
    def NEW(cls) -> XLinkShow:
        '''Opens the link in a new window or tab.'''
        ...
    
    @classmethod
    @property
    def REPLACE(cls) -> XLinkShow:
        '''Replaces the current SVG document with the linked document.'''
        ...
    
    @classmethod
    @property
    def EMBED(cls) -> XLinkShow:
        '''Embeds the linked document within the current SVG document.'''
        ...
    
    @classmethod
    @property
    def OTHER(cls) -> XLinkShow:
        '''Specifies a behavior other than the predefined behaviors.'''
        ...
    
    @classmethod
    @property
    def NONE(cls) -> XLinkShow:
        '''Indicates that no specific behavior is requested.'''
        ...
    
    ...

class XmlSpace:
    '''Specifies how white space inside elements is handled in XML documents.'''
    
    @classmethod
    @property
    def DEFAULT(cls) -> XmlSpace:
        '''Indicates that white space should be handled according to the XML processor's default behavior, typically normalizing white space by removing line breaks and extra spaces.'''
        ...
    
    @classmethod
    @property
    def PRESERVE(cls) -> XmlSpace:
        '''Indicates that white space should be preserved as it appears in the XML document. This is useful for maintaining the formatting of text where white space is significant.'''
        ...
    
    ...

class ZoomAndPan:
    '''Controls zooming and panning capabilities in an SVG document.'''
    
    @classmethod
    @property
    def DISABLE(cls) -> ZoomAndPan:
        '''Disables both zooming and panning features.'''
        ...
    
    @classmethod
    @property
    def MAGNIFY(cls) -> ZoomAndPan:
        '''Enables zooming and panning features.'''
        ...
    
    ...

