from typing import List, Optional, Dict, Iterable
import aspose.pycore
import aspose.pydrawing
import aspose.svg
import aspose.svg.builder
import aspose.svg.collections
import aspose.svg.converters
import aspose.svg.datatypes
import aspose.svg.diagnostics
import aspose.svg.dom
import aspose.svg.dom.attributes
import aspose.svg.dom.canvas
import aspose.svg.dom.css
import aspose.svg.dom.events
import aspose.svg.dom.mutations
import aspose.svg.dom.traversal
import aspose.svg.dom.traversal.filters
import aspose.svg.dom.views
import aspose.svg.dom.xpath
import aspose.svg.drawing
import aspose.svg.drawing.skiasharp
import aspose.svg.events
import aspose.svg.filters
import aspose.svg.imagevectorization
import aspose.svg.io
import aspose.svg.net
import aspose.svg.net.headers
import aspose.svg.net.messagefilters
import aspose.svg.net.messagehandlers
import aspose.svg.paths
import aspose.svg.rendering
import aspose.svg.rendering.devices
import aspose.svg.rendering.fonts
import aspose.svg.rendering.image
import aspose.svg.rendering.pdf
import aspose.svg.rendering.pdf.encryption
import aspose.svg.rendering.styles
import aspose.svg.rendering.styles.paintservers
import aspose.svg.rendering.xps
import aspose.svg.saving
import aspose.svg.saving.resourcehandlers
import aspose.svg.services
import aspose.svg.toolkit
import aspose.svg.toolkit.optimizers
import aspose.svg.window

class Attr(Node):
    '''The Attr interface represents an attribute in an Element object. Typically the allowable values for the attribute are defined in a schema associated with the document.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def name(self) -> str:
        '''Returns the name of this attribute.'''
        ...
    
    @property
    def specified(self) -> bool:
        '''True if this attribute was explicitly given a value in the instance document, false otherwise.'''
        ...
    
    @property
    def value(self) -> str:
        '''On retrieval, the value of the attribute is returned as a string.'''
        ...
    
    @value.setter
    def value(self, value : str):
        '''On retrieval, the value of the attribute is returned as a string.'''
        ...
    
    @property
    def owner_element(self) -> aspose.svg.dom.Element:
        ...
    
    ...

class CDATASection(Text):
    '''CDATA sections are used to escape blocks of text containing characters that would otherwise be regarded as markup.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def substring_data(self, offset : int, count : int) -> str:
        '''Extracts a range of data from the node.
        
        :param offset: The offset.
        :param count: The count.
        :returns: The text data'''
        ...
    
    def append_data(self, data : str):
        '''Append the string to the end of the character data of the node.
        
        :param data: The content data.'''
        ...
    
    def insert_data(self, offset : int, data : str):
        '''Insert a string at the specified 16-bit unit offset.
        
        :param offset: The offset.
        :param data: The content data.'''
        ...
    
    def delete_data(self, offset : int, count : int):
        '''Remove a range of 16-bit units from the node.
        
        :param offset: The offset.
        :param count: The count.'''
        ...
    
    def replace_data(self, offset : int, count : int, data : str):
        '''Replace the characters starting at the specified 16-bit unit offset with the specified string.
        
        :param offset: The offset.
        :param count: The count.
        :param data: The content data.'''
        ...
    
    def split_text(self, offset : int) -> aspose.svg.dom.Text:
        '''Breaks this node into two nodes at the specified offset, keeping both in the tree as siblings.
        
        :param offset: The offset.
        :returns: The :py:class:`aspose.svg.dom.Text`.'''
        ...
    
    def replace_whole_text(self, content : str) -> aspose.svg.dom.Text:
        '''Replaces the text of the current node and all logically-adjacent text nodes with the specified text. All logically-adjacent text nodes are removed including the current node unless it was the recipient of the replacement text.
        
        :param content: The content.
        :returns: The :py:class:`aspose.svg.dom.Text`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def data(self) -> str:
        '''The character data of the node that implements this interface.'''
        ...
    
    @data.setter
    def data(self, value : str):
        '''The character data of the node that implements this interface.'''
        ...
    
    @property
    def length(self) -> int:
        '''The number of 16-bit units that are available through data and the substringData method below. This may have the value zero, i.e., CharacterData nodes may be empty.'''
        ...
    
    @property
    def is_element_content_whitespace(self) -> bool:
        ...
    
    @property
    def whole_text(self) -> str:
        ...
    
    ...

class CharacterData(Node):
    '''The CharacterData extends Node with a set of attributes and methods for accessing character data in the DOM.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def substring_data(self, offset : int, count : int) -> str:
        '''Extracts a range of data from the node.
        
        :param offset: The offset.
        :param count: The count.
        :returns: The text data'''
        ...
    
    def append_data(self, data : str):
        '''Append the string to the end of the character data of the node.
        
        :param data: The content data.'''
        ...
    
    def insert_data(self, offset : int, data : str):
        '''Insert a string at the specified 16-bit unit offset.
        
        :param offset: The offset.
        :param data: The content data.'''
        ...
    
    def delete_data(self, offset : int, count : int):
        '''Remove a range of 16-bit units from the node.
        
        :param offset: The offset.
        :param count: The count.'''
        ...
    
    def replace_data(self, offset : int, count : int, data : str):
        '''Replace the characters starting at the specified 16-bit unit offset with the specified string.
        
        :param offset: The offset.
        :param count: The count.
        :param data: The content data.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def data(self) -> str:
        '''The character data of the node that implements this interface.'''
        ...
    
    @data.setter
    def data(self, value : str):
        '''The character data of the node that implements this interface.'''
        ...
    
    @property
    def length(self) -> int:
        '''The number of 16-bit units that are available through data and the substringData method below. This may have the value zero, i.e., CharacterData nodes may be empty.'''
        ...
    
    ...

class Comment(CharacterData):
    '''Inherits from CharacterData and represents the content of a comment, i.e., all the characters between the starting ''.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def substring_data(self, offset : int, count : int) -> str:
        '''Extracts a range of data from the node.
        
        :param offset: The offset.
        :param count: The count.
        :returns: The text data'''
        ...
    
    def append_data(self, data : str):
        '''Append the string to the end of the character data of the node.
        
        :param data: The content data.'''
        ...
    
    def insert_data(self, offset : int, data : str):
        '''Insert a string at the specified 16-bit unit offset.
        
        :param offset: The offset.
        :param data: The content data.'''
        ...
    
    def delete_data(self, offset : int, count : int):
        '''Remove a range of 16-bit units from the node.
        
        :param offset: The offset.
        :param count: The count.'''
        ...
    
    def replace_data(self, offset : int, count : int, data : str):
        '''Replace the characters starting at the specified 16-bit unit offset with the specified string.
        
        :param offset: The offset.
        :param count: The count.
        :param data: The content data.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def data(self) -> str:
        '''The character data of the node that implements this interface.'''
        ...
    
    @data.setter
    def data(self, value : str):
        '''The character data of the node that implements this interface.'''
        ...
    
    @property
    def length(self) -> int:
        '''The number of 16-bit units that are available through data and the substringData method below. This may have the value zero, i.e., CharacterData nodes may be empty.'''
        ...
    
    ...

class DOMException(aspose.svg.PlatformException):
    '''The DOMException interface represents an abnormal event (called an exception) which occurs as a result of calling a method or accessing a property of a web API. This is basically how error conditions are described in web APIs.'''
    
    @property
    def code(self) -> int:
        '''Returns a value that contains one of the error code constants, or 0 if none match. This field is used for historical reasons.'''
        ...
    
    @property
    def name(self) -> str:
        '''Returns a string that contains one of the strings associated with an error name.'''
        ...
    
    @classmethod
    @property
    def INDEX_SIZE_ERR(cls) -> int:
        '''If index or size is negative, or greater than the allowed value.'''
        ...
    
    @classmethod
    @property
    def DOMSTRING_SIZE_ERR(cls) -> int:
        '''If the specified range of text does not fit into a DOMString.'''
        ...
    
    @classmethod
    @property
    def HIERARCHY_REQUEST_ERR(cls) -> int:
        '''If any Node is inserted somewhere it doesn't belong.'''
        ...
    
    @classmethod
    @property
    def WRONG_DOCUMENT_ERR(cls) -> int:
        '''If a Node is used in a different document than the one that created it (that doesn't support it).'''
        ...
    
    @classmethod
    @property
    def INVALID_CHARACTER_ERR(cls) -> int:
        '''If an invalid or illegal character is specified, such as in an XML name.'''
        ...
    
    @classmethod
    @property
    def NO_DATA_ALLOWED_ERR(cls) -> int:
        '''If data is specified for a Node which does not support data.'''
        ...
    
    @classmethod
    @property
    def NO_MODIFICATION_ALLOWED_ERR(cls) -> int:
        '''If an attempt is made to modify an object where modifications are not allowed.'''
        ...
    
    @classmethod
    @property
    def NOT_FOUND_ERR(cls) -> int:
        '''If an attempt is made to reference a Node in a context where it does not exist.'''
        ...
    
    @classmethod
    @property
    def NOT_SUPPORTED_ERR(cls) -> int:
        '''If the implementation does not support the requested type of object or operation.'''
        ...
    
    @classmethod
    @property
    def INUSE_ATTRIBUTE_ERR(cls) -> int:
        '''If an attempt is made to add an attribute that is already in use elsewhere.'''
        ...
    
    @classmethod
    @property
    def INVALID_STATE_ERR(cls) -> int:
        '''If an attempt is made to use an object that is not, or is no longer, usable.'''
        ...
    
    @classmethod
    @property
    def SYNTAX_ERR(cls) -> int:
        '''If an invalid or illegal string is specified.'''
        ...
    
    @classmethod
    @property
    def INVALID_MODIFICATION_ERR(cls) -> int:
        '''If an attempt is made to modify the type of the underlying object.'''
        ...
    
    @classmethod
    @property
    def NAMESPACE_ERR(cls) -> int:
        '''If an attempt is made to create or change an object in a way which is incorrect with regard to namespaces.'''
        ...
    
    @classmethod
    @property
    def INVALID_ACCESS_ERR(cls) -> int:
        '''If a parameter or an operation is not supported by the underlying object.'''
        ...
    
    @classmethod
    @property
    def VALIDATION_ERR(cls) -> int:
        '''If a call to a method such as insertBefore or removeChild would make the Node invalid with respect to "partial validity", this exception would be raised and the operation would not be done. This code is used in [DOM Level 3 Validation]. Refer to this specification for further information.'''
        ...
    
    @classmethod
    @property
    def TYPE_MISMATCH_ERR(cls) -> int:
        '''If the type of an object is incompatible with the expected type of the parameter associated to the object.'''
        ...
    
    @classmethod
    @property
    def SECURITY_ERR(cls) -> int:
        '''The operation is insecure.'''
        ...
    
    @classmethod
    @property
    def NETWORK_ERR(cls) -> int:
        '''A network error occurred.'''
        ...
    
    @classmethod
    @property
    def ABORT_ERR(cls) -> int:
        '''The operation was aborted.'''
        ...
    
    @classmethod
    @property
    def URL_MISMATCH_ERR(cls) -> int:
        '''The given URL does not match another URL.'''
        ...
    
    @classmethod
    @property
    def QUOTA_EXCEEDED_ERR(cls) -> int:
        '''The quota has been exceeded.'''
        ...
    
    @classmethod
    @property
    def TIMEOUT_ERR(cls) -> int:
        '''The operation timed out.'''
        ...
    
    @classmethod
    @property
    def INVALID_NODE_TYPE_ERR(cls) -> int:
        '''The supplied node is incorrect or has an incorrect ancestor for this operation.'''
        ...
    
    @classmethod
    @property
    def DATA_CLONE_ERR(cls) -> int:
        '''The object can not be cloned.'''
        ...
    
    @classmethod
    @property
    def INVALID_EXPRESSION_ERR(cls) -> int:
        '''The expression has a syntax error or otherwise is not a legal expression according to the rules of the specific
        XPathEvaluator or contains specialized extension functions or variables not supported by this implementation.'''
        ...
    
    @classmethod
    @property
    def TYPE_ERR(cls) -> int:
        '''The expression cannot be converted to return the specified type.'''
        ...
    
    ...

class DOMObject:
    '''The DOMObject type is used to represent an base object for the entire Document Object Model.
    For Java and ECMAScript, DOMObject is bound to the Object type.'''
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    ...

class Document(Node):
    '''The Document represents the entire HTML, XML or SVG document. Conceptually, it is the root of the document tree, and provides the primary access to the document's data.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def navigate(self, address : str):
        '''Loads the document at the specified Uniform Resource Locator (URL) into the current instance, replacing the previous content.
        
        :param address: The document address. It will be combined with the current directory path to form an absolute URL.'''
        ...
    
    @overload
    def navigate(self, url : aspose.svg.Url):
        '''Loads the document at the specified Uniform Resource Locator (URL) into the current instance, replacing the previous content.
        
        :param url: The document URL.'''
        ...
    
    @overload
    def navigate(self, content : str, base_uri : str):
        '''Loads the document from specified content and using baseUri to resolve relative resources, replacing the previous content.
        
        :param content: The document content.
        :param base_uri: The base URI to resolve relative resources. It will be combined with the current directory path to form an absolute URL.'''
        ...
    
    @overload
    def navigate(self, content : str, base_uri : aspose.svg.Url):
        '''Loads the document from specified content and using baseUri to resolve relative resources, replacing the previous content.
        
        :param content: The document content.
        :param base_uri: The base URI to resolve relative resources.'''
        ...
    
    @overload
    def navigate(self, content : io.RawIOBase, base_uri : str):
        '''Loads the document from specified content and using baseUri to resolve relative resources, replacing the previous content.
        Document loading starts from the current position in the stream.
        
        :param content: The document content.
        :param base_uri: The base URI to resolve relative resources. It will be combined with the current directory path to form an absolute URL.'''
        ...
    
    @overload
    def navigate(self, content : io.RawIOBase, base_uri : aspose.svg.Url):
        '''Loads the document from specified content and using baseUri to resolve relative resources, replacing the previous content.
        Document loading starts from the current position in the stream.
        
        :param content: The document content.
        :param base_uri: The base URI to resolve relative resources.'''
        ...
    
    @overload
    def navigate(self, request : aspose.svg.net.RequestMessage):
        '''Loads the document based on specified request object, replacing the previous content.
        
        :param request: The request object that is used to load document content.'''
        ...
    
    @overload
    def create_node_iterator(self, root : aspose.svg.dom.Node) -> aspose.svg.dom.traversal.INodeIterator:
        '''Create a new NodeIterator over the subtree rooted at the
        specified node.
        
        :param root: node which will be iterated together with its children.
        The iterator is initially positioned just before this node. The
        whatToShow flags and the filter, if any, are not
        considered when setting this position. The root must not be
        null.
        :returns: The newly created NodeIterator.'''
        ...
    
    @overload
    def create_node_iterator(self, root : aspose.svg.dom.Node, what_to_show : int) -> aspose.svg.dom.traversal.INodeIterator:
        '''Create a new NodeIterator over the subtree rooted at the
        specified node.
        
        :param root: node which will be iterated together with its children.
        The iterator is initially positioned just before this node. The
        whatToShow flags and the filter, if any, are not
        considered when setting this position. The root must not be
        null.
        :param what_to_show: flag specifies which node types may appear in
        the logical view of the tree presented by the iterator. See the
        description of NodeFilter for the set of possible
        SHOW_ values.These flags can be combined using
        OR.
        :returns: The newly created NodeIterator.'''
        ...
    
    @overload
    def create_node_iterator(self, root : aspose.svg.dom.Node, what_to_show : int, filter : aspose.svg.dom.traversal.INodeFilter) -> aspose.svg.dom.traversal.INodeIterator:
        '''Create a new NodeIterator over the subtree rooted at the
        specified node.
        
        :param root: node which will be iterated together with its children.
        The iterator is initially positioned just before this node. The
        whatToShow flags and the filter, if any, are not
        considered when setting this position. The root must not be
        null.
        :param what_to_show: flag specifies which node types may appear in
        the logical view of the tree presented by the iterator. See the
        description of NodeFilter for the set of possible
        SHOW_ values.These flags can be combined using
        OR.
        :param filter: NodeFilter to be used with this
        TreeWalker, or null to indicate no filter.
        :returns: The newly created NodeIterator.'''
        ...
    
    @overload
    def create_tree_walker(self, root : aspose.svg.dom.Node) -> aspose.svg.dom.traversal.ITreeWalker:
        '''Create a new TreeWalker over the subtree rooted at the
        specified node.
        
        :param root: node which will serve as the root for the
        TreeWalker. The whatToShow flags and the
        NodeFilter are not considered when setting this value;
        any node type will be accepted as the root. The
        currentNode of the TreeWalker is
        initialized to this node, whether or not it is visible. The
        root functions as a stopping point for traversal
        methods that look upward in the document structure, such as
        parentNode and nextNode. The root must
        not be null.
        :returns: The newly created TreeWalker.'''
        ...
    
    @overload
    def create_tree_walker(self, root : aspose.svg.dom.Node, what_to_show : int) -> aspose.svg.dom.traversal.ITreeWalker:
        '''Create a new TreeWalker over the subtree rooted at the
        specified node.
        
        :param root: node which will serve as the root for the
        TreeWalker. The whatToShow flags and the
        NodeFilter are not considered when setting this value;
        any node type will be accepted as the root. The
        currentNode of the TreeWalker is
        initialized to this node, whether or not it is visible. The
        root functions as a stopping point for traversal
        methods that look upward in the document structure, such as
        parentNode and nextNode. The root must
        not be null.
        :param what_to_show: flag specifies which node types may appear in
        the logical view of the tree presented by the tree-walker. See the
        description of NodeFilter for the set of possible
        SHOW_ values.These flags can be combined using OR.
        :returns: The newly created TreeWalker.'''
        ...
    
    @overload
    def create_tree_walker(self, root : aspose.svg.dom.Node, what_to_show : int, filter : aspose.svg.dom.traversal.INodeFilter) -> aspose.svg.dom.traversal.ITreeWalker:
        '''Create a new TreeWalker over the subtree rooted at the
        specified node.
        
        :param root: node which will serve as the root for the
        TreeWalker. The whatToShow flags and the
        NodeFilter are not considered when setting this value;
        any node type will be accepted as the root. The
        currentNode of the TreeWalker is
        initialized to this node, whether or not it is visible. The
        root functions as a stopping point for traversal
        methods that look upward in the document structure, such as
        parentNode and nextNode. The root must
        not be null.
        :param what_to_show: flag specifies which node types may appear in
        the logical view of the tree presented by the tree-walker. See the
        description of NodeFilter for the set of possible
        SHOW_ values.These flags can be combined using OR.
        :param filter: NodeFilter to be used with this
        TreeWalker, or null to indicate no filter.
        :returns: The newly created TreeWalker.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def create_element(self, local_name : str) -> aspose.svg.dom.Element:
        '''Creates an element of the type specified. Note that the instance returned implements the Element interface, so attributes can be specified directly on the returned object.
        
        :param local_name: Name of the tag.
        :returns: The :py:class:`aspose.svg.dom.Element`.'''
        ...
    
    def create_element_ns(self, namespace_uri : str, qualified_name : str) -> aspose.svg.dom.Element:
        '''Creates an element of the given qualified name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :returns: The :py:class:`aspose.svg.dom.Element`.'''
        ...
    
    def create_document_fragment(self) -> aspose.svg.dom.DocumentFragment:
        '''Creates an empty DocumentFragment object.
        
        :returns: The :py:class:`aspose.svg.dom.DocumentFragment`.'''
        ...
    
    def create_text_node(self, data : str) -> aspose.svg.dom.Text:
        '''Creates a Text node given the specified string.
        
        :param data: The text data.
        :returns: The :py:class:`aspose.svg.dom.Text`.'''
        ...
    
    def create_comment(self, data : str) -> aspose.svg.dom.Comment:
        '''Creates a Comment node given the specified string.
        
        :param data: The comment data.
        :returns: The :py:class:`aspose.svg.dom.Comment`.'''
        ...
    
    def create_cdata_section(self, data : str) -> aspose.svg.dom.CDATASection:
        '''Creates a CDATASection node whose value is the specified string.
        
        :param data: The CDATA data.
        :returns: The :py:class:`aspose.svg.dom.CDATASection`.'''
        ...
    
    def create_processing_instruction(self, target : str, data : str) -> aspose.svg.dom.ProcessingInstruction:
        '''Creates a ProcessingInstruction node given the specified name and data strings.
        
        :param target: The target.
        :param data: The instruction data.
        :returns: The :py:class:`aspose.svg.dom.ProcessingInstruction`.'''
        ...
    
    def create_attribute(self, local_name : str) -> aspose.svg.dom.Attr:
        '''Creates an Attr of the given name.
        
        :param local_name: The attribute name.
        :returns: The :py:class:`aspose.svg.dom.Attr`.'''
        ...
    
    def create_attribute_ns(self, namespace_uri : str, qualified_name : str) -> aspose.svg.dom.Attr:
        '''Creates an attribute of the given qualified name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :returns: The :py:class:`aspose.svg.dom.Attr`.'''
        ...
    
    def create_entity_reference(self, name : str) -> aspose.svg.dom.EntityReference:
        '''Creates an EntityReference object. In addition, if the referenced entity is known, the child list of the EntityReference node is made the same as that of the corresponding Entity node.
        
        :param name: The entity name.
        :returns: The :py:class:`aspose.svg.dom.EntityReference`.'''
        ...
    
    def create_document_type(self, name : str, public_id : str, system_id : str, internal_subset : str) -> aspose.svg.dom.DocumentType:
        '''Creates a DocumentType node.
        
        :param name: The document type name.
        :param public_id: The public id.
        :param system_id: The system id.
        :param internal_subset: The internal subset.
        :returns: The :py:class:`aspose.svg.dom.DocumentType`.'''
        ...
    
    def get_elements_by_tag_name(self, tagname : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all the Elements in document order with a given tag name and are contained in the document.
        
        :param tagname: The tagname.
        :returns: Returns nodes.'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all the Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns nodes'''
        ...
    
    def get_element_by_id(self, element_id : str) -> aspose.svg.dom.Element:
        '''Returns the Element that has an ID attribute with the given value. If no such element exists, this returns null. If more than one element has an ID attribute with that value, what is returned is undefined.
        
        :param element_id: The element id.
        :returns: The :py:class:`aspose.svg.dom.Element`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.svg.dom.Element`.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.svg.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The query selector
        :returns: :py:class:`aspose.svg.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.svg.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched node.'''
        ...
    
    def import_node(self, imported_node : aspose.svg.dom.Node, deep : bool) -> aspose.svg.dom.Node:
        '''Imports a node from another document to this document, without altering or removing the source node from the original document; this method creates a new copy of the source node.
        
        :param imported_node: The imported node.
        :param deep: if set to ``true`` [deep].
        :returns: The :py:class:`aspose.svg.dom.Node`.'''
        ...
    
    def create_event(self, event_type : str) -> aspose.svg.dom.events.Event:
        '''Creates an :py:class:`aspose.svg.dom.events.Event` of a type supported by the implementation.
        
        :param event_type: The eventType parameter specifies the type of :py:class:`aspose.svg.dom.events.Event` interface to be created.
        :returns: The newly created :py:class:`aspose.svg.dom.events.Event`'''
        ...
    
    def write(self, texts : List[str]):
        '''Write a string of text to a document stream opened by
        open(). Note that the function will produce a document
        which is not necessarily driven by a DTD and therefore might be
        produce an invalid result in the context of the document.
        
        :param texts: The string to be parsed into some structure in the
        document structure model.'''
        ...
    
    def write_ln(self, texts : List[str]):
        '''Write a string of text followed by a newline character to a document
        stream opened by open(). Note that the function will
        produce a document which is not necessarily driven by a DTD and
        therefore might be produce an invalid result in the context of the
        document
        
        :param texts: The string to be parsed into some structure in the
        document structure model.'''
        ...
    
    def create_expression(self, expression : str, resolver : aspose.svg.dom.xpath.IXPathNSResolver) -> aspose.svg.dom.xpath.IXPathExpression:
        '''Creates a parsed XPath expression with resolved namespaces. This is useful
        when an expression will be reused in an application since it makes it possible
        to compile the expression string into a more efficient internal form and
        preresolve all namespace prefixes which occur within the expression.
        
        :param expression: The XPath expression string to be parsed.
        :param resolver: The ``resolver`` permits translation of all prefixes,
        including the ``xml`` namespace prefix, within the XPath expression into
        appropriate namespace URIs. If this is specified as ``null``, any namespace
        prefix within the expression will result in :py:class:`aspose.svg.dom.DOMException` being
        thrown with the code ``NAMESPACE_ERR``.
        :returns: The compiled form of the XPath expression.'''
        ...
    
    def create_ns_resolver(self, node_resolver : aspose.svg.dom.Node) -> aspose.svg.dom.xpath.IXPathNSResolver:
        '''Adapts any DOM node to resolve namespaces so that an XPath expression can be easily evaluated
        relative to the context of the node where it appeared within the document. This adapter works
        like the DOM Level 3 method ``lookupNamespaceURI`` on nodes in resolving the namespaceURI
        from a given prefix using the current information available in the node's hierarchy at the time
        lookupNamespaceURI is called, also correctly resolving the implicit xml prefix.
        
        :param node_resolver: The node to be used as a context for namespace resolution.
        :returns: :py:class:`aspose.svg.dom.xpath.IXPathNSResolver` which resolves namespaces with respect to the definitions in scope for a specified node.'''
        ...
    
    def evaluate(self, expression : str, context_node : aspose.svg.dom.Node, resolver : aspose.svg.dom.xpath.IXPathNSResolver, type : aspose.svg.dom.xpath.XPathResultType, result : any) -> aspose.svg.dom.xpath.IXPathResult:
        '''Evaluates an XPath expression string and returns a result of the specified type if possible.
        
        :param expression: The XPath expression string to be parsed and evaluated.
        :param context_node: The context is context node for the evaluation of this XPath expression.
        :param resolver: The resolver permits translation of all prefixes, including the xml
        namespace prefix, within the XPath expression into appropriate namespace URIs.
        :param type: If a specific type is specified, then the result will be returned as the corresponding type.
        :param result: The result specifies a specific result object which may be reused and returned by this method.
        :returns: The result of the evaluation of the XPath expression.'''
        ...
    
    def render_to(self, device : aspose.svg.rendering.IDevice):
        '''This method is used to render the contents of the current document to a specified graphical device.
        
        :param device: The user device.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def context(self) -> aspose.svg.dom.IBrowsingContext:
        '''Gets the current browsing context.'''
        ...
    
    @property
    def implementation(self) -> aspose.svg.dom.IDOMImplementation:
        '''The DOMImplementation object that handles this document.'''
        ...
    
    @property
    def location(self) -> aspose.svg.window.Location:
        '''The location of the document.'''
        ...
    
    @property
    def document_uri(self) -> str:
        ...
    
    @property
    def origin(self) -> str:
        '''Gets the document origin.'''
        ...
    
    @property
    def character_set(self) -> str:
        ...
    
    @property
    def charset(self) -> str:
        '''Gets the document's encoding.'''
        ...
    
    @property
    def input_encoding(self) -> str:
        ...
    
    @property
    def content_type(self) -> str:
        ...
    
    @property
    def ready_state(self) -> str:
        ...
    
    @property
    def doctype(self) -> aspose.svg.dom.DocumentType:
        '''The Document Type Declaration associated with this document.'''
        ...
    
    @property
    def document_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def first_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.svg.collections.HTMLCollection:
        '''Returns the child elements.'''
        ...
    
    @property
    def xml_standalone(self) -> bool:
        ...
    
    @xml_standalone.setter
    def xml_standalone(self, value : bool):
        ...
    
    @property
    def xml_version(self) -> str:
        ...
    
    @xml_version.setter
    def xml_version(self, value : str):
        ...
    
    @property
    def strict_error_checking(self) -> bool:
        ...
    
    @strict_error_checking.setter
    def strict_error_checking(self, value : bool):
        ...
    
    @property
    def default_view(self) -> aspose.svg.window.IWindow:
        ...
    
    @property
    def style_sheets(self) -> aspose.svg.dom.css.IStyleSheetList:
        ...
    
    ...

class DocumentFragment(Node):
    '''DocumentFragment is a "lightweight" or "minimal" Document object. It is very common to want to be able to extract a portion of a document's tree or to create a new fragment of a document.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def query_selector(self, selector : str) -> aspose.svg.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.svg.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.svg.collections.HTMLCollection`'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def children(self) -> aspose.svg.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    ...

class DocumentType(Node):
    '''The DocumentType provides an interface to the list of entities that are defined for the document'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def name(self) -> str:
        '''The name of DTD; i.e., the name immediately following the DOCTYPE keyword.'''
        ...
    
    @property
    def public_id(self) -> str:
        ...
    
    @property
    def system_id(self) -> str:
        ...
    
    @property
    def internal_subset(self) -> str:
        ...
    
    ...

class Element(Node):
    '''The Element interface represents an element in an HTML or XML document.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.svg.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.svg.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.svg.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.svg.dom.ShadowRootMode) -> aspose.svg.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.svg.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.svg.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The element's identifier. See the id attribute definition in HTML 4.01.'''
        ...
    
    @property
    def class_name(self) -> str:
        ...
    
    @class_name.setter
    def class_name(self, value : str):
        ...
    
    @property
    def attributes(self) -> aspose.svg.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.svg.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.svg.dom.ShadowRoot:
        ...
    
    ...

class Entity(Node):
    '''Represents a known entity, either parsed or unparsed, in an XML document.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def public_id(self) -> str:
        ...
    
    @property
    def system_id(self) -> str:
        ...
    
    @property
    def notation_name(self) -> str:
        ...
    
    @property
    def input_encoding(self) -> str:
        ...
    
    @property
    def xml_encoding(self) -> str:
        ...
    
    @property
    def xml_version(self) -> str:
        ...
    
    ...

class EntityReference(Node):
    '''EntityReference nodes may be used to represent an entity reference in the tree.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    ...

class EventTarget(DOMObject):
    '''The :py:class:`aspose.svg.dom.EventTarget` interface is implemented by all Nodes in an implementation which supports the DOM Event Model.
    Therefore, this interface can be obtained by using binding-specific casting methods on an instance of the Node interface.
    The interface allows registration and removal of Event Listeners on an :py:class:`aspose.svg.dom.EventTarget` and dispatch of events to that :py:class:`aspose.svg.dom.events.IEventTarget`.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    ...

class IBrowsingContext:
    '''A browsing context is an environment in which :py:class:`aspose.svg.dom.Document` objects are presented to the user.'''
    
    @property
    def security(self) -> aspose.svg.Sandbox:
        '''Gets the sandboxing flag.'''
        ...
    
    @property
    def parent(self) -> aspose.svg.dom.IBrowsingContext:
        '''Gets the parent context, if any.'''
        ...
    
    @property
    def active_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def window(self) -> aspose.svg.window.IWindow:
        '''Gets the WindowProxy object.'''
        ...
    
    @property
    def network(self) -> aspose.svg.net.INetwork:
        '''Gets the network services.'''
        ...
    
    @property
    def dom_implementation(self) -> aspose.svg.dom.IDOMImplementation:
        ...
    
    ...

class IChildNode:
    '''Defines :py:class:`aspose.svg.dom.IChildNode` interface that should be implemented by :py:class:`aspose.svg.dom.Node` that can have a parent.'''
    
    def remove(self):
        '''Removes the current node from parent.'''
        ...
    
    ...

class IDOMImplementation:
    '''The DOMImplementation interface provides a number of methods for performing operations that are independent of any particular instance of the document object model.'''
    
    def has_feature(self) -> bool:
        '''Test if the DOM implementation implements a specific feature and version, as specified in DOM Features.
        
        :returns: ``true`` if the specified feature has feature; otherwise, ``false``.'''
        ...
    
    def create_document_type(self, qualified_name : str, public_id : str, system_id : str) -> aspose.svg.dom.DocumentType:
        '''Creates an empty DocumentType node. Entity declarations and notations are not made available. Entity reference expansions and default attribute additions do not occur.
        
        :param qualified_name: Name of the qualified.
        :param public_id: The public id.
        :param system_id: The system id.
        :returns: The :py:class:`aspose.svg.dom.DocumentType`.'''
        ...
    
    def create_document(self, namespace_uri : str, qualified_name : str, doctype : aspose.svg.dom.DocumentType) -> aspose.svg.dom.Document:
        '''Creates a DOM Document object of the specified type with its document element.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param doctype: The doctype.
        :returns: Returns document.'''
        ...
    
    def create_html_document(self, title : str) -> aspose.svg.dom.Document:
        '''Returns a document, with a basic tree already constructed including a title element, unless the title argument is omitted.
        
        :param title: The title.
        :returns: Returns document.'''
        ...
    
    ...

class IGlobalEventHandlers:
    '''Represents interface that must be inherited by all element that is supported system event handling'''
    
    ...

class INonDocumentTypeChildNode:
    '''Defines :py:class:`aspose.svg.dom.IChildNode` that are not :py:attr:`aspose.svg.dom.Node.DOCUMENT_TYPE_NODE`.'''
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    ...

class INonElementParentNode:
    '''Defines :py:class:`aspose.svg.dom.IParentNode` that are not Element type.'''
    
    def get_element_by_id(self, element_id : str) -> aspose.svg.dom.Element:
        '''Returns the first element within node's descendants whose ID is elementId.
        
        :param element_id: The element identifier.
        :returns: Returns the first matched element.'''
        ...
    
    ...

class IParentNode(aspose.svg.dom.traversal.IElementTraversal):
    '''Defines the :py:class:`aspose.svg.dom.IParentNode` interface that is implemented by any possible parents.'''
    
    def query_selector(self, selectors : str) -> aspose.svg.dom.Element:
        '''Returns the first element that is a descendant of node that matches selectors.
        
        :param selectors: The selectors.
        :returns: Returns the first matched element.'''
        ...
    
    def query_selector_all(self, selectors : str) -> aspose.svg.collections.NodeList:
        '''Returns all element descendants of node that match selectors.
        
        :param selectors: The selectors.
        :returns: Returns the static result of running scope-match a selectors string selectors against the context object.'''
        ...
    
    @property
    def children(self) -> aspose.svg.collections.HTMLCollection:
        '''Returns the child elements.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    ...

class IStorage:
    '''This interface of the Web Storage API provides access to a particular domain's session or local storage.
    See Web Storage specification: :link:`https://html.spec.whatwg.org/multipage/webstorage.html#webstorage`'''
    
    def key(self, n : int) -> str:
        '''Returns the name of the nth key, or null if n is greater than or equal to the number of key/value pairs.
        
        :param n: Number of storage item.
        :returns: Key string.'''
        ...
    
    def get_item(self, key : str) -> str:
        '''Returns the current value associated with the given key, or null if the given key does not exist.
        
        :param key: Item key string.
        :returns: Item value string.'''
        ...
    
    def set_item(self, key : str, value : str):
        '''Sets the value of the pair identified by key to value, creating a new key/value pair if none existed for key previously.
        
        :param key: Item key string.
        :param value: Item value string.'''
        ...
    
    def remove_item(self, key : str):
        '''Removes the key/value pair with the given key, if a key/value pair with the given key exists.
        
        :param key: Item key string.'''
        ...
    
    def clear(self):
        '''Removes all key/value pairs, if there are any.'''
        ...
    
    @property
    def length(self) -> int:
        '''Returns the number of key/value pairs.'''
        ...
    
    ...

class Node(EventTarget):
    '''The Node interface is the primary datatype for the entire Document object Model. It represents a single node in the document tree.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    ...

class Notation(Node):
    '''Represents a notation declared in the DTD.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def public_id(self) -> str:
        ...
    
    @property
    def system_id(self) -> str:
        ...
    
    ...

class ProcessingInstruction(CharacterData):
    '''The ProcessingInstruction represents a "processing instruction", used in XML as a way to keep processor-specific information in the text of the document.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def substring_data(self, offset : int, count : int) -> str:
        '''Extracts a range of data from the node.
        
        :param offset: The offset.
        :param count: The count.
        :returns: The text data'''
        ...
    
    def append_data(self, data : str):
        '''Append the string to the end of the character data of the node.
        
        :param data: The content data.'''
        ...
    
    def insert_data(self, offset : int, data : str):
        '''Insert a string at the specified 16-bit unit offset.
        
        :param offset: The offset.
        :param data: The content data.'''
        ...
    
    def delete_data(self, offset : int, count : int):
        '''Remove a range of 16-bit units from the node.
        
        :param offset: The offset.
        :param count: The count.'''
        ...
    
    def replace_data(self, offset : int, count : int, data : str):
        '''Replace the characters starting at the specified 16-bit unit offset with the specified string.
        
        :param offset: The offset.
        :param count: The count.
        :param data: The content data.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def data(self) -> str:
        '''The character data of the node that implements this interface.'''
        ...
    
    @data.setter
    def data(self, value : str):
        '''The character data of the node that implements this interface.'''
        ...
    
    @property
    def length(self) -> int:
        '''The number of 16-bit units that are available through data and the substringData method below. This may have the value zero, i.e., CharacterData nodes may be empty.'''
        ...
    
    @property
    def target(self) -> str:
        '''The target of this processing instruction.'''
        ...
    
    ...

class QualifiedName:
    '''Represents an HTML qualified name.'''
    
    def equals(self, other : aspose.svg.dom.QualifiedName) -> bool:
        '''Determines whether the specified QualifiedName is equal to the current object.
        
        :param other: The QualifiedName to compare with the current object.
        :returns: true if the specified object is equal to the current object; otherwise, false.'''
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''Gets a string representation of the prefix of the QualifiedName.'''
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def name(self) -> str:
        '''Gets a string representation qualified name.'''
        ...
    
    ...

class ShadowRoot(DocumentFragment):
    '''ShadowRoot is a root node of shadow tree.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def query_selector(self, selector : str) -> aspose.svg.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.svg.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.svg.collections.HTMLCollection`'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def children(self) -> aspose.svg.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def mode(self) -> aspose.svg.dom.ShadowRootMode:
        '''Mode in which this ShadowRoot operates.'''
        ...
    
    @property
    def host(self) -> aspose.svg.dom.Element:
        '''Host is an element which contains this ShadowRoot.'''
        ...
    
    ...

class Text(CharacterData):
    '''The Text interface inherits from CharacterData and represents the textual content (termed character data in XML) of an Element or Attr.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def substring_data(self, offset : int, count : int) -> str:
        '''Extracts a range of data from the node.
        
        :param offset: The offset.
        :param count: The count.
        :returns: The text data'''
        ...
    
    def append_data(self, data : str):
        '''Append the string to the end of the character data of the node.
        
        :param data: The content data.'''
        ...
    
    def insert_data(self, offset : int, data : str):
        '''Insert a string at the specified 16-bit unit offset.
        
        :param offset: The offset.
        :param data: The content data.'''
        ...
    
    def delete_data(self, offset : int, count : int):
        '''Remove a range of 16-bit units from the node.
        
        :param offset: The offset.
        :param count: The count.'''
        ...
    
    def replace_data(self, offset : int, count : int, data : str):
        '''Replace the characters starting at the specified 16-bit unit offset with the specified string.
        
        :param offset: The offset.
        :param count: The count.
        :param data: The content data.'''
        ...
    
    def split_text(self, offset : int) -> aspose.svg.dom.Text:
        '''Breaks this node into two nodes at the specified offset, keeping both in the tree as siblings.
        
        :param offset: The offset.
        :returns: The :py:class:`aspose.svg.dom.Text`.'''
        ...
    
    def replace_whole_text(self, content : str) -> aspose.svg.dom.Text:
        '''Replaces the text of the current node and all logically-adjacent text nodes with the specified text. All logically-adjacent text nodes are removed including the current node unless it was the recipient of the replacement text.
        
        :param content: The content.
        :returns: The :py:class:`aspose.svg.dom.Text`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def data(self) -> str:
        '''The character data of the node that implements this interface.'''
        ...
    
    @data.setter
    def data(self, value : str):
        '''The character data of the node that implements this interface.'''
        ...
    
    @property
    def length(self) -> int:
        '''The number of 16-bit units that are available through data and the substringData method below. This may have the value zero, i.e., CharacterData nodes may be empty.'''
        ...
    
    @property
    def is_element_content_whitespace(self) -> bool:
        ...
    
    @property
    def whole_text(self) -> str:
        ...
    
    ...

class TypeInfo(DOMObject):
    '''The TypeInfo represents a type referenced from Element or Attr nodes, specified in the schemas associated with the document.'''
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def is_derived_from(self, type_namespace_arg : str, type_name_arg : str, derivation_method : int) -> bool:
        '''This method returns if there is a derivation between the reference type definition, i.e. the TypeInfo on which the method is being called, and the other type definition, i.e. the one passed as parameters.
        
        :param type_namespace_arg: the namespace of the other type definition
        :param type_name_arg: the name of the other type definition.
        :param derivation_method: the type of derivation and conditions applied between two types, as described in the list of constants provided in this interface.
        :returns: If the document's schema is a DTD or no schema is associated with the document, this method will always return false. If the document's schema is an XML Schema, the method will true if the reference type definition is derived from the other type definition according to the derivation parameter. If the value of the parameter is 0 (no bit is set to 1 for the derivationMethod parameter), the method will return true if the other type definition can be reached by recursing any combination of {base type definition}, {item type definition}, or {member type definitions} from the reference type definition.'''
        ...
    
    @property
    def type_name(self) -> str:
        ...
    
    @property
    def type_namespace(self) -> str:
        ...
    
    @classmethod
    @property
    def DERIVATION_RESTRICTION(cls) -> int:
        '''If the document's schema is an XML Schema [XML Schema Part 1], this constant represents the derivation by restriction if complex types are involved, or a restriction if simple types are involved.'''
        ...
    
    @classmethod
    @property
    def DERIVATION_EXTENSION(cls) -> int:
        '''If the document's schema is an XML Schema [XML Schema Part 1], this constant represents the derivation by extension.'''
        ...
    
    @classmethod
    @property
    def DERIVATION_UNION(cls) -> int:
        '''If the document's schema is an XML Schema [XML Schema Part 1], this constant represents the union if simple types are involved.'''
        ...
    
    @classmethod
    @property
    def DERIVATION_LIST(cls) -> int:
        '''If the document's schema is an XML Schema [XML Schema Part 1], this constant represents the list.'''
        ...
    
    ...

class ShadowRootMode:
    '''Modes in which ShadowRoot can operate.'''
    
    @classmethod
    @property
    def OPEN(cls) -> ShadowRootMode:
        '''"open" mode.'''
        ...
    
    @classmethod
    @property
    def CLOSED(cls) -> ShadowRootMode:
        '''"closed" mode.'''
        ...
    
    ...

