from typing import List, Optional, Dict, Iterable
import aspose.pycore
import aspose.pydrawing
import aspose.svg
import aspose.svg.builder
import aspose.svg.collections
import aspose.svg.converters
import aspose.svg.datatypes
import aspose.svg.diagnostics
import aspose.svg.dom
import aspose.svg.dom.attributes
import aspose.svg.dom.canvas
import aspose.svg.dom.css
import aspose.svg.dom.events
import aspose.svg.dom.mutations
import aspose.svg.dom.traversal
import aspose.svg.dom.traversal.filters
import aspose.svg.dom.views
import aspose.svg.dom.xpath
import aspose.svg.drawing
import aspose.svg.drawing.skiasharp
import aspose.svg.events
import aspose.svg.filters
import aspose.svg.imagevectorization
import aspose.svg.io
import aspose.svg.net
import aspose.svg.net.headers
import aspose.svg.net.messagefilters
import aspose.svg.net.messagehandlers
import aspose.svg.paths
import aspose.svg.rendering
import aspose.svg.rendering.devices
import aspose.svg.rendering.fonts
import aspose.svg.rendering.image
import aspose.svg.rendering.pdf
import aspose.svg.rendering.pdf.encryption
import aspose.svg.rendering.styles
import aspose.svg.rendering.styles.paintservers
import aspose.svg.rendering.xps
import aspose.svg.saving
import aspose.svg.saving.resourcehandlers
import aspose.svg.services
import aspose.svg.toolkit
import aspose.svg.toolkit.optimizers
import aspose.svg.window

class ISVGFilterPrimitiveStandardAttributes:
    '''This interface defines the set of DOM attributes that are common across the filter primitive interfaces.'''
    
    @property
    def x(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘x’ on the given ‘filter’ element.'''
        ...
    
    @property
    def y(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘y’ on the given ‘filter’ element.'''
        ...
    
    @property
    def width(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘width’ on the given ‘filter’ element.'''
        ...
    
    @property
    def height(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘height’ on the given ‘filter’ element.'''
        ...
    
    @property
    def result(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘result’ on the given ‘filter’ element.'''
        ...
    
    ...

class SVGFEBlendElement(aspose.svg.SVGElement):
    '''The SVGFEBlendElement interface corresponds to the ‘feBlend’ element.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.svg.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.svg.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.svg.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.svg.dom.ShadowRootMode) -> aspose.svg.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.svg.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.svg.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @property
    def class_name(self) -> aspose.svg.datatypes.SVGAnimatedString:
        ...
    
    @property
    def attributes(self) -> aspose.svg.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.svg.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.svg.dom.ShadowRoot:
        ...
    
    @property
    def owner_svg_element(self) -> aspose.svg.SVGSVGElement:
        ...
    
    @property
    def viewport_element(self) -> aspose.svg.SVGElement:
        ...
    
    @property
    def style(self) -> aspose.svg.dom.css.ICSSStyleDeclaration:
        '''Corresponds to attribute ‘style’ on the given element. If the user agent does not support styling with CSS, then this attribute must always have the value of null.'''
        ...
    
    @property
    def x(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘x’ on the given ‘filter’ element.'''
        ...
    
    @property
    def y(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘y’ on the given ‘filter’ element.'''
        ...
    
    @property
    def width(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘width’ on the given ‘filter’ element.'''
        ...
    
    @property
    def height(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘height’ on the given ‘filter’ element.'''
        ...
    
    @property
    def result(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘result’ on the given ‘filter’ element.'''
        ...
    
    @property
    def in1(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘in’ on the given ‘feBlend’ element.'''
        ...
    
    @property
    def in2(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘in2’ on the given ‘feBlend’ element.'''
        ...
    
    @property
    def mode(self) -> aspose.svg.datatypes.SVGAnimatedEnumeration:
        '''Corresponds to attribute ‘mode’ on the given ‘feBlend’ element. Takes one of the SVG_FEBLEND_MODE_* constants defined on this interface.'''
        ...
    
    @classmethod
    @property
    def SVG_FEBLEND_MODE_UNKNOWN(cls) -> int:
        '''The type is not one of predefined types. It is invalid to attempt to define a new value of this type or to attempt to switch an existing value to this type.'''
        ...
    
    @classmethod
    @property
    def SVG_FEBLEND_MODE_NORMAL(cls) -> int:
        '''Corresponds to value 'normal'.'''
        ...
    
    @classmethod
    @property
    def SVG_FEBLEND_MODE_MULTIPLY(cls) -> int:
        '''Corresponds to value 'multiply'.'''
        ...
    
    @classmethod
    @property
    def SVG_FEBLEND_MODE_SCREEN(cls) -> int:
        '''Corresponds to value 'screen'.'''
        ...
    
    @classmethod
    @property
    def SVG_FEBLEND_MODE_DARKEN(cls) -> int:
        '''Corresponds to value 'darken'.'''
        ...
    
    @classmethod
    @property
    def SVG_FEBLEND_MODE_LIGHTEN(cls) -> int:
        '''Corresponds to value 'lighten'.'''
        ...
    
    @classmethod
    @property
    def SVG_FEBLEND_MODE_OVERLAY(cls) -> int:
        '''Corresponds to value 'overlay'.'''
        ...
    
    @classmethod
    @property
    def SVG_FEBLEND_MODE_COLOR_DODGE(cls) -> int:
        '''Corresponds to value 'color_dodge'.'''
        ...
    
    @classmethod
    @property
    def SVG_FEBLEND_MODE_COLOR_BURN(cls) -> int:
        '''Corresponds to value 'color_burn'.'''
        ...
    
    @classmethod
    @property
    def SVG_FEBLEND_MODE_HARD_LIGHT(cls) -> int:
        '''Corresponds to value 'hard_light'.'''
        ...
    
    @classmethod
    @property
    def SVG_FEBLEND_MODE_SOFT_LIGHT(cls) -> int:
        '''Corresponds to value 'soft_light'.'''
        ...
    
    @classmethod
    @property
    def SVG_FEBLEND_MODE_DIFFERENCE(cls) -> int:
        '''Corresponds to value 'difference'.'''
        ...
    
    @classmethod
    @property
    def SVG_FEBLEND_MODE_EXCLUSION(cls) -> int:
        '''Corresponds to value 'exclusion'.'''
        ...
    
    @classmethod
    @property
    def SVG_FEBLEND_MODE_HUE(cls) -> int:
        '''Corresponds to value 'hue'.'''
        ...
    
    @classmethod
    @property
    def SVG_FEBLEND_MODE_SATURATION(cls) -> int:
        '''Corresponds to value 'saturation'.'''
        ...
    
    @classmethod
    @property
    def SVG_FEBLEND_MODE_COLOR(cls) -> int:
        '''Corresponds to value 'color'.'''
        ...
    
    @classmethod
    @property
    def SVG_FEBLEND_MODE_LUMINOSITY(cls) -> int:
        '''Corresponds to value 'luminosity'.'''
        ...
    
    ...

class SVGFEColorMatrixElement(aspose.svg.SVGElement):
    '''The SVGFEColorMatrixElement interface corresponds to the ‘feColorMatrix’ element.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.svg.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.svg.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.svg.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.svg.dom.ShadowRootMode) -> aspose.svg.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.svg.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.svg.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @property
    def class_name(self) -> aspose.svg.datatypes.SVGAnimatedString:
        ...
    
    @property
    def attributes(self) -> aspose.svg.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.svg.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.svg.dom.ShadowRoot:
        ...
    
    @property
    def owner_svg_element(self) -> aspose.svg.SVGSVGElement:
        ...
    
    @property
    def viewport_element(self) -> aspose.svg.SVGElement:
        ...
    
    @property
    def style(self) -> aspose.svg.dom.css.ICSSStyleDeclaration:
        '''Corresponds to attribute ‘style’ on the given element. If the user agent does not support styling with CSS, then this attribute must always have the value of null.'''
        ...
    
    @property
    def x(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘x’ on the given ‘filter’ element.'''
        ...
    
    @property
    def y(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘y’ on the given ‘filter’ element.'''
        ...
    
    @property
    def width(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘width’ on the given ‘filter’ element.'''
        ...
    
    @property
    def height(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘height’ on the given ‘filter’ element.'''
        ...
    
    @property
    def result(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘result’ on the given ‘filter’ element.'''
        ...
    
    @property
    def in1(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘in’ on the given ‘feColorMatrix’ element.'''
        ...
    
    @property
    def type(self) -> aspose.svg.datatypes.SVGAnimatedEnumeration:
        '''Corresponds to attribute ‘type’ on the given ‘feColorMatrix’ element. Takes one of the SVG_FECOLORMATRIX_TYPE_* constants defined on this interface.'''
        ...
    
    @property
    def values(self) -> aspose.svg.datatypes.SVGAnimatedNumberList:
        '''Corresponds to attribute ‘values’ on the given ‘feColorMatrix’ element.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOLORMATRIX_TYPE_UNKNOWN(cls) -> int:
        '''The type is not one of predefined types. It is invalid to attempt to define a new value of this type or to attempt to switch an existing value to this type.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOLORMATRIX_TYPE_MATRIX(cls) -> int:
        '''Corresponds to value 'matrix'.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOLORMATRIX_TYPE_SATURATE(cls) -> int:
        '''Corresponds to value 'saturate'.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOLORMATRIX_TYPE_HUEROTATE(cls) -> int:
        '''Corresponds to value 'hueRotate'.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOLORMATRIX_TYPE_LUMINANCETOALPHA(cls) -> int:
        '''Corresponds to value 'luminanceToAlpha'.'''
        ...
    
    ...

class SVGFEComponentTransferElement(aspose.svg.SVGElement):
    '''The SVGFEComponentTransferElement interface corresponds to the ‘feComponentTransfer’ element.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.svg.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.svg.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.svg.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.svg.dom.ShadowRootMode) -> aspose.svg.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.svg.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.svg.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @property
    def class_name(self) -> aspose.svg.datatypes.SVGAnimatedString:
        ...
    
    @property
    def attributes(self) -> aspose.svg.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.svg.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.svg.dom.ShadowRoot:
        ...
    
    @property
    def owner_svg_element(self) -> aspose.svg.SVGSVGElement:
        ...
    
    @property
    def viewport_element(self) -> aspose.svg.SVGElement:
        ...
    
    @property
    def style(self) -> aspose.svg.dom.css.ICSSStyleDeclaration:
        '''Corresponds to attribute ‘style’ on the given element. If the user agent does not support styling with CSS, then this attribute must always have the value of null.'''
        ...
    
    @property
    def x(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘x’ on the given ‘filter’ element.'''
        ...
    
    @property
    def y(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘y’ on the given ‘filter’ element.'''
        ...
    
    @property
    def width(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘width’ on the given ‘filter’ element.'''
        ...
    
    @property
    def height(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘height’ on the given ‘filter’ element.'''
        ...
    
    @property
    def result(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘result’ on the given ‘filter’ element.'''
        ...
    
    @property
    def in1(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘in’ on the given ‘feComponentTransfer’ element.'''
        ...
    
    ...

class SVGFECompositeElement(aspose.svg.SVGElement):
    '''The SVGFECompositeElement interface corresponds to the ‘feComposite’ element.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.svg.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.svg.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.svg.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.svg.dom.ShadowRootMode) -> aspose.svg.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.svg.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.svg.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @property
    def class_name(self) -> aspose.svg.datatypes.SVGAnimatedString:
        ...
    
    @property
    def attributes(self) -> aspose.svg.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.svg.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.svg.dom.ShadowRoot:
        ...
    
    @property
    def owner_svg_element(self) -> aspose.svg.SVGSVGElement:
        ...
    
    @property
    def viewport_element(self) -> aspose.svg.SVGElement:
        ...
    
    @property
    def style(self) -> aspose.svg.dom.css.ICSSStyleDeclaration:
        '''Corresponds to attribute ‘style’ on the given element. If the user agent does not support styling with CSS, then this attribute must always have the value of null.'''
        ...
    
    @property
    def x(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘x’ on the given ‘filter’ element.'''
        ...
    
    @property
    def y(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘y’ on the given ‘filter’ element.'''
        ...
    
    @property
    def width(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘width’ on the given ‘filter’ element.'''
        ...
    
    @property
    def height(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘height’ on the given ‘filter’ element.'''
        ...
    
    @property
    def result(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘result’ on the given ‘filter’ element.'''
        ...
    
    @property
    def in1(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘in’ on the given ‘feComposite’ element.'''
        ...
    
    @property
    def in2(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘in2’ on the given ‘feComposite’ element.'''
        ...
    
    @property
    def operator(self) -> aspose.svg.datatypes.SVGAnimatedEnumeration:
        '''Corresponds to attribute ‘operator’ on the given ‘feComposite’ element. Takes one of the SVG_FECOMPOSITE_OPERATOR_* constants defined on this interface.'''
        ...
    
    @property
    def k1(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘k1’ on the given ‘feComposite’ element.'''
        ...
    
    @property
    def k2(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘k2’ on the given ‘feComposite’ element.'''
        ...
    
    @property
    def k3(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘k3’ on the given ‘feComposite’ element.'''
        ...
    
    @property
    def k4(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘k4’ on the given ‘feComposite’ element.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPOSITE_OPERATOR_UNKNOWN(cls) -> int:
        '''The type is not one of predefined types. It is invalid to attempt to define a new value of this type or to attempt to switch an existing value to this type.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPOSITE_OPERATOR_OVER(cls) -> int:
        '''Corresponds to value 'over'.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPOSITE_OPERATOR_IN(cls) -> int:
        '''Corresponds to value 'in'.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPOSITE_OPERATOR_OUT(cls) -> int:
        '''Corresponds to value 'out'.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPOSITE_OPERATOR_ATOP(cls) -> int:
        '''Corresponds to value 'atop'.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPOSITE_OPERATOR_XOR(cls) -> int:
        '''Corresponds to value 'xor'.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPOSITE_OPERATOR_ARITHMETIC(cls) -> int:
        '''Corresponds to value 'arithmetic'.'''
        ...
    
    ...

class SVGFEConvolveMatrixElement(aspose.svg.SVGElement):
    '''The SVGFEConvolveMatrixElement interface corresponds to the ‘feConvolveMatrix’ element.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.svg.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.svg.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.svg.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.svg.dom.ShadowRootMode) -> aspose.svg.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.svg.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.svg.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @property
    def class_name(self) -> aspose.svg.datatypes.SVGAnimatedString:
        ...
    
    @property
    def attributes(self) -> aspose.svg.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.svg.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.svg.dom.ShadowRoot:
        ...
    
    @property
    def owner_svg_element(self) -> aspose.svg.SVGSVGElement:
        ...
    
    @property
    def viewport_element(self) -> aspose.svg.SVGElement:
        ...
    
    @property
    def style(self) -> aspose.svg.dom.css.ICSSStyleDeclaration:
        '''Corresponds to attribute ‘style’ on the given element. If the user agent does not support styling with CSS, then this attribute must always have the value of null.'''
        ...
    
    @property
    def x(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘x’ on the given ‘filter’ element.'''
        ...
    
    @property
    def y(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘y’ on the given ‘filter’ element.'''
        ...
    
    @property
    def width(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘width’ on the given ‘filter’ element.'''
        ...
    
    @property
    def height(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘height’ on the given ‘filter’ element.'''
        ...
    
    @property
    def result(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘result’ on the given ‘filter’ element.'''
        ...
    
    @property
    def in1(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘in’ on the given ‘feConvolveMatrix’ element.'''
        ...
    
    @property
    def order_x(self) -> aspose.svg.datatypes.SVGAnimatedInteger:
        ...
    
    @property
    def order_y(self) -> aspose.svg.datatypes.SVGAnimatedInteger:
        ...
    
    @property
    def kernel_matrix(self) -> aspose.svg.datatypes.SVGAnimatedNumberList:
        ...
    
    @property
    def divisor(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘divisor’ on the given ‘feConvolveMatrix’ element.'''
        ...
    
    @property
    def bias(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘bias’ on the given ‘feConvolveMatrix’ element.'''
        ...
    
    @property
    def target_x(self) -> aspose.svg.datatypes.SVGAnimatedInteger:
        ...
    
    @property
    def target_y(self) -> aspose.svg.datatypes.SVGAnimatedInteger:
        ...
    
    @property
    def edge_mode(self) -> aspose.svg.datatypes.SVGAnimatedEnumeration:
        ...
    
    @property
    def kernel_unit_length_x(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        ...
    
    @property
    def kernel_unit_length_y(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        ...
    
    @property
    def preserve_alpha(self) -> aspose.svg.datatypes.SVGAnimatedBoolean:
        ...
    
    @classmethod
    @property
    def SVG_EDGEMODE_UNKNOWN(cls) -> int:
        '''The type is not one of predefined types. It is invalid to attempt to define a new value of this type or to attempt to switch an existing value to this type.'''
        ...
    
    @classmethod
    @property
    def SVG_EDGEMODE_DUPLICATE(cls) -> int:
        '''Corresponds to value 'duplicate'.'''
        ...
    
    @classmethod
    @property
    def SVG_EDGEMODE_WRAP(cls) -> int:
        '''Corresponds to value 'wrap'.'''
        ...
    
    @classmethod
    @property
    def SVG_EDGEMODE_NONE(cls) -> int:
        '''Corresponds to value 'none'.'''
        ...
    
    ...

class SVGFEDiffuseLightingElement(aspose.svg.SVGElement):
    '''The SVGFEDiffuseLightingElement interface corresponds to the ‘feDiffuseLighting’ element.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.svg.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.svg.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.svg.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.svg.dom.ShadowRootMode) -> aspose.svg.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.svg.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.svg.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @property
    def class_name(self) -> aspose.svg.datatypes.SVGAnimatedString:
        ...
    
    @property
    def attributes(self) -> aspose.svg.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.svg.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.svg.dom.ShadowRoot:
        ...
    
    @property
    def owner_svg_element(self) -> aspose.svg.SVGSVGElement:
        ...
    
    @property
    def viewport_element(self) -> aspose.svg.SVGElement:
        ...
    
    @property
    def style(self) -> aspose.svg.dom.css.ICSSStyleDeclaration:
        '''Corresponds to attribute ‘style’ on the given element. If the user agent does not support styling with CSS, then this attribute must always have the value of null.'''
        ...
    
    @property
    def x(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘x’ on the given ‘filter’ element.'''
        ...
    
    @property
    def y(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘y’ on the given ‘filter’ element.'''
        ...
    
    @property
    def width(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘width’ on the given ‘filter’ element.'''
        ...
    
    @property
    def height(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘height’ on the given ‘filter’ element.'''
        ...
    
    @property
    def result(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘result’ on the given ‘filter’ element.'''
        ...
    
    @property
    def in1(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘in’ on the given ‘feDiffuseLighting’ element.'''
        ...
    
    @property
    def surface_scale(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        ...
    
    @property
    def diffuse_constant(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        ...
    
    @property
    def kernel_unit_length_x(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        ...
    
    @property
    def kernel_unit_length_y(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        ...
    
    ...

class SVGFEDisplacementMapElement(aspose.svg.SVGElement):
    '''The SVGFEDisplacementMapElement interface corresponds to the ‘feDisplacementMap’ element.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.svg.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.svg.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.svg.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.svg.dom.ShadowRootMode) -> aspose.svg.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.svg.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.svg.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @property
    def class_name(self) -> aspose.svg.datatypes.SVGAnimatedString:
        ...
    
    @property
    def attributes(self) -> aspose.svg.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.svg.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.svg.dom.ShadowRoot:
        ...
    
    @property
    def owner_svg_element(self) -> aspose.svg.SVGSVGElement:
        ...
    
    @property
    def viewport_element(self) -> aspose.svg.SVGElement:
        ...
    
    @property
    def style(self) -> aspose.svg.dom.css.ICSSStyleDeclaration:
        '''Corresponds to attribute ‘style’ on the given element. If the user agent does not support styling with CSS, then this attribute must always have the value of null.'''
        ...
    
    @property
    def x(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘x’ on the given ‘filter’ element.'''
        ...
    
    @property
    def y(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘y’ on the given ‘filter’ element.'''
        ...
    
    @property
    def width(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘width’ on the given ‘filter’ element.'''
        ...
    
    @property
    def height(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘height’ on the given ‘filter’ element.'''
        ...
    
    @property
    def result(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘result’ on the given ‘filter’ element.'''
        ...
    
    @property
    def in1(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘in’ on the given ‘feDisplacementMap’ element.'''
        ...
    
    @property
    def in2(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘in2’ on the given ‘feDisplacementMap’ element.'''
        ...
    
    @property
    def scale(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘scale’ on the given ‘feDisplacementMap’ element.'''
        ...
    
    @property
    def x_channel_selector(self) -> aspose.svg.datatypes.SVGAnimatedEnumeration:
        ...
    
    @property
    def y_channel_selector(self) -> aspose.svg.datatypes.SVGAnimatedEnumeration:
        ...
    
    @classmethod
    @property
    def SVG_CHANNEL_UNKNOWN(cls) -> int:
        '''The type is not one of predefined types. It is invalid to attempt to define a new value of this type or to attempt to switch an existing value to this type.'''
        ...
    
    @classmethod
    @property
    def SVG_CHANNEL_R(cls) -> int:
        '''Corresponds to value 'R'.'''
        ...
    
    @classmethod
    @property
    def SVG_CHANNEL_G(cls) -> int:
        '''Corresponds to value 'G'.'''
        ...
    
    @classmethod
    @property
    def SVG_CHANNEL_B(cls) -> int:
        '''Corresponds to value 'B'.'''
        ...
    
    @classmethod
    @property
    def SVG_CHANNEL_A(cls) -> int:
        '''Corresponds to value 'A'.'''
        ...
    
    ...

class SVGFEDistantLightElement(aspose.svg.SVGElement):
    '''The SVGFEDistantLightElement interface corresponds to the ‘feDistantLight’ element.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.svg.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.svg.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.svg.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.svg.dom.ShadowRootMode) -> aspose.svg.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.svg.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.svg.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @property
    def class_name(self) -> aspose.svg.datatypes.SVGAnimatedString:
        ...
    
    @property
    def attributes(self) -> aspose.svg.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.svg.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.svg.dom.ShadowRoot:
        ...
    
    @property
    def owner_svg_element(self) -> aspose.svg.SVGSVGElement:
        ...
    
    @property
    def viewport_element(self) -> aspose.svg.SVGElement:
        ...
    
    @property
    def style(self) -> aspose.svg.dom.css.ICSSStyleDeclaration:
        '''Corresponds to attribute ‘style’ on the given element. If the user agent does not support styling with CSS, then this attribute must always have the value of null.'''
        ...
    
    @property
    def azimuth(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘azimuth’ on the given ‘feDistantLight’ element.'''
        ...
    
    @property
    def elevation(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘elevation’ on the given ‘feDistantLight’ element.'''
        ...
    
    ...

class SVGFEDropShadowElement(aspose.svg.SVGElement):
    '''The SVGFEDropShadowElement interface corresponds to the ‘feDropShadow’ element.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.svg.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.svg.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.svg.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.svg.dom.ShadowRootMode) -> aspose.svg.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.svg.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.svg.dom.Element`.'''
        ...
    
    def set_std_deviation(self, std_deviation_x : float, std_deviation_y : float):
        '''Sets the values for attribute ‘stdDeviation’.
        
        :param std_deviation_x: The X component of attribute ‘stdDeviation’.
        :param std_deviation_y: The Y component of attribute ‘stdDeviation’.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @property
    def class_name(self) -> aspose.svg.datatypes.SVGAnimatedString:
        ...
    
    @property
    def attributes(self) -> aspose.svg.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.svg.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.svg.dom.ShadowRoot:
        ...
    
    @property
    def owner_svg_element(self) -> aspose.svg.SVGSVGElement:
        ...
    
    @property
    def viewport_element(self) -> aspose.svg.SVGElement:
        ...
    
    @property
    def style(self) -> aspose.svg.dom.css.ICSSStyleDeclaration:
        '''Corresponds to attribute ‘style’ on the given element. If the user agent does not support styling with CSS, then this attribute must always have the value of null.'''
        ...
    
    @property
    def x(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘x’ on the given ‘feDropShadow’ element.'''
        ...
    
    @property
    def y(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘y’ on the given ‘feDropShadow’ element.'''
        ...
    
    @property
    def width(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘width’ on the given ‘feDropShadow’ element.'''
        ...
    
    @property
    def height(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘height’ on the given ‘feDropShadow’ element.'''
        ...
    
    @property
    def result(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘result’ on the given ‘feDropShadow’ element.'''
        ...
    
    @property
    def in1(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘in’ on the given ‘feDropShadow’ element.'''
        ...
    
    @property
    def dx(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘dx’ on the given ‘feDropShadow’ element.'''
        ...
    
    @property
    def dy(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘dy’ on the given ‘feDropShadow’ element.'''
        ...
    
    @property
    def std_deviation_x(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        ...
    
    @property
    def std_deviation_y(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        ...
    
    ...

class SVGFEFloodElement(aspose.svg.SVGElement):
    '''The SVGFEFloodElement interface corresponds to the ‘feFlood’ element.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.svg.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.svg.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.svg.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.svg.dom.ShadowRootMode) -> aspose.svg.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.svg.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.svg.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @property
    def class_name(self) -> aspose.svg.datatypes.SVGAnimatedString:
        ...
    
    @property
    def attributes(self) -> aspose.svg.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.svg.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.svg.dom.ShadowRoot:
        ...
    
    @property
    def owner_svg_element(self) -> aspose.svg.SVGSVGElement:
        ...
    
    @property
    def viewport_element(self) -> aspose.svg.SVGElement:
        ...
    
    @property
    def style(self) -> aspose.svg.dom.css.ICSSStyleDeclaration:
        '''Corresponds to attribute ‘style’ on the given element. If the user agent does not support styling with CSS, then this attribute must always have the value of null.'''
        ...
    
    @property
    def x(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘x’ on the given ‘filter’ element.'''
        ...
    
    @property
    def y(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘y’ on the given ‘filter’ element.'''
        ...
    
    @property
    def width(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘width’ on the given ‘filter’ element.'''
        ...
    
    @property
    def height(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘height’ on the given ‘filter’ element.'''
        ...
    
    @property
    def result(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘result’ on the given ‘filter’ element.'''
        ...
    
    ...

class SVGFEFuncAElement(aspose.svg.SVGComponentTransferFunctionElement):
    '''The SVGFEFuncAElement interface corresponds to the ‘feFuncA’ element.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.svg.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.svg.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.svg.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.svg.dom.ShadowRootMode) -> aspose.svg.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.svg.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.svg.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @property
    def class_name(self) -> aspose.svg.datatypes.SVGAnimatedString:
        ...
    
    @property
    def attributes(self) -> aspose.svg.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.svg.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.svg.dom.ShadowRoot:
        ...
    
    @property
    def owner_svg_element(self) -> aspose.svg.SVGSVGElement:
        ...
    
    @property
    def viewport_element(self) -> aspose.svg.SVGElement:
        ...
    
    @property
    def style(self) -> aspose.svg.dom.css.ICSSStyleDeclaration:
        '''Corresponds to attribute ‘style’ on the given element. If the user agent does not support styling with CSS, then this attribute must always have the value of null.'''
        ...
    
    @property
    def type(self) -> aspose.svg.datatypes.SVGAnimatedEnumeration:
        '''Corresponds to attribute ‘type’ on the given element. Takes one of the SVG_FECOMPONENTTRANSFER_TYPE_* constants defined on this interface.'''
        ...
    
    @property
    def table_values(self) -> aspose.svg.datatypes.SVGAnimatedNumberList:
        ...
    
    @property
    def slope(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘slope’ on the given element.'''
        ...
    
    @property
    def intercept(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘intercept’ on the given element.'''
        ...
    
    @property
    def amplitude(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘amplitude’ on the given element.'''
        ...
    
    @property
    def exponent(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘exponent’ on the given element.'''
        ...
    
    @property
    def offset(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘offset’ on the given element.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPONENTTRANSFER_TYPE_UNKNOWN(cls) -> int:
        '''The type is not one of predefined types. It is invalid to attempt to define a new value of this type or to attempt to switch an existing value to this type.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPONENTTRANSFER_TYPE_IDENTITY(cls) -> int:
        '''Corresponds to value 'identity'.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPONENTTRANSFER_TYPE_TABLE(cls) -> int:
        '''Corresponds to value 'table'.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPONENTTRANSFER_TYPE_DISCRETE(cls) -> int:
        '''Corresponds to value 'discrete'.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPONENTTRANSFER_TYPE_LINEAR(cls) -> int:
        '''Corresponds to value 'linear'.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPONENTTRANSFER_TYPE_GAMMA(cls) -> int:
        '''Corresponds to value 'gamma'.'''
        ...
    
    ...

class SVGFEFuncBElement(aspose.svg.SVGComponentTransferFunctionElement):
    '''The SVGFEFuncBElement interface corresponds to the ‘feFuncB’ element.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.svg.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.svg.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.svg.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.svg.dom.ShadowRootMode) -> aspose.svg.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.svg.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.svg.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @property
    def class_name(self) -> aspose.svg.datatypes.SVGAnimatedString:
        ...
    
    @property
    def attributes(self) -> aspose.svg.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.svg.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.svg.dom.ShadowRoot:
        ...
    
    @property
    def owner_svg_element(self) -> aspose.svg.SVGSVGElement:
        ...
    
    @property
    def viewport_element(self) -> aspose.svg.SVGElement:
        ...
    
    @property
    def style(self) -> aspose.svg.dom.css.ICSSStyleDeclaration:
        '''Corresponds to attribute ‘style’ on the given element. If the user agent does not support styling with CSS, then this attribute must always have the value of null.'''
        ...
    
    @property
    def type(self) -> aspose.svg.datatypes.SVGAnimatedEnumeration:
        '''Corresponds to attribute ‘type’ on the given element. Takes one of the SVG_FECOMPONENTTRANSFER_TYPE_* constants defined on this interface.'''
        ...
    
    @property
    def table_values(self) -> aspose.svg.datatypes.SVGAnimatedNumberList:
        ...
    
    @property
    def slope(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘slope’ on the given element.'''
        ...
    
    @property
    def intercept(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘intercept’ on the given element.'''
        ...
    
    @property
    def amplitude(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘amplitude’ on the given element.'''
        ...
    
    @property
    def exponent(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘exponent’ on the given element.'''
        ...
    
    @property
    def offset(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘offset’ on the given element.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPONENTTRANSFER_TYPE_UNKNOWN(cls) -> int:
        '''The type is not one of predefined types. It is invalid to attempt to define a new value of this type or to attempt to switch an existing value to this type.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPONENTTRANSFER_TYPE_IDENTITY(cls) -> int:
        '''Corresponds to value 'identity'.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPONENTTRANSFER_TYPE_TABLE(cls) -> int:
        '''Corresponds to value 'table'.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPONENTTRANSFER_TYPE_DISCRETE(cls) -> int:
        '''Corresponds to value 'discrete'.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPONENTTRANSFER_TYPE_LINEAR(cls) -> int:
        '''Corresponds to value 'linear'.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPONENTTRANSFER_TYPE_GAMMA(cls) -> int:
        '''Corresponds to value 'gamma'.'''
        ...
    
    ...

class SVGFEFuncGElement(aspose.svg.SVGComponentTransferFunctionElement):
    '''The SVGFEFuncRElement interface corresponds to the ‘feFuncG’ element.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.svg.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.svg.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.svg.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.svg.dom.ShadowRootMode) -> aspose.svg.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.svg.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.svg.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @property
    def class_name(self) -> aspose.svg.datatypes.SVGAnimatedString:
        ...
    
    @property
    def attributes(self) -> aspose.svg.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.svg.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.svg.dom.ShadowRoot:
        ...
    
    @property
    def owner_svg_element(self) -> aspose.svg.SVGSVGElement:
        ...
    
    @property
    def viewport_element(self) -> aspose.svg.SVGElement:
        ...
    
    @property
    def style(self) -> aspose.svg.dom.css.ICSSStyleDeclaration:
        '''Corresponds to attribute ‘style’ on the given element. If the user agent does not support styling with CSS, then this attribute must always have the value of null.'''
        ...
    
    @property
    def type(self) -> aspose.svg.datatypes.SVGAnimatedEnumeration:
        '''Corresponds to attribute ‘type’ on the given element. Takes one of the SVG_FECOMPONENTTRANSFER_TYPE_* constants defined on this interface.'''
        ...
    
    @property
    def table_values(self) -> aspose.svg.datatypes.SVGAnimatedNumberList:
        ...
    
    @property
    def slope(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘slope’ on the given element.'''
        ...
    
    @property
    def intercept(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘intercept’ on the given element.'''
        ...
    
    @property
    def amplitude(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘amplitude’ on the given element.'''
        ...
    
    @property
    def exponent(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘exponent’ on the given element.'''
        ...
    
    @property
    def offset(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘offset’ on the given element.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPONENTTRANSFER_TYPE_UNKNOWN(cls) -> int:
        '''The type is not one of predefined types. It is invalid to attempt to define a new value of this type or to attempt to switch an existing value to this type.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPONENTTRANSFER_TYPE_IDENTITY(cls) -> int:
        '''Corresponds to value 'identity'.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPONENTTRANSFER_TYPE_TABLE(cls) -> int:
        '''Corresponds to value 'table'.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPONENTTRANSFER_TYPE_DISCRETE(cls) -> int:
        '''Corresponds to value 'discrete'.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPONENTTRANSFER_TYPE_LINEAR(cls) -> int:
        '''Corresponds to value 'linear'.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPONENTTRANSFER_TYPE_GAMMA(cls) -> int:
        '''Corresponds to value 'gamma'.'''
        ...
    
    ...

class SVGFEFuncRElement(aspose.svg.SVGComponentTransferFunctionElement):
    '''The SVGFEFuncRElement interface corresponds to the ‘feFuncR’ element.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.svg.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.svg.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.svg.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.svg.dom.ShadowRootMode) -> aspose.svg.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.svg.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.svg.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @property
    def class_name(self) -> aspose.svg.datatypes.SVGAnimatedString:
        ...
    
    @property
    def attributes(self) -> aspose.svg.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.svg.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.svg.dom.ShadowRoot:
        ...
    
    @property
    def owner_svg_element(self) -> aspose.svg.SVGSVGElement:
        ...
    
    @property
    def viewport_element(self) -> aspose.svg.SVGElement:
        ...
    
    @property
    def style(self) -> aspose.svg.dom.css.ICSSStyleDeclaration:
        '''Corresponds to attribute ‘style’ on the given element. If the user agent does not support styling with CSS, then this attribute must always have the value of null.'''
        ...
    
    @property
    def type(self) -> aspose.svg.datatypes.SVGAnimatedEnumeration:
        '''Corresponds to attribute ‘type’ on the given element. Takes one of the SVG_FECOMPONENTTRANSFER_TYPE_* constants defined on this interface.'''
        ...
    
    @property
    def table_values(self) -> aspose.svg.datatypes.SVGAnimatedNumberList:
        ...
    
    @property
    def slope(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘slope’ on the given element.'''
        ...
    
    @property
    def intercept(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘intercept’ on the given element.'''
        ...
    
    @property
    def amplitude(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘amplitude’ on the given element.'''
        ...
    
    @property
    def exponent(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘exponent’ on the given element.'''
        ...
    
    @property
    def offset(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘offset’ on the given element.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPONENTTRANSFER_TYPE_UNKNOWN(cls) -> int:
        '''The type is not one of predefined types. It is invalid to attempt to define a new value of this type or to attempt to switch an existing value to this type.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPONENTTRANSFER_TYPE_IDENTITY(cls) -> int:
        '''Corresponds to value 'identity'.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPONENTTRANSFER_TYPE_TABLE(cls) -> int:
        '''Corresponds to value 'table'.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPONENTTRANSFER_TYPE_DISCRETE(cls) -> int:
        '''Corresponds to value 'discrete'.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPONENTTRANSFER_TYPE_LINEAR(cls) -> int:
        '''Corresponds to value 'linear'.'''
        ...
    
    @classmethod
    @property
    def SVG_FECOMPONENTTRANSFER_TYPE_GAMMA(cls) -> int:
        '''Corresponds to value 'gamma'.'''
        ...
    
    ...

class SVGFEGaussianBlurElement(aspose.svg.SVGElement):
    '''The SVGFEGaussianBlurElement interface corresponds to the �feGaussianBlur� element.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.svg.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.svg.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.svg.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.svg.dom.ShadowRootMode) -> aspose.svg.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.svg.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.svg.dom.Element`.'''
        ...
    
    def set_std_deviation(self, std_deviation_x : float, std_deviation_y : float):
        '''Sets the values for attribute �stdDeviation�.
        
        :param std_deviation_x: The X component of attribute �stdDeviation�.
        :param std_deviation_y: The Y component of attribute �stdDeviation�.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @property
    def class_name(self) -> aspose.svg.datatypes.SVGAnimatedString:
        ...
    
    @property
    def attributes(self) -> aspose.svg.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.svg.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.svg.dom.ShadowRoot:
        ...
    
    @property
    def owner_svg_element(self) -> aspose.svg.SVGSVGElement:
        ...
    
    @property
    def viewport_element(self) -> aspose.svg.SVGElement:
        ...
    
    @property
    def style(self) -> aspose.svg.dom.css.ICSSStyleDeclaration:
        '''Corresponds to attribute ‘style’ on the given element. If the user agent does not support styling with CSS, then this attribute must always have the value of null.'''
        ...
    
    @property
    def x(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute �x� on the given �filter� element.'''
        ...
    
    @property
    def y(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute �y� on the given �filter� element.'''
        ...
    
    @property
    def width(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute �width� on the given �filter� element.'''
        ...
    
    @property
    def height(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute �height� on the given �filter� element.'''
        ...
    
    @property
    def result(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute �result� on the given �filter� element.'''
        ...
    
    @property
    def in1(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute �in� on the given �feGaussianBlur� element.'''
        ...
    
    @property
    def std_deviation_x(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        ...
    
    @property
    def std_deviation_y(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        ...
    
    ...

class SVGFEImageElement(aspose.svg.SVGElement):
    '''The SVGFEImageElement interface corresponds to the ‘feImage’ element.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.svg.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.svg.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.svg.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.svg.dom.ShadowRootMode) -> aspose.svg.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.svg.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.svg.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @property
    def class_name(self) -> aspose.svg.datatypes.SVGAnimatedString:
        ...
    
    @property
    def attributes(self) -> aspose.svg.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.svg.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.svg.dom.ShadowRoot:
        ...
    
    @property
    def owner_svg_element(self) -> aspose.svg.SVGSVGElement:
        ...
    
    @property
    def viewport_element(self) -> aspose.svg.SVGElement:
        ...
    
    @property
    def style(self) -> aspose.svg.dom.css.ICSSStyleDeclaration:
        '''Corresponds to attribute ‘style’ on the given element. If the user agent does not support styling with CSS, then this attribute must always have the value of null.'''
        ...
    
    @property
    def href(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘xlink:href’ on the given element.'''
        ...
    
    @property
    def x(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘x’ on the given ‘filter’ element.'''
        ...
    
    @property
    def y(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘y’ on the given ‘filter’ element.'''
        ...
    
    @property
    def width(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘width’ on the given ‘filter’ element.'''
        ...
    
    @property
    def height(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘height’ on the given ‘filter’ element.'''
        ...
    
    @property
    def result(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘result’ on the given ‘filter’ element.'''
        ...
    
    @property
    def preserve_aspect_ratio(self) -> aspose.svg.datatypes.SVGAnimatedPreserveAspectRatio:
        ...
    
    ...

class SVGFEMergeElement(aspose.svg.SVGElement):
    '''The SVGFEMergeElement interface corresponds to the ‘feMerge’ element.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.svg.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.svg.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.svg.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.svg.dom.ShadowRootMode) -> aspose.svg.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.svg.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.svg.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @property
    def class_name(self) -> aspose.svg.datatypes.SVGAnimatedString:
        ...
    
    @property
    def attributes(self) -> aspose.svg.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.svg.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.svg.dom.ShadowRoot:
        ...
    
    @property
    def owner_svg_element(self) -> aspose.svg.SVGSVGElement:
        ...
    
    @property
    def viewport_element(self) -> aspose.svg.SVGElement:
        ...
    
    @property
    def style(self) -> aspose.svg.dom.css.ICSSStyleDeclaration:
        '''Corresponds to attribute ‘style’ on the given element. If the user agent does not support styling with CSS, then this attribute must always have the value of null.'''
        ...
    
    @property
    def x(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘x’ on the given ‘filter’ element.'''
        ...
    
    @property
    def y(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘y’ on the given ‘filter’ element.'''
        ...
    
    @property
    def width(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘width’ on the given ‘filter’ element.'''
        ...
    
    @property
    def height(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘height’ on the given ‘filter’ element.'''
        ...
    
    @property
    def result(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘result’ on the given ‘filter’ element.'''
        ...
    
    ...

class SVGFEMergeNodeElement(aspose.svg.SVGElement):
    '''The SVGFEMergeNodeElement interface corresponds to the ‘feMergeNode’ element.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.svg.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.svg.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.svg.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.svg.dom.ShadowRootMode) -> aspose.svg.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.svg.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.svg.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @property
    def class_name(self) -> aspose.svg.datatypes.SVGAnimatedString:
        ...
    
    @property
    def attributes(self) -> aspose.svg.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.svg.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.svg.dom.ShadowRoot:
        ...
    
    @property
    def owner_svg_element(self) -> aspose.svg.SVGSVGElement:
        ...
    
    @property
    def viewport_element(self) -> aspose.svg.SVGElement:
        ...
    
    @property
    def style(self) -> aspose.svg.dom.css.ICSSStyleDeclaration:
        '''Corresponds to attribute ‘style’ on the given element. If the user agent does not support styling with CSS, then this attribute must always have the value of null.'''
        ...
    
    @property
    def in1(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘in’ on the given ‘feMergeNode’ element.'''
        ...
    
    ...

class SVGFEMorphologyElement(aspose.svg.SVGElement):
    '''The SVGFEMorphologyElement interface corresponds to the ‘feMorphology’ element.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.svg.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.svg.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.svg.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.svg.dom.ShadowRootMode) -> aspose.svg.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.svg.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.svg.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @property
    def class_name(self) -> aspose.svg.datatypes.SVGAnimatedString:
        ...
    
    @property
    def attributes(self) -> aspose.svg.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.svg.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.svg.dom.ShadowRoot:
        ...
    
    @property
    def owner_svg_element(self) -> aspose.svg.SVGSVGElement:
        ...
    
    @property
    def viewport_element(self) -> aspose.svg.SVGElement:
        ...
    
    @property
    def style(self) -> aspose.svg.dom.css.ICSSStyleDeclaration:
        '''Corresponds to attribute ‘style’ on the given element. If the user agent does not support styling with CSS, then this attribute must always have the value of null.'''
        ...
    
    @property
    def x(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘x’ on the given ‘filter’ element.'''
        ...
    
    @property
    def y(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘y’ on the given ‘filter’ element.'''
        ...
    
    @property
    def width(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘width’ on the given ‘filter’ element.'''
        ...
    
    @property
    def height(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘height’ on the given ‘filter’ element.'''
        ...
    
    @property
    def result(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘result’ on the given ‘filter’ element.'''
        ...
    
    @property
    def in1(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘in’ on the given ‘feMorphology’ element.'''
        ...
    
    @property
    def operator(self) -> aspose.svg.datatypes.SVGAnimatedEnumeration:
        '''Corresponds to attribute ‘operator’ on the given ‘feMorphology’ element. Takes one of the SVG_MORPHOLOGY_OPERATOR_* constants defined on this interface.'''
        ...
    
    @property
    def radius_x(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        ...
    
    @property
    def radius_y(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        ...
    
    @classmethod
    @property
    def SVG_MORPHOLOGY_OPERATOR_UNKNOWN(cls) -> int:
        '''The type is not one of predefined types. It is invalid to attempt to define a new value of this type or to attempt to switch an existing value to this type.'''
        ...
    
    @classmethod
    @property
    def SVG_MORPHOLOGY_OPERATOR_ERODE(cls) -> int:
        '''Corresponds to value 'erode'.'''
        ...
    
    @classmethod
    @property
    def SVG_MORPHOLOGY_OPERATOR_DILATE(cls) -> int:
        '''Corresponds to value 'dilate'.'''
        ...
    
    ...

class SVGFEOffsetElement(aspose.svg.SVGElement):
    '''The SVGFEOffsetElement interface corresponds to the ‘feOffset’ element.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.svg.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.svg.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.svg.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.svg.dom.ShadowRootMode) -> aspose.svg.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.svg.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.svg.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @property
    def class_name(self) -> aspose.svg.datatypes.SVGAnimatedString:
        ...
    
    @property
    def attributes(self) -> aspose.svg.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.svg.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.svg.dom.ShadowRoot:
        ...
    
    @property
    def owner_svg_element(self) -> aspose.svg.SVGSVGElement:
        ...
    
    @property
    def viewport_element(self) -> aspose.svg.SVGElement:
        ...
    
    @property
    def style(self) -> aspose.svg.dom.css.ICSSStyleDeclaration:
        '''Corresponds to attribute ‘style’ on the given element. If the user agent does not support styling with CSS, then this attribute must always have the value of null.'''
        ...
    
    @property
    def x(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘x’ on the given ‘filter’ element.'''
        ...
    
    @property
    def y(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘y’ on the given ‘filter’ element.'''
        ...
    
    @property
    def width(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘width’ on the given ‘filter’ element.'''
        ...
    
    @property
    def height(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘height’ on the given ‘filter’ element.'''
        ...
    
    @property
    def result(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘result’ on the given ‘filter’ element.'''
        ...
    
    @property
    def in1(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘in’ on the given ‘feOffset’ element.'''
        ...
    
    @property
    def dx(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘dx’ on the given ‘feOffset’ element.'''
        ...
    
    @property
    def dy(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘dy’ on the given ‘feOffset’ element.'''
        ...
    
    ...

class SVGFEPointLightElement(aspose.svg.SVGElement):
    '''The SVGFEPointLightElement interface corresponds to the ‘fePointLight’ element.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.svg.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.svg.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.svg.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.svg.dom.ShadowRootMode) -> aspose.svg.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.svg.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.svg.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @property
    def class_name(self) -> aspose.svg.datatypes.SVGAnimatedString:
        ...
    
    @property
    def attributes(self) -> aspose.svg.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.svg.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.svg.dom.ShadowRoot:
        ...
    
    @property
    def owner_svg_element(self) -> aspose.svg.SVGSVGElement:
        ...
    
    @property
    def viewport_element(self) -> aspose.svg.SVGElement:
        ...
    
    @property
    def style(self) -> aspose.svg.dom.css.ICSSStyleDeclaration:
        '''Corresponds to attribute ‘style’ on the given element. If the user agent does not support styling with CSS, then this attribute must always have the value of null.'''
        ...
    
    @property
    def x(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘x’ on the given ‘fePointLight’ element.'''
        ...
    
    @property
    def y(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘y’ on the given ‘fePointLight’ element.'''
        ...
    
    @property
    def z(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘z’ on the given ‘fePointLight’ element.'''
        ...
    
    ...

class SVGFESpecularLightingElement(aspose.svg.SVGElement):
    '''The SVGFESpecularLightingElement interface corresponds to the ‘feSpecularLighting’ element.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.svg.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.svg.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.svg.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.svg.dom.ShadowRootMode) -> aspose.svg.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.svg.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.svg.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @property
    def class_name(self) -> aspose.svg.datatypes.SVGAnimatedString:
        ...
    
    @property
    def attributes(self) -> aspose.svg.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.svg.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.svg.dom.ShadowRoot:
        ...
    
    @property
    def owner_svg_element(self) -> aspose.svg.SVGSVGElement:
        ...
    
    @property
    def viewport_element(self) -> aspose.svg.SVGElement:
        ...
    
    @property
    def style(self) -> aspose.svg.dom.css.ICSSStyleDeclaration:
        '''Corresponds to attribute ‘style’ on the given element. If the user agent does not support styling with CSS, then this attribute must always have the value of null.'''
        ...
    
    @property
    def x(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘x’ on the given ‘filter’ element.'''
        ...
    
    @property
    def y(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘y’ on the given ‘filter’ element.'''
        ...
    
    @property
    def width(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘width’ on the given ‘filter’ element.'''
        ...
    
    @property
    def height(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘height’ on the given ‘filter’ element.'''
        ...
    
    @property
    def result(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘result’ on the given ‘filter’ element.'''
        ...
    
    @property
    def in1(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘in’ on the given ‘feSpecularLighting’ element.'''
        ...
    
    @property
    def surface_scale(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        ...
    
    @property
    def specular_constant(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        ...
    
    @property
    def specular_exponent(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        ...
    
    @property
    def kernel_unit_length_x(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        ...
    
    @property
    def kernel_unit_length_y(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        ...
    
    ...

class SVGFESpotLightElement(aspose.svg.SVGElement):
    '''The SVGFESpotLightElement interface corresponds to the ‘feSpotLight’ element.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.svg.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.svg.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.svg.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.svg.dom.ShadowRootMode) -> aspose.svg.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.svg.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.svg.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @property
    def class_name(self) -> aspose.svg.datatypes.SVGAnimatedString:
        ...
    
    @property
    def attributes(self) -> aspose.svg.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.svg.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.svg.dom.ShadowRoot:
        ...
    
    @property
    def owner_svg_element(self) -> aspose.svg.SVGSVGElement:
        ...
    
    @property
    def viewport_element(self) -> aspose.svg.SVGElement:
        ...
    
    @property
    def style(self) -> aspose.svg.dom.css.ICSSStyleDeclaration:
        '''Corresponds to attribute ‘style’ on the given element. If the user agent does not support styling with CSS, then this attribute must always have the value of null.'''
        ...
    
    @property
    def x(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘x’ on the given ‘feSpotLight’ element.'''
        ...
    
    @property
    def y(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘y’ on the given ‘feSpotLight’ element.'''
        ...
    
    @property
    def z(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘z’ on the given ‘feSpotLight’ element.'''
        ...
    
    @property
    def points_at_x(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        ...
    
    @property
    def points_at_y(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        ...
    
    @property
    def points_at_z(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        ...
    
    @property
    def specular_exponent(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        ...
    
    @property
    def limiting_cone_angle(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        ...
    
    ...

class SVGFETileElement(aspose.svg.SVGElement):
    '''The SVGFETileElement interface corresponds to the ‘feTile’ element.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.svg.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.svg.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.svg.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.svg.dom.ShadowRootMode) -> aspose.svg.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.svg.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.svg.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @property
    def class_name(self) -> aspose.svg.datatypes.SVGAnimatedString:
        ...
    
    @property
    def attributes(self) -> aspose.svg.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.svg.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.svg.dom.ShadowRoot:
        ...
    
    @property
    def owner_svg_element(self) -> aspose.svg.SVGSVGElement:
        ...
    
    @property
    def viewport_element(self) -> aspose.svg.SVGElement:
        ...
    
    @property
    def style(self) -> aspose.svg.dom.css.ICSSStyleDeclaration:
        '''Corresponds to attribute ‘style’ on the given element. If the user agent does not support styling with CSS, then this attribute must always have the value of null.'''
        ...
    
    @property
    def x(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘x’ on the given ‘filter’ element.'''
        ...
    
    @property
    def y(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘y’ on the given ‘filter’ element.'''
        ...
    
    @property
    def width(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘width’ on the given ‘filter’ element.'''
        ...
    
    @property
    def height(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘height’ on the given ‘filter’ element.'''
        ...
    
    @property
    def result(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘result’ on the given ‘filter’ element.'''
        ...
    
    @property
    def in1(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘in’ on the given ‘feTile’ element.'''
        ...
    
    ...

class SVGFETurbulenceElement(aspose.svg.SVGElement):
    '''The SVGFETurbulenceElement interface corresponds to the ‘feTurbulence’ element.'''
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.'''
        ...
    
    @overload
    def add_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the registration of event listeners on the event target.
        
        :param type: The event type for which the user is registering
        :param listener: Takes an interface implemented by the user which contains the methods to be called when the event occurs.
        :param use_capture: If true, useCapture indicates that the user wishes to initiate capture.
        After initiating capture, all events of the specified type will be dispatched to the registered
        :py:class:`aspose.svg.dom.events.IEventListener`
        before being dispatched to any Event Targets beneath them in the tree.
        Events which are bubbling upward through the tree will not trigger an :py:class:`aspose.svg.dom.events.IEventListener` designated to use capture.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.'''
        ...
    
    @overload
    def remove_event_listener(self, type : str, listener : aspose.svg.dom.events.IEventListener, use_capture : bool):
        '''This method allows the removal of event listeners from the event target.
        If an :py:class:`aspose.svg.dom.events.IEventListener` is removed from an :py:class:`aspose.svg.dom.EventTarget` while it is processing an event, it will not be triggered by the current actions.
        Event Listeners can never be invoked after being removed.
        
        :param type: Specifies the event type of the :py:class:`aspose.svg.dom.events.IEventListener` being removed.
        :param listener: The :py:class:`aspose.svg.dom.events.IEventListener` parameter indicates the :py:class:`aspose.svg.dom.events.IEventListener` to be removed.
        :param use_capture: Specifies whether the EventListener being removed was registered as a capturing listener or not.
        If a listener was registered twice, one with capture and one without, each must be removed separately.
        Removal of a capturing listener does not affect a non-capturing version of the same listener, and vice versa.'''
        ...
    
    @overload
    def clone_node(self) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :returns: Returns node'''
        ...
    
    @overload
    def clone_node(self, deep : bool) -> aspose.svg.dom.Node:
        '''Returns a duplicate of this node, i.e., serves as a generic copy constructor for nodes. The duplicate node has no parent (parentNode is null) and no user data.
        
        :param deep: if set to ``true`` [deep].
        :returns: Returns node'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    @overload
    def toggle_attribute(self, qualified_name : str, force : bool) -> bool:
        '''If force is not given, "toggles" qualifiedName, removing it if it is present and adding it if it is not present. If force is true, adds qualifiedName.
        If force is false, removes qualifiedName.
        
        :param qualified_name: The attribute QualifiedName.
        :param force: The force option to toggle attribute.
        :returns: Returns true if qualifiedName is now present; otherwise false.'''
        ...
    
    def get_platform_type(self) -> Type:
        '''This method is used to retrieve ECMAScript object :py:class:`System.Type`.
        
        :returns: The ECMAScript object :py:class:`System.Type`.'''
        ...
    
    def dispatch_event(self, event : aspose.svg.dom.events.Event) -> bool:
        '''This method allows the dispatch of events into the implementations event model.
        
        :param event: Specifies the event type, behavior, and contextual information to be used in processing the event.
        :returns: The return value of :py:func:`aspose.svg.dom.EventTarget.dispatch_event` indicates whether any of the listeners which handled the event called :py:func:`aspose.svg.dom.events.Event.prevent_default`.
        If :py:func:`aspose.svg.dom.events.Event.prevent_default` was called the value is false, else the value is true.'''
        ...
    
    def has_child_nodes(self) -> bool:
        '''Returns whether this node has any children.
        
        :returns: ``true`` if has child nodes otherwise, ``false``.'''
        ...
    
    def normalize(self):
        '''Puts all Text nodes in the full depth of the sub-tree underneath this Node, including attribute nodes, into a "normal" form where only structure (e.g., elements, comments, processing instructions, CDATA sections, and entity references) separates Text nodes, i.e., there are neither adjacent Text nodes nor empty Text nodes. This can be used to ensure that the DOM view of a document is the same as if it were saved and re-loaded, and is useful when operations (such as XPointer [XPointer] lookups) that depend on a particular document tree structure are to be used. If the parameter "normalize-characters" of the DOMConfiguration object attached to the Node.ownerDocument is true, this method will also fully normalize the characters of the Text nodes.'''
        ...
    
    def is_equal_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Tests whether two nodes are equal.
        This method tests for equality of nodes, not sameness (i.e., whether the two nodes are references to the same object) which can be tested with Node.isSameNode(). All nodes that are the same will also be equal, though the reverse may not be true.
        
        :param other_node: The other node.
        :returns: ``true`` if [is equal node] [the specified arg]; otherwise, ``false``.'''
        ...
    
    def is_same_node(self, other_node : aspose.svg.dom.Node) -> bool:
        '''Returns whether this node is the same node as the given one.
        This method provides a way to determine whether two Node references returned by the implementation reference the same object. When two Node references are references to the same object, even if through a proxy, the references may be used completely interchangeably, such that all attributes have the same values and calling the same DOM method on either reference always has exactly the same effect.
        
        :param other_node: The other node.
        :returns: ``true`` if [is same node] [the specified other]; otherwise, ``false``.'''
        ...
    
    def lookup_prefix(self, namespace_uri : str) -> str:
        '''Look up the prefix associated to the given namespace URI, starting from this node. The default namespace declarations are ignored by this method.
        See Namespace Prefix Lookup for details on the algorithm used by this method.
        
        :param namespace_uri: The namespace URI.
        :returns: Returns prefix'''
        ...
    
    def lookup_namespace_uri(self, prefix : str) -> str:
        '''Look up the namespace URI associated to the given prefix, starting from this node.
        
        :param prefix: The prefix.
        :returns: Returns namespace URI'''
        ...
    
    def is_default_namespace(self, namespace_uri : str) -> bool:
        '''This method checks if the specified namespaceURI is the default namespace or not.
        
        :param namespace_uri: The namespace URI.
        :returns: ``true`` if [is default namespace] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def insert_before(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Inserts the node before the existing child node child. If child is null, insert node at the end of the list of children.
        If child is a DocumentFragment object, all of its children are inserted, in the same order, before child. If the child is already in the tree, it is first removed.
        
        :param node: The new child.
        :param child: The ref child.
        :returns: Returns inserted node'''
        ...
    
    def replace_child(self, node : aspose.svg.dom.Node, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Replaces the child node oldChild with newChild in the list of children, and returns the oldChild node.
        If newChild is a DocumentFragment object, oldChild is replaced by all of the DocumentFragment children, which are inserted in the same order. If the newChild is already in the tree, it is first removed.
        
        :param node: The new node.
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def remove_child(self, child : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Removes the child node indicated by oldChild from the list of children, and returns it.
        
        :param child: The old child.
        :returns: Returns node'''
        ...
    
    def append_child(self, node : aspose.svg.dom.Node) -> aspose.svg.dom.Node:
        '''Adds the node newChild to the end of the list of children of this node. If the newChild is already in the tree, it is first removed.
        
        :param node: The node to append.
        :returns: Returns node'''
        ...
    
    def get_attribute_names(self) -> List[str]:
        '''Returns the attribute names of the element as an Array of strings. If the element has no attributes it returns an empty array.
        
        :returns: Array of strings represents attribute names.'''
        ...
    
    def has_attributes(self) -> bool:
        '''Returns whether this node (if it is an element) has any attributes
        
        :returns: boolean ``true`` if this node has any attributes, ``false`` otherwise.'''
        ...
    
    def get_attribute(self, qualified_name : str) -> str:
        '''Retrieves an attribute value by name.
        
        :param qualified_name: The name of the attribute to retrieve.
        :returns: Returns attribute value'''
        ...
    
    def get_attribute_ns(self, namespace_uri : str, local_name : str) -> str:
        '''Retrieves an attribute value by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute(self, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with that name is already present in the element, its value is changed to be that of the value parameter
        
        :param qualified_name: The attribute name.
        :param value: The value.'''
        ...
    
    def set_attribute_ns(self, namespace_uri : str, qualified_name : str, value : str):
        '''Adds a new attribute. If an attribute with the same local name and namespace URI is already present on the element, its prefix is changed to be the prefix part of the qualifiedName, and its value is changed to be the value parameter.
        
        :param namespace_uri: The namespace URI.
        :param qualified_name: Name of the qualified.
        :param value: The value.'''
        ...
    
    def remove_attribute(self, qualified_name : str):
        '''Removes an attribute by name.
        
        :param qualified_name: The attribute name.'''
        ...
    
    def remove_attribute_ns(self, namespace_uri : str, local_name : str):
        '''Removes an attribute by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.'''
        ...
    
    def has_attribute(self, qualified_name : str) -> bool:
        '''Returns true when an attribute with a given name is specified on this element or has a default value, false otherwise.
        
        :param qualified_name: The attribute name.
        :returns: ``true`` if the specified name has attribute; otherwise, ``false``.'''
        ...
    
    def has_attribute_ns(self, namespace_uri : str, local_name : str) -> bool:
        '''Returns true when an attribute with a given local name and namespace URI is specified on this element or has a default value, false otherwise.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: ``true`` if [has attribute NS] [the specified namespace URI]; otherwise, ``false``.'''
        ...
    
    def get_attribute_node(self, qualified_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an attribute node by name.
        
        :param qualified_name: The attribute name.
        :returns: Returns attribute value'''
        ...
    
    def set_attribute_node(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute node. If an attribute with that name (nodeName) is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def remove_attribute_node(self, old_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Removes the specified attribute node.
        
        :param old_attr: The old attr.
        :returns: Returns attribute'''
        ...
    
    def get_attribute_node_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.dom.Attr:
        '''Retrieves an Attr node by local name and namespace URI.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns attribute'''
        ...
    
    def set_attribute_node_ns(self, new_attr : aspose.svg.dom.Attr) -> aspose.svg.dom.Attr:
        '''Adds a new attribute. If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
        
        :param new_attr: The new attr.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name(self, name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all descendant Elements with a given tag name, in document order.
        
        :param name: The tag name.
        :returns: Returns attribute'''
        ...
    
    def get_elements_by_tag_name_ns(self, namespace_uri : str, local_name : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a NodeList of all the descendant Elements with a given local name and namespace URI in document order.
        
        :param namespace_uri: The namespace URI.
        :param local_name: Name of the local.
        :returns: Returns elements'''
        ...
    
    def remove(self):
        '''Removes this instance.'''
        ...
    
    def query_selector_all(self, selector : str) -> aspose.svg.collections.NodeList:
        '''Returns a NodeList of all the Elements in document, which match selector
        
        :param selector: The selector
        :returns: :py:class:`aspose.svg.collections.HTMLCollection`'''
        ...
    
    def query_selector(self, selector : str) -> aspose.svg.dom.Element:
        '''Returns the first Element in document, which match selector
        
        :param selector: The selector.
        :returns: The matched element'''
        ...
    
    def attach_shadow(self, mode : aspose.svg.dom.ShadowRootMode) -> aspose.svg.dom.ShadowRoot:
        '''Creates shadow root and attaches it to current element.
        
        :param mode: Mode in which shadow root will be created.
        :returns: Created :py:class:`aspose.svg.dom.ShadowRoot`.'''
        ...
    
    def get_elements_by_class_name(self, class_names : str) -> aspose.svg.collections.HTMLCollection:
        '''Returns a live NodeList object containing all the elements in the document that have all the classes specified in argument.
        http://www.w3.org/TR/dom/
        
        :param class_names: The string string that contains an unordered set of unique space-separated tokens representing classes (class names)
        :returns: The :py:class:`aspose.svg.dom.Element`.'''
        ...
    
    @property
    def node_type(self) -> int:
        ...
    
    @property
    def local_name(self) -> str:
        ...
    
    @property
    def namespace_uri(self) -> str:
        ...
    
    @property
    def prefix(self) -> str:
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @prefix.setter
    def prefix(self, value : str):
        '''The namespace prefix of this node, or null if it is unspecified. When it is defined to be null, setting it has no effect'''
        ...
    
    @property
    def node_name(self) -> str:
        ...
    
    @property
    def base_uri(self) -> str:
        ...
    
    @property
    def owner_document(self) -> aspose.svg.dom.Document:
        ...
    
    @property
    def parent_node(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def parent_element(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_nodes(self) -> aspose.svg.collections.NodeList:
        ...
    
    @property
    def first_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def last_child(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def previous_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def next_sibling(self) -> aspose.svg.dom.Node:
        ...
    
    @property
    def node_value(self) -> str:
        ...
    
    @node_value.setter
    def node_value(self, value : str):
        ...
    
    @property
    def text_content(self) -> str:
        ...
    
    @text_content.setter
    def text_content(self, value : str):
        ...
    
    @classmethod
    @property
    def ELEMENT_NODE(cls) -> int:
        '''An element node'''
        ...
    
    @classmethod
    @property
    def ATTRIBUTE_NODE(cls) -> int:
        '''An attribute node'''
        ...
    
    @classmethod
    @property
    def TEXT_NODE(cls) -> int:
        '''A text node'''
        ...
    
    @classmethod
    @property
    def CDATA_SECTION_NODE(cls) -> int:
        '''A cdata section node'''
        ...
    
    @classmethod
    @property
    def ENTITY_REFERENCE_NODE(cls) -> int:
        '''An entity reference node'''
        ...
    
    @classmethod
    @property
    def ENTITY_NODE(cls) -> int:
        '''An entity node'''
        ...
    
    @classmethod
    @property
    def PROCESSING_INSTRUCTION_NODE(cls) -> int:
        '''A processing instruction node'''
        ...
    
    @classmethod
    @property
    def COMMENT_NODE(cls) -> int:
        '''A comment node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_NODE(cls) -> int:
        '''A document node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_TYPE_NODE(cls) -> int:
        '''A document type node'''
        ...
    
    @classmethod
    @property
    def DOCUMENT_FRAGMENT_NODE(cls) -> int:
        '''A document fragment node'''
        ...
    
    @classmethod
    @property
    def NOTATION_NODE(cls) -> int:
        '''A notation node'''
        ...
    
    @property
    def tag_name(self) -> str:
        ...
    
    @property
    def id(self) -> str:
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @id.setter
    def id(self, value : str):
        '''The value of the ‘id’ attribute on the given element, or the empty string if ‘id’ is not present.'''
        ...
    
    @property
    def class_name(self) -> aspose.svg.datatypes.SVGAnimatedString:
        ...
    
    @property
    def attributes(self) -> aspose.svg.collections.NamedNodeMap:
        '''A NamedNodeMap containing the attributes of this node (if it is an Element) or null otherwise.'''
        ...
    
    @property
    def first_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def last_element_child(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def previous_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def next_element_sibling(self) -> aspose.svg.dom.Element:
        ...
    
    @property
    def child_element_count(self) -> int:
        ...
    
    @property
    def children(self) -> aspose.svg.collections.HTMLCollection:
        '''Returns the child elements of current element.'''
        ...
    
    @property
    def inner_html(self) -> str:
        ...
    
    @inner_html.setter
    def inner_html(self, value : str):
        ...
    
    @property
    def outer_html(self) -> str:
        ...
    
    @outer_html.setter
    def outer_html(self, value : str):
        ...
    
    @property
    def shadow_root(self) -> aspose.svg.dom.ShadowRoot:
        ...
    
    @property
    def owner_svg_element(self) -> aspose.svg.SVGSVGElement:
        ...
    
    @property
    def viewport_element(self) -> aspose.svg.SVGElement:
        ...
    
    @property
    def style(self) -> aspose.svg.dom.css.ICSSStyleDeclaration:
        '''Corresponds to attribute ‘style’ on the given element. If the user agent does not support styling with CSS, then this attribute must always have the value of null.'''
        ...
    
    @property
    def x(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘x’ on the given ‘filter’ element.'''
        ...
    
    @property
    def y(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘y’ on the given ‘filter’ element.'''
        ...
    
    @property
    def width(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘width’ on the given ‘filter’ element.'''
        ...
    
    @property
    def height(self) -> aspose.svg.datatypes.SVGAnimatedLength:
        '''Corresponds to attribute ‘height’ on the given ‘filter’ element.'''
        ...
    
    @property
    def result(self) -> aspose.svg.datatypes.SVGAnimatedString:
        '''Corresponds to attribute ‘result’ on the given ‘filter’ element.'''
        ...
    
    @property
    def base_frequency_x(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        ...
    
    @property
    def base_frequency_y(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        ...
    
    @property
    def num_octaves(self) -> aspose.svg.datatypes.SVGAnimatedInteger:
        ...
    
    @property
    def seed(self) -> aspose.svg.datatypes.SVGAnimatedNumber:
        '''Corresponds to attribute ‘seed’ on the given ‘feTurbulence’ element.'''
        ...
    
    @property
    def stitch_tiles(self) -> aspose.svg.datatypes.SVGAnimatedEnumeration:
        ...
    
    @property
    def type(self) -> aspose.svg.datatypes.SVGAnimatedEnumeration:
        '''Corresponds to attribute ‘type’ on the given ‘feTurbulence’ element. Takes one of the SVG_TURBULENCE_TYPE_* constants defined on this interface.'''
        ...
    
    @classmethod
    @property
    def SVG_TURBULENCE_TYPE_UNKNOWN(cls) -> int:
        '''The type is not one of predefined types. It is invalid to attempt to define a new value of this type or to attempt to switch an existing value to this type.'''
        ...
    
    @classmethod
    @property
    def SVG_TURBULENCE_TYPE_FRACTALNOISE(cls) -> int:
        '''Corresponds to value 'fractalNoise'.'''
        ...
    
    @classmethod
    @property
    def SVG_TURBULENCE_TYPE_TURBULENCE(cls) -> int:
        '''Corresponds to value 'turbulence'.'''
        ...
    
    @classmethod
    @property
    def SVG_STITCHTYPE_UNKNOWN(cls) -> int:
        '''The type is not one of predefined types. It is invalid to attempt to define a new value of this type or to attempt to switch an existing value to this type.'''
        ...
    
    @classmethod
    @property
    def SVG_STITCHTYPE_STITCH(cls) -> int:
        '''Corresponds to value 'stitch'.'''
        ...
    
    @classmethod
    @property
    def SVG_STITCHTYPE_NOSTITCH(cls) -> int:
        '''Corresponds to value 'noStitch'.'''
        ...
    
    ...

